--  setting a seed for rng
TIME = os.time()
CLOCK = tostring(os.clock())
CLOCK = tonumber(string.sub(CLOCK, string.find(CLOCK, "%.")+1))
math.randomseed(TIME + CLOCK)
MATRIX_AND = {{0,0},{0,1}}
MATRIX_OR = {{0,1},{1,1}}
HEXES = '0123456789abcdef'
local SciKGTeX = {}
SciKGTeX.whole_string = ""
SciKGTeX.properties_used = {}
SciKGTeX.property_commands = {}
SciKGTeX.mandatory_properties = {
    'research_problem',
    'objective',
    'method',
    'result',
    'conclusion'
}
SciKGTeX.PRODUCE_XMP_FILE = true
SciKGTeX.WARNING_LEVEL = 1

local XMP = {}
XMP.lines = {}
XMP.namespaces = {}
XMP.property_ns = {}
XMP.XMP_TOP = [[<x:xmpmeta xmlns:x="adobe:ns:meta/">]]
XMP.XMP_BOTTOM = [[</x:xmpmeta>]]
XMP.PACKET_END = [[<?xpacket end="r"?>]]

local UUID = {}

---------------------------- utilities -------------------------------

-- performs the bitwise operation specified by truth matrix on two numbers.
function BITWISE(x, y, matrix)
  local z = 0
  local pow = 1
  while x > 0 or y > 0 do
    z = z + (matrix[x%2+1][y%2+1] * pow)
    pow = pow * 2
    x = math.floor(x/2)
    y = math.floor(y/2)
  end
  return z
end

function INT2HEX(x)
  local s,base,pow = '',16,0
  local d
  while x > 0 do
    d = x % base + 1
    x = math.floor(x/base)
    s = string.sub(HEXES, d, d)..s
  end
  if #s == 1 then s = "0" .. s end
  return s
end

function get_output_dir()
    if arg ~= nil then
        for k,v in ipairs(arg) do
            val, is_output_argument = v:gsub('%-%-output%-directory=(.*)','%1')
            if is_output_argument > 0 then
                return val
            end
        end
        return  nil
    end
    return nil
end

function read_header_of_file(path)
    local fh = io.open(path, "rb")
    if fh then
        local first_line = assert(fh:read())
        fh:close()
        return first_line
    else
        print ("No xmp metadata file found!")
        return nil 
    end
end
  
function extract_uuid_from_header(header)
    return header:gsub('.*id=\"(.-)\".*','%1')
end

function generate_UUID()
    UUID:initialize('00:0c:29:69:41:c6')
    return UUID:toString()
end

function string:split(sep)
    if sep == nil then
        sep = "%s"
    end
    local t = {}
    for str in self:gmatch("([^"..sep.."]+)") do
        table.insert(t, str)
    end
    return t
end

function spaces_to_underscores(s)
    return s:gsub('%s+','_')
end

function remove_environments(s)
    s,c = s:gsub('\\begin%s*{.-}{.-}%s*','')
    s,c = s:gsub('\\begin%s*{.-}%s*','')
    s,c = s:gsub('\\end%s*{.-}%s*','')
    return s
end

function remove_any_latex_command(s)
    s, c = s:gsub('\\%w+%s*%[%d*%]%s*{(.*)}','%1')
    if c > 0 then
        return remove_latex_commands(s)
    end
    s, c = s:gsub('\\%w+%s*{(.*)}','%1')
    if c > 0 then
        return remove_latex_commands(s)
    end
    s, c = s:gsub('\\%w+%s*','')
    if c > 0 then
        return remove_latex_commands(s)
    end
    return s
end

function find_last_occurence(s, repls)
    occurences = {}
    for pattern, repl in pairs(repls) do
        i, j = s:find(pattern)
        if i ~= nil then
            table.insert(occurences, {i,j,pattern})
        end
    end
    table.sort(occurences, function(l, r) return l[1]>r[1] end)
    if #occurences > 0 then
        return occurences[1]
    else
        return nil
    end
end

function exhaustively_replace_last_occurence_of_pattern(s, repls)
    last_occurence = find_last_occurence(s, repls)
    if last_occurence ~= nil then
        starts, ends, pattern = table.unpack(last_occurence)
        to_replace = s:sub(starts,ends)
    else
        return s
    end
    new_string = s:sub(0,starts-1) .. to_replace:gsub(pattern, repls[pattern], 1) .. s:sub(ends+1)
    return exhaustively_replace_last_occurence_of_pattern(new_string, repls)
end

function remove_latex_commands(s)
    replacements = {
        -- contribution with * and []
        ['\\contribution%s*%*%s*%[%d*%]%s*{.-}{.*}%s*'] = '',
        -- contribution with *
        ['\\contribution%s*%*%s*{.-}%s*{.*}%s*'] = '',
        -- contribution with []
        ['\\contribution%s*%[%d*%]%s*{.-}{(.*)}'] = '%1',
        -- contribution normal
        ['\\contribution%s*{.-}%s*{(.*)}'] = '%1',

        ['\\uri%s*{.-}%s*{(.*)}'] = '%1',
    }
    for cmd, used in pairs(SciKGTeX.property_commands) do
        -- []
        replacements['\\'.. cmd .. '%s*%[%d*%]%s*{(.*)}'] = '%1'
        -- normal command 
        replacements['\\'.. cmd .. '%s*{(.*)}'] = '%1'
        -- with * and []
        replacements['\\'.. cmd .. '%s*%*%s*%[%d*%]%s*{.*}%s*'] = ''
        -- with *
        replacements['\\'.. cmd .. '%s*%*%s*{.*}%s*'] =''
    end
    s = remove_environments(s)
    s = exhaustively_replace_last_occurence_of_pattern(s, replacements)    
    s = remove_any_latex_command(s)
    -- remove escape chars
    s = s:gsub('\\','')
    return s
end

function uri_valid(s)
    if s:find('http') ~= 1 then
        return false
    else
        return true
    end
end 

function resolve_entity(s)
    -- make sure the entity is only resolved at the innermost of nested commands.
    for _, cmd in ipairs(SciKGTeX.mandatory_properties) do
        if s:find('\\' .. cmd) then
            return false
        end
    end
    if s:find('\\contribution') then
        return false
    end
    uri, found = s:gsub('.*\\uri%s*{(.-)}%s*{.*}.*', '%1')
    if found == 1 then
        label = s:gsub('.*\\uri%s*{.-}%s*{(.*)}.*', '%1')
        entity = string.format('<rdf:Description rdf:about=\"%s\"><rdfs:label>%s</rdfs:label></rdf:Description>', uri, label)
        return entity
    else
        uri, found = s:gsub('.*\\uri%s*{(.-)}.*', '%1')
        if found == 1 then
            entity = string.format('<rdf:Description rdf:about=\"%s\"></rdf:Description>', uri)
            return entity
        else
            return false
        end
    end
end

---------------------------- UUID class methods  -------------------------------------

-- hwaddr is a string: hexes delimited by colons. e.g.: 00:0c:29:69:41:c6
function UUID:initialize(hwaddr)
    self._bytes = {
      math.random(0, 255),
      math.random(0, 255),
      math.random(0, 255),
      math.random(0, 255),
      math.random(0, 255),
      math.random(0, 255),
      math.random(0, 255),
      math.random(0, 255),
      math.random(0, 255),
      math.random(0, 255),
      -- should come from mac address
      tonumber(hwaddr:sub(1, 2), 16),
      tonumber(hwaddr:sub(4, 5), 16),
      tonumber(hwaddr:sub(7, 8), 16),
      tonumber(hwaddr:sub(10, 11), 16),
      tonumber(hwaddr:sub(13, 14), 16),
      tonumber(hwaddr:sub(16, 17), 16)
    }
    -- set the version
    self._bytes[7] = BITWISE(self._bytes[7], 0x0f, MATRIX_AND)
    self._bytes[7] = BITWISE(self._bytes[7], 0x40, MATRIX_OR)
    -- set the variant
    self._bytes[9] = BITWISE(self._bytes[7], 0x3f, MATRIX_AND)
    self._bytes[9] = BITWISE(self._bytes[7], 0x80, MATRIX_OR)
    self._string = nil
  end
  
  -- lazy string creation.
  function UUID:toString()
    if self._string == nil then
      self._string = INT2HEX(self._bytes[1])..INT2HEX(self._bytes[2])..
           INT2HEX(self._bytes[3])..INT2HEX(self._bytes[4]).."-"..
           INT2HEX(self._bytes[5])..INT2HEX(self._bytes[6]).."-"..
           INT2HEX(self._bytes[7])..INT2HEX(self._bytes[8]).."-"..
           INT2HEX(self._bytes[9])..INT2HEX(self._bytes[10]).."-"..
           INT2HEX(self._bytes[11])..INT2HEX(self._bytes[12])..
           INT2HEX(self._bytes[13])..INT2HEX(self._bytes[14])..
           INT2HEX(self._bytes[15])..INT2HEX(self._bytes[16])
    end
    return self._string
  end

---------------------------- Main class methods -------------------------------

function SciKGTeX:set_warning_level(wl)
    self.WARNING_LEVEL = wl
end

function SciKGTeX:warn(warning_message, ...)
    if self.WARNING_LEVEL > 0 then
        texio.write_nl("term and log", 
                [[Package SciKGTeX Warning: ]] .. string.format(warning_message, ...))
        texio.write_nl("term and log","\n")
    end
end

function SciKGTeX:error(warning_message, ...)
    tex.error([[Package SciKGTeX Error: ]] .. string.format(warning_message, ...))
end

SciKGTeX.command_factory = {}

SciKGTeX.command_factory.cmd_top = [[\newcommand{\%s}[2][]{]]
 
SciKGTeX.command_factory.cmd_top_star = [[\WithSuffix\newcommand\%s*[2][]{]]
 
SciKGTeX.command_factory.cmd_top_override = [[\renewcommand{\%s}[2][]{]]

SciKGTeX.command_factory.cmd_top_star_override = [[\WithSuffix\renewcommand\%s*[2][]{]]

SciKGTeX.command_factory.directlua_part = [[  \directlua{
    local content = "\luaescapestring{\unexpanded{#2}}"
    local belongs_to_contribution = "\luaescapestring{\unexpanded{#1}}"
    SciKGTeX.XMP:add_annotation(belongs_to_contribution, '%s', content, 'annotation-id')
  }]]

SciKGTeX.command_factory.cmd_bottom = [[}]]
SciKGTeX.command_factory.cmd_bottom_star = [[\ignorespaces}]]

function SciKGTeX.command_factory:build_command(command_name, tag_name)
    full_cmd = self.cmd_top .. "\n" .. self.directlua_part .. "\n  #2\n" .. self.cmd_bottom
    formatted_cmd = string.format(full_cmd, command_name, tag_name)
    for i, line in ipairs(formatted_cmd:split("\n")) do
        tex.print(line .. "%")
    end
end

function SciKGTeX.command_factory:build_star_command(command_name, tag_name)
    full_cmd = self.cmd_top_star .. "\n" .. self.directlua_part .. "\n" .. self.cmd_bottom_star
    formatted_cmd = string.format(full_cmd, command_name, tag_name)
    for i, line in ipairs(formatted_cmd:split("\n")) do
        tex.print(line .. "%")
    end
end

function SciKGTeX.command_factory:override_command(command_name, tag_name)
    full_cmd = self.cmd_top_override .. "\n" .. self.directlua_part .. "\n  #2\n" .. self.cmd_bottom
    formatted_cmd = string.format(full_cmd, command_name, tag_name)
    for i, line in ipairs(formatted_cmd:split("\n")) do
        tex.print(line .. "%")
    end
end

function SciKGTeX.command_factory:override_star_command(command_name, tag_name)
    full_cmd = self.cmd_top_star_override .. "\n" .. self.directlua_part .. "\n" .. self.cmd_bottom_star
    formatted_cmd = string.format(full_cmd, command_name, tag_name)
    for i, line in ipairs(formatted_cmd:split("\n")) do
        tex.print(line .. "%")
    end
end

function SciKGTeX:make_new_command(new_property, namespace, tag_name)
    if tag_name==nil then
        tag_name=new_property
    end
    -- check if property already exists
    if self.property_commands[new_property]~=nil then
        self:warn([[Method newpropertycommand: Repeated definition.
    Command %s already exists!
    Are you sure you want to override it?]], new_property)
        self:add_property(new_property, namespace)
        self.command_factory:override_command(new_property, tag_name)
        self.command_factory:override_star_command(new_property, tag_name)
    else
        self.property_commands[new_property] = false
        self:add_property(new_property, namespace)
        self.command_factory:build_command(new_property, tag_name)
        self.command_factory:build_star_command(new_property, tag_name)
    end
end

function SciKGTeX:add_property(new_property, namespace)
    new_property = self.XMP:escape_xml_tags(new_property)
    -- check if property already exists
    if self.properties_used[new_property]~=nil then
        self:warn([[Method addmetaproperty: Repeated definition.
Property %s already added!
Are you sure you want to replace it?]], new_property:gsub('_', ''))
    -- if not make it known to the object
    else
        self.properties_used[new_property] = false
    end
    ns_prefix = self.XMP:extract_namespace_prefix(namespace)
    self.XMP.property_ns[new_property] = ns_prefix
end

function SciKGTeX:register_property(prop_type)
    self.properties_used[prop_type] = true
end

function SciKGTeX:warn_unused_command()
    warning_message = [[No %s annotation found!
Are you sure you don't want to mark an entity with %s?]]
    for i, p in ipairs(self.mandatory_properties) do
        used = self.properties_used[p]
        if not used then
            p=p:gsub('_', '')
            self:warn(warning_message, p, p);
        end
    end
end

function SciKGTeX:warn_ambiguous_orkg_label(label, property_uris)
    warning_message = [[The property '%s' you used has several possible correspondences in the ORKG!
Currently this property is used %s.
Please check the URL to find out if that is the correct usage.
If not check if any of the following are more suiting:
%s

To suppress this message add the following to your document preamble:

\addmetaproperty[orkg_property, http://orkg.org/property/]{%s}

and replace any use of the command with 

\contribution{%s}

To use a different URI, replace '%s' with the property id at the end any of the URLs above which fits your usage best. 
]]
    uris = ""
    current = "http://orkg.org/property/" .. property_uris[1]
    for i, p in ipairs(property_uris) do
        if i > 1 then 
            uris = uris .. i-1 .. ". http://orkg.org/property/" .. p
            if i < #property_uris then
                uris = uris .. '\n'
            end
        end
    end
    how_to_use="\\addmetaproperty{http://orkg.org/property/}{" .. "}"
    self:warn(warning_message, label, current, uris, property_uris[1], property_uris[1], property_uris[1])
end

function SciKGTeX:print_entity(uri, label, hyperrefloaded)
    if label ~= "" and hyperrefloaded then
        tex.print(string.format('\\href{%s}{%s}', uri , label))
    elseif label ~= "" then
        tex.print(label)
    elseif hyperrefloaded then
        tex.print(string.format('\\url{%s}',uri))
    else
        tex.print(uri)
    end
end

---------------------------- XMP class methods -------------------------------

function XMP:escape_xml_tags(s)
    s = spaces_to_underscores(s)
    s, i = s:gsub('[^%a%d%.-_]','')
    if i > 0 then
        SciKGTeX:warn([[Method escape_xml_tags: Forbidden characters.
        Property %s can only contain letters, digits, underscores, hyphens and periods!
        Forbidden characters removed.]], s)
    end
    s, i = s:gsub('^([Xx][Mm][Ll])','_%1')
    if i > 0 then
        SciKGTeX:warn([[Method escape_xml_tags: Forbidden characters.
        Property %s can not start with xml!
        Changed to _xml.]], s)
    end
    return s
end

function XMP:escape_xml_content(s)
    s = s:gsub('&', '&amp;')
    s = s:gsub('>', '&gt;')
    return s:gsub('<', '&lt;')
end

function XMP:add_line(...)
    table.insert(self.lines, string.format(...))
end

function XMP:add_paper_node(paper_iri) 
    self.paper = {}
    self.paper.contributions = {}
    self.paper.id = paper_iri
    self.paper.title = nil
    self.paper.authors = {}
    self.paper.researchfield = nil
end

function XMP:add_contribution(key, contribution_iri)
    local contribution = {}
    contribution.properties = {}
    contribution.id = contribution_iri:gsub("<(default_contribution)>", "ORKG_default")
    self.paper.contributions[key] = contribution
end

function XMP:extract_namespace_prefix(ns_arg)
    if ns_arg == '' then
        return nil
    end
    uri_and_prefix = ns_arg:split(',%s+?')

    if #uri_and_prefix < 2 then
        SciKGTeX:error([[Method addmetaproperty: No prefix found.
    Unknown prefix, URI specification: %s.
    Please specify the arguments as [prefix, URI]!]], ns_arg)
        return nil
    elseif #uri_and_prefix > 2 then
        SciKGTeX:warn([[Method addmetaproperty: Too many arguments.
    Too many arguments in prefix, URI specification: %s.
    Excess arguments are ignored.]], ns_arg)
    end

    if not uri_valid(uri_and_prefix[2]) then 
        message = [[Method addmetaproperty: Invalid URI.
    The given URI %s is not a valid choice!
    Please use a resolvable URI starting with 'http'.]]
        SciKGTeX:error(message, uri_and_prefix[2])
        return nil
    end
    -- add the namespace if it has not been added yet    
    if self.namespaces[uri_and_prefix[1]]==nil then
        self:add_namespace(uri_and_prefix[1], uri_and_prefix[2])
    end
    return uri_and_prefix[1] 
end

function XMP:process_content(c)
    c = self:escape_xml_content(c)
    entity = resolve_entity(c)
    if entity ~= false then
        return entity
    end
    c = remove_latex_commands(c)
    return c
end

function XMP:property_has_namespace(annotation_type)
    annotation_type_t = annotation_type:split(':')
    
    if #annotation_type_t > 1 then
        annotation_type = annotation_type_t[2]
        prefix = annotation_type_t[1]
    else
        annotation_type = annotation_type_t[1]
        prefix = nil
    end
    return prefix, annotation_type 
end

function XMP:set_title(title)
    self.paper.title = title
end

function XMP:add_author(author)
    table.insert(self.paper.authors, author)
end

function XMP:set_researchfield(researchfield)
    self.paper.researchfield = researchfield
end

function XMP:add_annotation(contribution_ids, annotation_type, content, annotation_id)
    local annotation = {}
    -- check if a namespace is attached to the property specification
    prefix, annotation_type = self:property_has_namespace(annotation_type)
    annotation.type = annotation_type
    annotation.content = content
    annotation.id = annotation_id
    annotation.type = self:escape_xml_tags(annotation_type)

    -- take the prefix given, the prefix saved in the namespace dictionary or the default ns 
    annotation.prefix = prefix or self.property_ns[annotation.type] or 'orkg_property'
    if not (prefix or self.property_ns[annotation.type]) then
        orkg_entry = SciKGTeX.orkg_property_uri_map[annotation_type]
        if orkg_entry then
            -- property exists in ORKG
            if type(orkg_entry) == 'table' then
                -- more than two properties have this label
                annotation.id = orkg_entry[1]
                SciKGTeX:warn_ambiguous_orkg_label(annotation_type, orkg_entry)
            else
                -- one property with this label
                annotation.id = orkg_entry
            end
        else
            -- make a new property with the label
            -- TODO: raise a warning message.
            SciKGTeX:warn([[The property '%s' does not have a correspondence in the ORKG!
Consider reusing one of the properties in the ORKG (orkg.org) or adding the property to the knowledge graph online (https://orkg.org/addProperty).
To suppress this message use \addmetaproperty[orkg_property, http://orkg.org/property/]{<property id>}. Replace <property id> with the id of your newly created property.
Annotate in the text by using the contribution command like this: \contribution{<property id>}{<your text>}.
                ]], annotation_type, annotation_type)
            annotation.id = self:escape_xml_tags(annotation.type)
        end
    else
        annotation.id = self:escape_xml_tags(annotation.type)
    end
    -- register the use of the property in text
    SciKGTeX:register_property(annotation.type)

    -- check if the annotation was numbered
    if contribution_ids == '' then
        contribution_ids = '<default_contribution>'
    end
    contributions_ids_t = contribution_ids:split(',%s+?')
    -- add the annotations at the specified contribution
    for i, contribution_id in ipairs(contributions_ids_t) do
        -- add a new contribution if it has not been added yet
        if self.paper.contributions[contribution_id] == nil then
            self:add_contribution(contribution_id, 'contribution_'..contribution_id)
        end
        -- add the property annotation to the list of properties of a contribution
        -- check if the same annotation already exists (in case of double evaluation of the LaTeX command for example)
        already_there = false
        for _, prop in pairs(self.paper.contributions[contribution_id].properties) do
            if prop.content == annotation.content and prop.type == annotation.type then
                already_there = true
                break
            end
        end
        if not already_there then
            table.insert(self.paper.contributions[contribution_id].properties, annotation)
        end
    end
end

function XMP:add_namespace(abbr, uri)
    self.namespaces[abbr] = uri
end

function XMP:generate_rdf_root()
    ns_key_array = {}
    for ns, uri in pairs(self.namespaces) do table.insert(ns_key_array, ns) end
    root_string = [[<rdf:RDF ]]
    table.sort(ns_key_array)
    for i, key in ipairs(ns_key_array) do
        root_string = root_string .. "\n  xmlns:" .. key .. [[="]] .. self.namespaces[key] .. [["]]
    end
    root_string = root_string .. [[>]]
    return root_string
end

function XMP:generate_xmp_string(lb_char)
    lb_char = lb_char or "\n"
    if lb_char == "r" then
        lb_char = "\r"
    end
    output_string = ""
    sorted_contributions = {}
    for cb_id, contribution in pairs(XMP.paper.contributions) do 
        table.insert(sorted_contributions,cb_id)
    end
    table.sort(sorted_contributions)
    self:add_line('<?xpacket begin="?" id="%s"?>',self.paper.id)
    self:add_line(self.XMP_TOP)
    self:add_line(self:generate_rdf_root())
    --print(debug.traceback())
    if self.paper then
        self:add_line(
            '  <rdf:Description rdf:about="https://www.orkg.org/orkg/paper/%s">',
             self.paper.id
        )
        self:add_line('    <rdf:type rdf:resource="http://orkg.org/core#Paper"/>')
        if self.paper.title ~= nil then
            self:add_line(
                '    <orkg:hasTitle>%s</orkg:hasTitle>', 
                self:process_content(self.paper.title)
            )
        end
        for i, author in ipairs(self.paper.authors) do
          self:add_line(
            '    <orkg:hasAuthor>%s</orkg:hasAuthor>',
            self:process_content(author))
        end
        if self.paper.researchfield ~= nil then
            self:add_line(
                '    <orkg_property:P30>%s</orkg_property:P30>',
                self:process_content(self.paper.researchfield)
            )
        end
        for i, cb_id in pairs(sorted_contributions) do
            contribution = self.paper.contributions[cb_id]
            if i==1 then
                if #sorted_contributions > 1 then
                    self:add_line('    <orkg:hasResearchContribution rdf:parseType="Collection">')
                else
                    self:add_line('    <orkg:hasResearchContribution>')
                end
            end
            self:add_line(
                '      <orkg:ResearchContribution rdf:about="https://www.orkg.org/orkg/paper/%s">', 
                self.paper.id .. "/" ..contribution.id
            )
            for j, property in ipairs(contribution.properties) do
                self:add_line(
                    '          <%s:%s>%s</%s:%s>', 
                    property.prefix,
                    property.id, 
                    self:process_content(property.content),
                    property.prefix,
                    property.id
                )
            end
            self:add_line('      </orkg:ResearchContribution>')
            if i == #sorted_contributions then
                self:add_line('    </orkg:hasResearchContribution>')
            end
        end
        self:add_line('  </rdf:Description>')
    end
    self:add_line('</rdf:RDF>')
    self:add_line(self.XMP_BOTTOM)
    self:add_line(self.PACKET_END)

    return table.concat(self.lines, lb_char)

end

function XMP:attach_metadata_pdfstream(metadata_type)
    local xmp_string = self:generate_xmp_string()
    local new_pdf = pdf.obj {
        type = 'stream',
        attr = '/Type /'..metadata_type..' /Subtype /XML',
        immediate = true,
        compresslevel = 0,
        string = xmp_string,
    }
    self.lines = {}
    return new_pdf
end

function XMP:dump_metadata()
    local xmp_string = self:generate_xmp_string()
    local dir = get_output_dir() or '.'
    f = io.open(dir .. '/' .. tex.jobname .. '.xmp_metadata.xml','w')
    io.output(f)
    io.write(xmp_string)
    io.close(f)
end

luatexbase.add_to_callback('stop_run', function()
    SciKGTeX:warn_unused_command()
    if SciKGTeX.PRODUCE_XMP_FILE then
        XMP:dump_metadata()
    end
end, 'at_end')

--  Writing metadata packets
luatexbase.add_to_callback('finish_pdffile', function()
    if XMP.paper then
        if CONFORM_TO_PDFA then
            catalog_key='SciKGMetadata'
        else
            catalog_key='Metadata'
        end
        local metadata_obj = XMP:attach_metadata_pdfstream(catalog_key)
        local catalog = pdf.getcatalog() or ''
        pdf.setcatalog(catalog..string.format('/%s %s 0 R', catalog_key, metadata_obj))
    end
end, 'finish')

-- TODO: real identifier assigned

-- get the id or generate UUID
local output_dir = get_output_dir() or '.'
local header = read_header_of_file(output_dir .. '/' .. tex.jobname .. '.xmp_metadata.xml')
if  header ~= nil then
    id = extract_uuid_from_header(header)
end
if id == nil then
    id = generate_UUID()
    print('generate new id:', id)
end
XMP:add_paper_node(id)
XMP:add_namespace("rdf","http://www.w3.org/1999/02/22-rdf-syntax-ns#")
XMP:add_namespace("rdfs","http://www.w3.org/2000/01/rdf-schema#")
XMP:add_namespace("orkg","http://orkg.org/core#")
XMP:add_namespace("orkg_property","http://orkg.org/property/")

SciKGTeX.XMP = XMP
SciKGTeX.orkg_property_uri_map = {['yields']='P1',['employs']='P2',['addresses']='P0',['is a']='P3',['refers to']='P4',['uses']={'P5','uses','USES','P45096','P71204','wikidata:P2283','P126000'},['author']={'P6','P27','wikidata:P50'},['affiliation']='P7',['email']='P8',['ORCID']='P9',['DOI']={'P10','wikidata:P356'},['problem']='P11',['solution']='P12',['use case']='P13',['description']={'P14','description','SCHEMAORG:description','P106010','SKOSXL:description'},['implementation']={'P15','P35','HAS_IMPLEMENTATION'},['has']={'P16','P18022','P18055'},['has part']={'P17','P5085'},['part of']={'P18','PART_OF','wikidata:P361','P71202'},['input']='P19',['output']='P20',['programming language']='P21',['environment']='P22',['defines']='P23',['field']='P24',['web site']='P25',['doi']='P26',['publication month']='P28',['publication year']='P29',['research field']={'P30','P37484'},['contribution']='P31',['research problem']='P32',['approach']={'P33','HAS_APPROACH','P97035'},['evaluation']={'P34','HAS_EVALUATION','P5091'},['has subfield']='P36',['Heuristic followed']='P5000',['deals with']='P5001',['uses similarity']='P5002',['Performance metric']='P5003',['Evidence']='P5004',['Uncertainty']='P5005',['Limitations']='P5006',['Clustering']='P5007',['Graph']='P5008',['uses library']='P1000',['uses graph']='P1001',['uses framework']='P1002',['url']={'P1003','url','P45084','SCHEMAORG:url'},['model']={'P1004','P20072'},['method']='P1005',['result']='P1006',['experiment']='P1007',['conducted at']='P1008',['participants']='P1009',['robotised the workflow']='P2000',['Algorithm']='P2001',['Stable']='P2002',['Best complexity']='P2003',['Worst complexity']='P2004',['dataset']='P2005',['metric']={'P2006','HAS_METRIC'},['presents']='P2007',['code List']='P4005',['Formalization']='P2008',['keywords']='P3000',['dimension']='P4004',['structure']='P4007',['has specified output']='P4003',['measure']='P4006',['Feature extraction']='P3001',['Feature selection']='P3002',['Classification']='P3003',['precision']={'P3004','P5072'},['Sensitivity']='P3005',['Specificity']='P3006',['propose']='P3007',['SASD']='P4045',['SADASdAD']='P4046',['R4001']='P4000',['label']={'P4001','P5094'},['R4009']='P4002',['value']={'HAS_VALUE','P5086','P41815','P37446','CSVW_Value','P88000'},['component']='P4008',['has value specification']={'P4009','OBI:OBI_0001938'},['top Concept Of']='P4010',['in Scheme']='P4011',['type']={'P4012','type'},['range']='P4013',['has specified numeric value']='P4014',['has specified input']='P4015',['Process']={'P4018','PROCESS','P7109','P27042','P25016','P34126','P29003','P34026','P34030','P34069','P34067','P35124','P43060','P43053','P43057','P41297','P41296','P41312','P41269','P37161','P37390','P68007','P110036','P110039','P117053'},['Material']={'P4016','P7033','P9071','P34108','P27039','P18079','P18081','P27037','P25023','P25014','P34125','P29001','P34024','P34028','P34070','P34097','P34065','P34544','P34546','P34548','P34550','P34552','P35072','P35091','P35121','P36020','P37007','P37008','P37009','P69008','P45005','P44130','P43061','P43054','P43058','P41303','P41307','P41302','P41282','P41255','P41260','P41268','P37160','P37337','P37389','P37425','P37426','P37427','P37429','P37435','P37531','P37649','P54035','P54038','P55015','P68006','P68015','P110033','P110034','P110035','P110038','P117052','P97057'},['Data']={'P4017','P9072','P18007','P27040','P18080','P27038','P25024','P25015','P29002','P34025','P34029','P34071','P34066','P34545','P34547','P34549','P34551','P34553','P35073','P35092','P35122','P36019','P69007','P45006','P43062','P43059','P41298','P41304','P41308','P41301','P41295','P41311','P41254','P41252','P41261','P37336','P37163','P37392','P51000','P54036','P54039','P55016','P68008','P68016','P110037'},['Company']='P4019',['MAPE']='P4020',['MAE']='P4021',['Institution']='P4022',['Person']='P4023',['Challenge']='P4024',['from Chartered Institute of Library and Information Professional’s Library and Information Gazette']='P4025',['over the period May 2006-2007']='P4026',['research skills']='P4027',['customer service']='P4028',['interpersonal skills']='P4029',['communication skills']='P4030',['general computing skills']='P4031',['between advertisements and Information National Training Organisation and Library and Information Management Employability Skills']='P4032',['available']='P4033',['is']={'P4034','P4039','P20073','P20045','P20156','P20169'},['between']={'P4035','P4040'},['using']={'P4036','P4041'},['listing']={'P4037','P4042'},['could be applicated to']={'P4038','P4043'},['restricted to']='P4044',['has Xray string']='P43119',['has solubility']='P43111',['has size']='P4047',['from']={'P4048','P23062','P23101'},['has vertices']='P4049',['Has edges']='P4050',['provided by']='P4051',['is independent of']='P4052',['is about']='P4053',['based on']={'P4054','wikidata:P144'},['sample size']={'P4055','P57104'},['has methodology']='P4056',['Planung']='P4057',['Aktivität']='P4058',['Has url']='P4059',['capable of']='P4060',['is dependent of']='P4061',['showing']='P4062',['detecting']='P4063',['providing']='P4064',['finding']='P4065',['employing']='P4066',['leveraging']='P4067',['recognizing and normalizing']='P4068',['attaining']='P4069',['required skills for high-level staticians are']='P4070',['Jobs for lower level staticians are restricted to']='P4071',['sdfdasfsdfsf']='P4072',['fastText']='P4073',['Multipartite Rank']='P4074',['users']='P4075',['describes']='P4076',['source code']='P4077',['Information science']='P4078',['icon']='icon',['material']='MATERIAL',['data']='DATA',['Has ORCID']='HAS_ORCID',['onHomepage']='onHomepage',['Task']='P5009',['Test questions']='P5010',['Train questions']='P5011',['Question language']='P5012',['Language']={'P5013','P41926','Language'},['Question amount']='P5014',['Recall']={'P5015','P71079'},['F-measure']='P5016',['Runtime']='P5017',['On']='P5018',['Technique']={'P5019','P70000'},['Question analysis task']='P5020',['Phrase mapping task']='P5021',['Disambiguation task']='P5022',['Query construction task']='P5023',['Keyword']='P5024',['Filter']='P5025',['Sampling']={'P5026','P5037'},['Aggregation']={'P5027','P5038'},['Incremental']={'P5028','P5039'},['Disk']={'P5029','P5040'},['Domain']={'P5030','P5041','P41924'},['Application type']={'P5031','P5042'},['Data types']='P5032',['Visualization types']='P5033',['User recommendation']='P5034',['Preferences']='P5035',['Statistics']='P5036',['R6900']='P5099',['R6904']='P5100',['has material']='P7000',['Approach type']='P5043',['Document type']='P5044',['Summary usage']='P5045',['Summary characteristics']='P5046',['utilizes']='P5047',['sub system']='P5048',['location']={'P5049','wikidata:P276'},['see also']='P5050',['manufacturer']={'P5051','wikidata:P176'},['Webrosensor Oy']='P5052',['observes']='P5053',['vibration']='P5054',['WBS CM301 Datasheet']='P5055',['datasheet']='P5056',['Accelerometer vibration sensor (sd1)']='P5057',['Accelerometer vibration sensor (sd2)']='P5058',['Accelerometer vibration sensor (sd3)']='P5059',['AXIS 211W Wireless Network Camera']='P5060',['AXIS Communications']='P5061',['AXIS 211W Datasheet']='P5062',['A sensor network']='P5063',['website']='P5064',['Situation Theory Ontology']='P5065',['Waikato Environment for Knowledge Analysis']='P5066',['version']={'P5067','version','P45088','SCHEMAORG:version'},['acronym']='P5068',['Observation']='P5069',['class']={'P5070','sh:class','wikidata:P2308'},['sensor']='P5071',['recall']='P5073',['actual']='P5074',['predicted']='P5075',['instances']='P5076',['Apache Jena']='P5077',['Semantic Web Rule Language']='P5078',['Apache Cassandra']='P5079',['Apache Storm']='P5080',['purpose']='P5081',['operation']='P5082',['mode']={'P5083','P57007'},['Labelled Data']='P5084',['number of hidden neurons']='P5087',['classes']={'P5088','P119129'},['algorithm']='P5089',['configuration']='P5090',['is property of']='P5092',['pavement']='P5093',['class mappings']='P5095',['rule']='P5096',['performance']='P5097',['time']='P5098',['has user license']='P7002',['in presence of']='P7007',['Supports RDF']='P7009',['Uses graph store']='P7010',['Performed at']='P7011',['Cohort size']='P7012',['Has formula']='P7013',['Demo video']='P7014',['Architecture']='P7015',['Figure']='P7016',['R6906']='P5101',['R6908']='P5102',['order']={'P5103','order','sh:order'},['R6915']='P5104',['R6918']='P5105',['R6933']='P5108',['R6926']='P5106',['R6928']='P5107',['R6935']='P5109',['R6938']='P5110',['R6939']='P5111',['Has video']={'P7044','HasVideo'},['material & methods']='P6000',['results']={'P6001','P59031','wikidata:P2501'},['Results']={'P6002','P37365'},['has ingredient']='P6003',['has property']={'P6004','hasProperty'},['wha']='P7001',['has number']={'P7003','OEO:OEO_00140178'},['unit']={'P7004','P45076','P47007','P110124','unit'},['targeting']='P7005',['by using']='P7008',['state of research']='P7006',['Related video']='P7045',['R8136']='P7017',['R8138']='P7018',['R8141']='P7019',['R8145']='P7020',['R8148']='P7021',['R8150']='P7022',['R8156']='P7023',['R8160']='P7024',['R8167']='P7025',['R8168']='P7026',['R8169']='P7027',['R8171']='P7028',['R8176']='P7029',['R8179']='P7030',['R8183']='P7031',['R8180']='P7032',['Ontology']={'P7034','P7211','P7221'},['Full name']={'P7035','P7212','P7222'},['Example class']={'P7036','P7213','P7223'},['Description']={'P7037','P7214','P7224'},['Class count']={'P7038','P7215','P7225'},['Object property count']={'P7039','P7216','P7226'},['Data property count']={'P7040','P7217','P7227'},['Uses ontology']={'P7041','P7218','P7228'},['IRI']={'P7042','P7229','P7219'},['Website']={'P7043','P7220','P7230','website'},['Implemented into real vehicle']='P15018',['has source']='P15003',['Quick summary']='P15004',['Features used and feature selection']='P15005',['Machine learning algorithms']='P15006',['Semantic representation']='P7046',['Scope']={'P7047','P44173'},['Prospective/retrospective']='P7048',['Acquisition']='P7049',['Metadata']='P7050',['High level claims']='P7051',['Supports research data']='P7052',['Natural language statements']='P7053',['Discourse']='P7054',['Data type']='P7055',['Knowledge representation']='P7056',['Lemmas']='P15026',['# Entries']='P15027',['Labels']='P15028',['Tested for SA']='P15029',['POS Tags']='P15030',['MSA']='P15031',['Dialect']='P15032',['Emoticons']='P15033',['Availability']={'P15034','P59093'},['has object']='P7078',['Investigates']='P7079',['Uses technique']='P7080',['Analyzed for features']='P7081',['deployed in']='P7067',['measured by']='P7069',['uses tool']='P7073',['Used for']='P7074',['has outcome']='P7075',['Addressed by']='P7076',['has objective']='P7077',['has subProblem']='P7057',['Results from']='P7058',['Functions identical to']='P7059',['Results in']='P7060',['has characteristic']='P7061',['achieved by']='P7062',['establishes']='P7063',['has length']='P7064',['has feature']='P7065',['has function']='P7066',['Measures']='P7068',['has quality']='P7113',['has duration']='P7070',['Has finding']='P7071',['has conclusion']='P7072',['Operates in']='P7092',['lower than']={'P7093','LOWER_THAN','P71200'},['Implemented as']='P7082',['has participants characteristic']='P7098',['has data']={'P7099','P88002'},['has evidence']='P7100',['Has horizontal resolution']='P7137',['Artificial island ']='P7138',['Finite differences ']='P7139',['Arakawa B-grid']='P7140',['Analyses of']='P7083',['Observed in']='P7084',['has observations']='P7085',['includes']='P7086',['has disposition']='P7087',['At time period']='P7088',['has cause']={'P7089','wikidata:P828'},['replaced by']='P7090',['Includes analysis of']='P7091',['applied to']='P7094',['produces']={'P7095','PRODUCES'},['confirmed by']='P7096',['revealed by']='P7097',['has reference']={'P7102','HasReference'},['method applied to']='P7103',['realizes']='P7108',['has elements']='P7101',['Model Family']='P7121',['method applied to collagen fiber yields staining result']='P7105',['method applied to filament yields staining result']='P7106',['method applied to unit membranes yields staining result']='P7107',['Has Prognostic Variable']='P7120',['has species']='P7146',['method applied to elastin yields staining result']='P7104',['has version']='P7112',['Scheme method']='P7119',['Global Climate Model']='P7110',['has name']='P7111',['tripolar grid']='P7118',['has documentation']='P7114',['Has Horizontal Discretization']='P7115',['River Routing']='P7116',['The Northern Hemisphere geographical distribution of sea ice (1979-1998) is generally well simulated, particularly in winter']='P7127',['The total Arctic sea ice extent is underestimated from August to November in CNRM-CM5.1 due to a significant underestimation of sea ice off Alaska and over the eastern part of the Siberian basin']='P7128',['Total Arctic sea ice extent']='P7131',['Pole Treatment']='P7117',['has horizontal resolution']='P7135',['Global Annual Mean Surface salinity differences (1960–1999): -0.54 psu, rms=0.83 psu']={'P7125','P7126'},['The simulated Antarctic sea ice extent is underestimated by 1.6 x 10^6 km^2 in September']='P7129',['Simulated Antarctic sea ice extent']='P7130',['drift of sea level height']='P7123',['realistic energy budget']='P7124',['has spatial resolution']='P7122',['Sea ice off Alaska']='P7132',['Sea ice over the eastern part of the Siberian Basin']='P7133',['cytoplasm']='P7134',['Coupling With Atmosphere']='P7136',['spectral']='P7142',['Centered finite differences']='P7143',['FTW']='P7141',['Earth System Model']='P7144',['Carbon Cycle']='P7145',['sequencing platform']='P7147',['reads per run']='P7148',['read length in base pairs (paired-end*) ']='P7149',['reads per run in Million']='P7150',['runtime in days']='P7151',['data output rate in Gigabyte per day']='P7153',['cost of resequencing a human genome with 30X coverage in $']='P7156',['RMSE of global mean surface air temperature against ERA-Interim reanalysis']='P7190',['reagents cost in $']='P7154',['cost of machine in $']='P7157',['total data output yield in Gigabyte']='P7152',['cost per Gigabyte data output in $']='P7155',['Basic Approximations']='P7159',['Has scheme']='P7158',['Fixed grid']='P7160',['Centered finite differences ']='P7161',['Fixed grid ']='P7162',['major ice sheets']='P7163',['static ice']='P7164',['Minor ice caps']='P7165',['The horizontal discretisation is on an orthogonal curvilinear grid nominally one degree for both longitude and latitude. refinements: (1) a tripolar grid north of 65°N ; (2) a cosine dependent (Mercator) grid  south of 30°S; (3) a refinement of latitudinal spacing to 1/3°  between 10°S and 10°N ']='P7166',['even coverage']='P7168',['well resolved']='P7169',['not stained']='P7170',['has application']='P7167',['Tested various designs']='P15012',['Offline Database']='P15020',['poorly resolved']='P7171',['Advantages']='P15023',['Disadvantages']='P15024',['Oki T., and Y.C. Sud (1998) Design of the Total Runoff Integrating Pathways [TRIP] - A global river channel network.. Earth Interactions, 2.       Add to Favorites Track Citation Download Citation Email   https://doi.org/10.1175/1087-3562(1998)002<0001:DOTRIP>2.3.CO;2']='P7172',['Cold deep snow albedo ']='P7173',['Bare ice albedo']='P7174',['Melting deep snow albedo']='P7175',['The horizontal discretisation is on an orthogonal curvilinear grid nominally one degree for both longitude and latitude. It has the following refinements: (1) a tripolar grid (Murray 1996) is used north of 65°N to preclude a singularity at the geographical north pole; (2) a cosine dependent (Mercator) grid is used south of 30°S to avoid large grid cell aspect ratios and also to better resolve zonal currents in the Southern Ocean and at the Antarctic margin; and, (3) a refinement of latitudinal spacing to 1/3° is applied between 10°S and 10°N to better resolve predominantly zonal equatorial ocean currents.']={'P7176','P7177'},['Vertical Physics']='P7178',['Critical Richardson number']='P7179',['Radiation scheme']='P7180',['Surface Air Temperature']='P7184',['0.04 °C']='P7185',['0.35 °C']='P7186',['bias of global mean surface air temperature']='P7187',['RMSE of global mean surface air temperature']='P7188',['Edwards, J.M. and A. Slingo (1996) Studies with a flexible new radiation code. I: choosing a configuration for a large-scale model Q. J. R. Meteorol. Soc., 122, 689-720 ']={'P7181','P7182'},['Tripleclouds scheme']='P7183',['Bias of global mean surface air temperature against ERA-Interim reanalysis']='P7189',['Classifier']='P15021',['Bias of mean surface temperature over northern hemisphere land against ERA-Interim reanalysis:']='P7191',['Bias of mean surface temperature over high latitudes Southern Ocean (>60°)  against ERA-Interim reanalysis']='P7192',['Bias of mean surface temperature over high latitudes Southern Ocean (>60°) against ERA-Interim reanalysis']='P7193',['Bias of global mean precipitation against GPCP climatology']='P7194',['Cloud scheme']='P7195',['sea-ice volume trend']='P7200',['Sea-ice volume trend in the northern hemisphere']={'P7201','P7203'},['Sea-ice volume trend in the southern hemisphere']='P7202',['Trend of SST']='P7204',['Bias of global mean SST']='P7205',['Bias of northern hemisphere (0°-60°N) annual mean cloud amount against the D2 ISCCP observations ']={'P7196','P7197'},['Bias of southern hemisphere (60°S-0°) annual mean cloud amount against the D2 ISCCP observations ']={'P7198','P7199'},['Scheme Type']='P7208',['Bias of global mean SSS against the WOA2009 data']='P7206',['Interview, Survey or Brainstorming']='P15011',['Dynamical Core']='P7207',['1.4°']='P7209',['Solution ']='P7210',['Feature Extraction']='P15019',['same as']='SAME_AS',['venue']='HAS_VENUE',['reference']={'reference','P41817'},['1.4 °']='P8006',['Template sub-template']={'TemplateSub','TemplateSubTemplate'},['Algorithm name']='P15022',['applies']='P8000',['proposes']='P8001',['are based on']='P8002',['are defined by']='P8003',['extracts']='P8004',['scales up']='P8005',['Template of research field']='TemplateOfResearchField',['Template of predicate']='TemplateOfPredicate',['Template of class']='TemplateOfClass',['value specification']={'P9003','P34124'},['specified numeric value']='P9004',['Radiant energy input']='P28000',['has study design dependent variable']='P9000',['has dataset']={'P9001','hasDataset','HAS_DATASET'},['Template of research problem']='TemplateOfResearchProblem',['Template component']='TemplateComponent',['Template component property']='TemplateComponentProperty',['Template component value']='TemplateComponentValue',['has p-value']='P9002',['study design dependent variable']='P9005',['p-value']='P9006',['Modality']={'P9008','P69003'},['CPLEX']='P9007',['Has assay title']={'P34155','P34227','P34191','P34164','P34523','P34540','P34218','P34173','P34209','P34182','P34146','P34200','P34416','P34245','P34254','P34236','P34263','P34272','P34290','P34281','P34299','P34308','P34317','P34326','P34335','P34344','P34353','P34362','P34371','P34380','P34389','P34398','P34479','P34488','P34407','P34425','P34434','P34443','P34461','P34452','P34470','P34531','P34497','P34506','P34515'},['Has confirmatory assay']={'P34156','P34228','P34192','P34165','P34524','P34541','P34174','P34210','P34183','P34147','P34201','P34219','P34417','P34246','P34255','P34237','P34264','P34273','P34282','P34291','P34300','P34309','P34318','P34327','P34336','P34345','P34354','P34363','P34372','P34381','P34390','P34399','P34462','P34480','P34489','P34408','P34426','P34435','P34444','P34453','P34471','P34532','P34498','P34507','P34516'},['Has endpoint']={'P34157','P34229','P34193','P34211','P34166','P34525','P34542','P34175','P34184','P34148','P34202','P34220','P34418','P34247','P34256','P34238','P34310','P34265','P34274','P34283','P34292','P34301','P34319','P34328','P34337','P34346','P34355','P34364','P34373','P34382','P34391','P34400','P34463','P34481','P34490','P34409','P34427','P34436','P34445','P34454','P34472','P34533','P34499','P34508','P34517'},['Pretrained model']='P9009',['Clustering method']='P9010',['mean Average Precision']='P9011',['Lexicon']='P15025',['R@1']='P9013',['Image-to-Text Retrieval ']='P9014',['Text-to-Image Retrieval']='P9015',['image to text retrieval']='P9012',['electrolyte']='P9022',['R@10']='P9016',['Median Rank']='P9017',['Visual']='P9021',['Has model']='P9018',['Has heuristic']='P9019',['Has exact solution method']='P9020',['has instance']='P9023',['Source']={'P9024','P55018'},['has system specification']='P9025',['has performance']='P9026',['Has experimental datasets']={'P9027','P9031','P9029','P9033','P9035','P9037'},['has evaluation score']={'P9028','P9032','P9030','P9034','P9036','P9038'},['has age']='P9057',['has gender']='P9058',['has illness']='P9059',['date of illness onset']='P9060',['date of hospital admission']='P9061',['Study date']='P9040',['Methods']='P9041',['Approaches']='P9042',['Notes']='P9039',['R0 estimates (average)']={'P9043','P9045','P9046','P9047','P9048','P9049','P9050','P9051','P9052','P9053','P9054','P9055','P9056'},['95% Confidence interval']='P9044',['has symptom']='P9062',['receives therapy']='P9063',['has drug']='P9064',['has technique']='P9065',['RNeasy Plus Universal Mini kit']='P9066',['Qiagen']='P9067',['has body temperature']='P9068',['has date ']='P9069',['has instrument']='P9070',['Used prototypes for early feedback']='P15014',['Tested usability or user eTperience']='P15015',['Tested driving performance']='P15016',['Implemented as display mock-up']='P15017',['Relevant data']='P34000',['R60168']='P33129',['R60170']='P33130',['Has assay format']={'P34161','P34215','P34152','P34521','P34537','P34278','P34296','P34170','P34224','P34188','P34143','P34206','P34179','P34197','P34233','P34413','P34242','P34260','P34269','P34251','P34314','P34287','P34305','P34368','P34323','P34332','P34350','P34341','P34359','P34377','P34386','P34395','P34476','P34485','P34404','P34503','P34422','P34431','P34440','P34458','P34449','P34467','P34529','P34494','P34512'},['R59833']='P33075',['R59835']='P33076',['R59837']='P33077',['R58162']='P33041',['R58164']='P33042',['R58166']='P33043',['R58168']='P33044',['R58170']='P33045',['R58172']='P33046',['R58174']='P33047',['R58176']='P33048',['R58178']='P33049',['R58180']='P33050',['Has benchmark']='P34103',['Has incubation time value']={'P34230','P34194','P34212','P34167','P34526','P34185','P34149','P34203','P34158','P34176','P34221','P34419','P34248','P34257','P34239','P34311','P34266','P34320','P34275','P34284','P34293','P34302','P34329','P34338','P34347','P34356','P34365','P34374','P34383','P34392','P34401','P34482','P34410','P34428','P34437','P34446','P34464','P34455','P34473','P34534','P34491','P34500','P34509','P34518','P34543'},['on research field']='P34100',['analysis aspect']='P34101',['Has assay method']={'P34216','P34144','P34538','P34297','P34162','P34171','P34225','P34189','P34153','P34207','P34180','P34198','P34522','P34234','P34414','P34243','P34261','P34252','P34270','P34279','P34288','P34306','P34315','P34324','P34333','P34351','P34342','P34360','P34369','P34378','P34387','P34396','P34477','P34486','P34405','P34504','P34423','P34432','P34441','P34459','P34450','P34468','P34530','P34495','P34513'},['Has assay phase characteristic']={'P34217','P34145','P34539','P34163','P34172','P34226','P34154','P34190','P34208','P34181','P34199','P34415','P34244','P34235','P34262','P34253','P34271','P34289','P34280','P34298','P34307','P34316','P34325','P34334','P34343','P34352','P34361','P34370','P34379','P34388','P34397','P34478','P34487','P34406','P34424','P34433','P34442','P34460','P34451','P34469','P34496','P34505','P34514'},['Assay measurement type']={'P34204','P34150','P34141','P34267','P34276','P34294','P34213','P34159','P34186','P34222','P34177','P34168','P34519','P34535','P34195','P34411','P34240','P34249','P34231','P34258','P34303','P34312','P34339','P34285','P34366','P34321','P34375','P34330','P34348','P34357','P34384','P34393','P34465','P34474','P34483','P34402','P34447','P34420','P34438','P34429','P34456','P34527','P34492','P34501','P34510'},['has_doi']='P33028',[' has_venue']={'P33029','P33027'},[' HAS_RESULTS']={'P33031','P33032','P33033','P33034','P33035','P33030'},['Sub-hypothesis']='P33036',['Which species are compared?']='P33037',['Indicator for enemy release']='P33038',['Release of which kind of enemies?']='P33039',['Has lower limit for 95% onfidence interval ']={'P34104','P34105','P34106'},['AUROC']='P34116',['AUCPR']='P34117',['Measure of native biodiversity']='P33014',['Has Kaggle Competition']='P34102',['Transition in the invasion process']='P33012',['Observed proportion of species making the transition']='P33013',['Has visualization']='hasVisualization',['\"Format\"']='P33000',['Format']='P33001',['Has upper limit for 95% onfidence interval']='P34107',['Has lower limit for 95% confidence interval ']='P34109',['References']='P33004',['Has assay footprint']={'P34151','P34520','P34277','P34295','P34214','P34142','P34223','P34205','P34178','P34160','P34187','P34169','P34536','P34196','P34412','P34232','P34241','P34259','P34268','P34250','P34313','P34286','P34304','P34349','P34367','P34322','P34376','P34331','P34340','P34358','P34385','P34394','P34475','P34484','P34403','P34502','P34421','P34430','P34439','P34457','P34448','P34466','P34528','P34493','P34511'},['P32']={'P33005','P33007'},['Measure of resistance/susceptibility']='P33006',['Type of interaction']='P33008',['Type of effect description']='P33009',['Ecological Level of evidence']='P33010',['Outcome of interaction']='P33011',['Has ECS result']='P32124',['Has information processing paradigm']='P34099',['Features/improvement']='P33002',['Total Metadata entries']='P33003',['about species']='P34098',['R70803']='P34128',['R70805']='P34129',['Conducted by']='P15007',['Criteria defined by']='P15008',['Intended audience']='P15009',['Intended use']='P15010',['Introduce']='P20071',['R^2']='P34123',['R70821']='P34133',['R70823']='P34134',['DBMS']='P34136',['Content']='P34137',['Has web application']='P34138',['Query language']='P34139',['Results format']='P34140',['use']={'P20074','P18039','P20043','P20177'},['mask']='P20075',['replacing']='P20076',['replacement']='P20077',['involves']='P20078',['remove']='P20079',['sample']={'P20080','P46003'},['evaluate-on']='P20081',['follow']='P20082',['consists']='P20083',['Two sentence-level classification tasks']='P20084',[' Phenotypic plasticity form']={'P32109','P32110','P32111','P32112','P32113','P32114','P32115','P32116','P32064','P32065','P32066','P32067','P32068','P32069','P32070','P32071','P32072','P32073','P32074','P32075','P32076','P32077','P32078','P32079','P32080','P32081','P32082','P32083','P32084','P32085','P32086','P32087','P32088','P32089','P32090','P32091','P32092','P32093','P32094','P32095','P32096','P32097','P32098','P32099','P32100','P32101','P32102','P32103','P32104','P32105','P32106','P32107','P32108','P32019','P32020','P32021','P32022','P32023','P32024','P32025','P32026','P32027','P32028','P32029','P32030','P32031','P32032','P32033','P32034','P32035','P32036','P32037','P32038','P32039','P32040','P32041','P32042','P32043','P32044','P32045','P32046','P32047','P32048','P32054','P32061','P32049','P32050','P32051','P32052','P32053','P32055','P32056','P32057','P32058','P32059','P32060','P32062','P32063','P32000','P32003','P32004','P32005','P32006','P32007','P32008','P32009','P32010','P32011','P32012','P32013','P32014','P32015','P32016','P32017','P32018'},['Direct anthropogenic dist.?']='P32119',['PPV']='P34118',['Goodness of fit: Loss']='P34120',['Chi-Square']='P34121',['NDCG']='P34122',['Specific traits']='P32001',['Species name']='P32002',['Non-plant species ']={'P31017','P31018','P31019','P31020','P31021','P31022','P31007','P31008','P31009','P31010','P31011','P31012','P31013','P31014','P31015','P31016','P31003'},['Investigated species']='P31023',['Number of species']='P31024',['Performance:Specificity']='P34113',['Performance:NPV']='P34114',['Has participating device']='P30006',['Has participating person']='P30007',['Has gaseous sample input']='P30008',['Has solution sample input']='P30009',['Has solid sample input']='P30010',['Has radiant energy input']='P30011',['Has output']='P30012',['Has component type']='P30013',['Has specified volume']='P30014',['Has specified mass']='P30015',['pH']={'P30016','P44006'},['Wavelength of maximum absorption']='P30019',['Duration of absorption process']='P30020',['Half time for charge recombination (t1/2)']='P30021',['Related Comparisons']='P30023',['R63786']='P33141',['R63788']='P33142',['has params']='P30024',['uses pipeline']='P30025',['appraoch']='P31000',['Konzepte der Jugendarbeit']='P34057',['Number of concepts']='P34060',['Text coverage']='P34061',['Doppeltes Mandat der Jugendarbeit']='P34058',['Measure of invasion success']='P29012',['stand']='P29010',['has_method']='P33025',['has_value']='P33026',['The size of data that is being considered for processing is probably the most important factor. If the data can fit into the system memory, then clusters are usually not required and the entire data can be processed on a single machine. The platforms such as GPU, Multicore CPUs etc. can be used to speed up the data processing in this case. If the data does not fit into the system memory, then one has to look at other cluster options such as Hadoop, Spark etc. Again, Hadoop and Spark clusters can handle large amount of data but Hadoop has well developed tools and frameworks although it is slower for iterative tasks. The user has to decide if he needs to use off-the-shelf tools which are available for Hadoop or if he wants to optimize the cluster performance in which case Spark is more appropriate']='P33022',['testun']='P33023',['Relevance']='P33024',['R59759']='P33063',['R59761']='P33064',['R59763']='P33065',['R59765']='P33066',['Data size supported ']='P33155',['deleted']={'P29015','P20154','P29014','P28004'},['R51465']='P29016',['R51467']='P29017',['R51469']='P29018',['R51471']='P29019',['R51473']='P29020',['R51475']='P29021',['R51477']='P29022',['R51479']='P29023',['R51481']='P29024',['paper:DOI']='P33040',['R51509']='P29034',['R51511']='P29035',['R51513']='P29036',['R51515']='P29037',['R51491']='P29026',['R51493']='P29027',['R51495']='P29028',['R51497']='P29029',['R51499']='P29030',['R51501']='P29031',['R51503']='P29032',['R51505']='P29033',['R51517']='P29038',['R51519']='P29039',['R51521']='P29040',['R51523']='P29041',['R51527']='P29042',['R51529']='P29043',['R51531']='P29044',['R51533']='P29045',['R51535']='P29046',['R51537']='P29047',['R51539']='P29048',['R51541']='P29049',['Produced by']='P30005',['New data sources']='P33015',['Data Access']='P33017',['has_host']='P34014',['state of host plant tissue at moment of consumption']='P34017',['contains']={'contains','P18041','wikidata:P4330'},['has patient']='P15000',['related to']='P15001',['Compares']='P18091',['has GenBank accession number']='P15002',['Implemented into car mock-up']='P15013',['Ontologies']='P15035',['Inputs/Outputs']='P15036',['Pre/Post-conditions']='P15037',['Protocols']='P15038',['QoS']='P15039',['Specification Languages']='P15040',['Matching Result Degrees']='P15041',['Incomplete Knowledge']='P15042',['Variational Scope']='P15043',['Heuristics & Simplif.']='P15044',['Calculation Concepts']='P15045',['Nature of Traceability']='P15046',['Automation']='P15047',['Tool-Support']='P15048',['Year of Development']='P15049',['Area of use']='P15050',['Objective']={'P15051','P67098'},['Accuracy/Results']='P15052',['Future work/challenges']='P15053',['Artefacts']='P15054',['Mechanisms providing feedback']='P15055',['Information sources']='P15056',['Benefits']='P15057',['Types of feedback']='P15058',['Category']={'P15059','P96002'},['Highlights']='P15060',['Technology Bases']='P15061',['Game Genres']='P15062',['Major Contributions']='P15063',['Has vocabulary']='P15296',['Gramatically augmented ontology The results were quite promising, as the ontology contributed to improvements in the analysis of signs and in the generation of Ukrainian natural language']='P15297',['esearch Method']='P15064',['Agile Method']='P15065',['Focus']='P15066',['Publication type']='P15067',['Research Method']='P15068',['# of Subjects']='P15069',['Studied Picking System']='P15070',['System']={'P15071','P59005'},['Year']={'P15072','P37543'},['Vis. Types']='P15073',['Recomm.']='P15074',['Incr.']='P15075',['App. Type']='P15076',['File Size']='P15077',['Avg. size of transactions']='P15078',['Avg. size of itemsets']='P15079',['Threshold']='P15080',['Time(sec)']='P15081',['Memory Usage']='P15082',['catalysts']='P15083',['feedgas composition']='P15084',['T (°C)']='P15085',['P (MPa)']='P15086',['conv (%)']='P15087',['selectivity (%)']='P15088',['SV (ml·g −1·h−1cat)']='P15089',['substrate']='P15090',['catalyst']='P15091',['Analyte']='P15092',['Application']='P15093',['Sensitivitya']='P15094',['Detection limit']='P15095',['Experimental Dataset']='P15096',['Groundtruth Speci cation']='P15097',['Performance Results']='P15098',['Error Analysis']='P15099',['Comparative Evaluation']='P15100',['Key Idea']='P15101',['Physical Layout Representation']='P15102',['Logical Structure Representation']='P15103',['Output Representation']='P15104',['Logical Labels']='P15105',['Application Domain']='P15106',['Material linearity - Adhesive - Linear']='P15107',['Material linearity - Adhesive - Nonlinear']='P15108',['Material linearity - Adherend - Linear']='P15109',['Material linearity - Adherend - nonlinear']='P15110',['Adherends - Isotropic']='P15111',['Adherends - Composite']='P15112',['Adherends - Similar']='P15113',['Adherends - Dissimilar - Thickness']='P15114',['Adherends - Dissimilar -Material']='P15115',['Adhesive stresses - sx']='P15116',['Adhesive stresses - sy']='P15117',['Adhesive stresses - txy']='P15118',['Solution - Closed-form']='P15119',['Solution - Numerical']='P15120',['Place of experiment']='P15121',['Population']='P15122',['Procedure']='P15123',['data analysis']='P15124',['Concluding remarks']='P15125',['Comments']='P15126',['Governmnt regulation']='P15127',['Illegal activities']='P15128',['National statistics (GNP)']='P15129',['Labor market or status of labor (unregul., no soc. benef., work condit., etc.)']='P15130',['Tax evas. or unreport. income']='P15131',['Activity’s size (small scale of operat.)']='P15132',['Professional status (self-empl. Or family-based)']='P15133',['Activity’s regulation or registration']='P15134',['Networks']='P15135',['Autonomy and flexibility']='P15136',['Survival']='P15137',['Political (legal aspects) Governmnt regulation']='P15138',['Criteria Economic Activity’s size (small scale of operat.)']='P15139',['Social Autonomy and flexibility']='P15140',['Demand']='P15141',['Topology']='P15142',['outing']='P15143',['Inventory']='P15144',['Fleet composition']='P15145',['Fleet size']='P15146',['Inventory fleet']='P15147',['Composition']='P15148',['Products']='P15149',['Routing aspects']='P15150',['Inventory management aspects']='P15151',['Sources']={'P15152','P65071'},['Chitosanase family']='P15153',['Applications']='P15154',['Protocol']='P15155',['Innovation']='P15156',['Cluster count']='P15157',['Inter-cluster topology']='P15158',['CH election']='P15159',['Mobility']='P15160',['Location awareness']='P15161',['Load balancing']='P15162',['Node type']='P15163',['Nature']='P15164',['Cluster Properties Cluster size']='P15165',['Intra com.']='P15166',['Inter com.']='P15167',['CH Properties Mobility']='P15168',['ole']='P15169',['Objectives']='P15170',['Clustering Process CH Election']='P15171',['Alg. Complexity']='P15172',['Dynamism']='P15173',['CH Properties Mobility Node type']='P15174',['Column']='P15175',['Industry']='P15176',['Technical infrastructure']='P15177',['System integration']='P15178',['Data processing']='P15179',['Activation method']='P15180',['Group that reacts (with activated matrix)']='P15181',['Polymer']='P15182',['Group hat reacts']='P15183',['eagent']='P15184',['Activated group produced']='P15185',['Group that reacts (with activated matrix)']='P15186',['Sample Period']='P15187',['Nominal or real exchange rate used']='P15188',['Countries and Estimation technique used']='P15189',['Main Result']='P15190',['Name']={'P15191','P37605'},['System model']='P15192',['Control model']='P15193',['Fault tolerance']='P15194',['Simulator']='P15195',['Linux']='P15196',['Windows']='P15197',['Standards and technologies used']='P15198',['Open source']='P15199',['Behavior coordination']='P15200',['Real time']='P15201',['Distributed environment']='P15202',['Dynamic wiring']='P15203',['Security']='P15204',['Elements']='P15205',['Authors']='P15206',['Date']='P15207',['Steel Grade']='P15208',['Special Notes']='P15209',['Configuration of system']='P15210',['Control approach']='P15211',['Operating conditions']='P15212',['Undershoot [pu] 1 Δf1']='P15213',['Undershoot [pu] 2 Δf2']='P15214',['Column2 ΔPtie']='P15215',['Settling time (s) 1 Δf1']='P15216',['Settling time (s) 2 Δf2']='P15217',['Column3 ΔPtie']='P15218',['Controller design']='P15219',['Control structure']='P15220',['│ACE1│ Avg [pu]']='P15221',['│ACE2│ Avg [pu]']='P15222',['│ACE3│ Avg [pu]']='P15223',['Undershoot [pu] Δf']='P15224',['Δf2']='P15225',['Δf3']='P15226',['Undershoot [pu] 3 ΔPtie']='P15227',['Settling time (s) 3 ΔPtie']='P15228',['Correlation']='P15229',['Performance indicator (in per-capita terms if not otherwise indicated)']='P15230',['Aggregation level']='P15231',['Time perspective (CS = cross-section, L = longitudinal)']='P15232',['Age indicators']='P15233',['Age–performance patternc,d OLS / ordinary least square regression']='P15234',['FE / controlled for omitted variables by inclusion of fixed effects']='P15235',['IV / instrumental variable approach']='P15236',['Countries']='P15237',['Period']='P15238',['Methodology']='P15239',['Conclusion (s) EC-Y (from energy consumption to economic growth )']='P15240',['Y-EC (from ecnomic grwth to energy consumption )']='P15241',['Y2EC (feedback hypothesis )']='P15242',['YaEC neutral hypothesis between energy consumption and economic growth )']='P15243',['Conclusion (s) ELC-Y (electricty consumption to economic growth )']='P15244',['Y-ELC (from ecnomic grwth to electricty consumption )']='P15245',['Y2E (feedback hypothesis )']='P15246',['YaELC (neutral hypothesis between electricty consumption and economic growth)']='P15247',['No.']='P15248',['Country']='P15249',['Conclusion (s) NE-Y(nuclear energy consumption to economic growth )']='P15250',['Y-NE (from ecnomic grwth to nuclear energy consumption )']='P15251',['Y2NE (feedback hypothesis )']='P15252',['YaNE (neutral hypothesis between nuclear energy consumption and economic growth  )']='P15253',['Conclusion (s) NE-Y (from nuclear energy consumption to economic growth)']='P15254',['Educational context']='P15255',['Evaluator']='P15256',['Result']='P15257',['Topic']='P15258',['Taxonomy stage: Step']='P15259',['Computational platform']='P15260',['Age (years)']='P15261',['Sex']='P15262',['Chief Clinical presentation']='P15263',['Size (mm)']='P15264',['Follow up (months)']='P15265',['Container flow']='P15266',['oute']='P15267',['Market']='P15268',['emarkable factor']='P15269',['Inventory policy']='P15270',['Main question']='P15271',['Testing profile']='P15272',['Measurements']='P15273',['Cooling']='P15274',['Temperature swing and Tm ax']='P15275',['Failures and indicators']='P15276',['Failure mechanism']='P15277',['Circuit']='P15278',['Age']='P15279',['Site']='P15280',['Size (cm)']='P15281',['Weight (g)']='P15282',['Symptoms and signs']='P15283',['Laboratory fi ndings']='P15284',['Surgery']='P15285',['RT/Neoadjuvant or adjuvant CT']='P15286',['Recurrence']='P15287',['Treatment of recurrence']='P15288',['Follow-up']='P15289',['Has resource']='P15295',['Number of Objectives']='P15290',['Algorithm(s)']='P15291',['Tool']={'P15292','Tool'},['Quality Indicators']='P15293',['Has ressource']='P15294',['Tools']='P15298',['Some of the simulation model characteristics']='P15299',['Performance measures']='P15300',['Author’s conclusions']='P15301',['AMHS configuration']='P15302',['Strategy']='P15303',['Objective function(s)']='P15304',['Application area studied']='P15305',['Type of question asked']='P15306',['esearch method & question set']='P15307',['Subjects']='P15308',['Confidentiality (Privacy) Technique']='P15366',['Institutioans']='P27054',['Publications']='P27055',['# convolutional layer']='P15309',['# fully connected layer, # features']='P15310',['3D model']={'P15311','wikidata:P4896'},['Cascaded method']='P15312',['Databases']='P15313',['Video (v)/image (i)']='P15314',['Gray (g)/color (c)']='P15315',['Amount of data']='P15316',['Variations']='P15317',['Number of landmark points']='P15318',['# points']='P15319',['fps']='P15320',['start period (gg/mm/aaaa)']='P22058',['end period (gg/mm/aaaa)']='P22059',['Detection (d) or tracking (t)']='P15321',['Realtime (y) or not (n)']='P15322',['Source code (sc) or binary code (bc)']='P15323',['Number of points']='P15324',['Links']='P15325',['Normalized error']='P15326',['Coverage']='P15327',['Country zone']='P15328',['Types of literature reviews']='P15329',['Paper']={'P15330','P83016'},['Journals/ (papers)']='P15331',['Events/ (papers)']='P15332',['Other sources/ (papers)']='P15333',['Foci']='P15334',['Factor']={'P15335','P52037'},['Papers']='P15336',['Publication type Period']='P15337',['Papers Foci']='P15338',['Types of literature Publication reviews type']='P15339',['Context']='P15340',['Power of income']='P15341',['Type of data']='P15342',['Shape of EKC']='P15343',['EKC Turnaround point(s)']='P15344',['EKC Turnaround point(s) 2']='P15345',['Tailoring feedback']='P15346',['inter- human interaction']='P15347',['user targeting']='P15348',['adaptation']='P15349',['goal setting']='P15350',['context awareness']='P15351',['self learning']='P15352',['Building']='P15353',['Building Methodology']='P15354',['Key findings']='P15355',['Sr. No']='P15356',['Techniques']='P15357',['Developer']='P15358',['Advantage']='P15359',['Disadvantage']='P15360',['Authenticity Technique']='P15361',['Sybil Attacks']='P15362',['Node Imper’']='P15363',['Sending False Info’']='P15364',['ID Disc’']='P15365',['Non-repudiation Technique']='P15367',['Availability Technique']='P15368',['Integrity Technique']='P15369',['Challenges']='P15370',['#Test']='P15371',['Accuracy (%) deyeo0:']='P15372',['deyeo0:']='P15373',['Time (s)']='P15374',['n']='P15375',['Aim of the study']='P15376',['Study population']='P15377',['eferred index']='P15378',['efered index']='P15379',['Disaster phase Pre-disaster']='P15380',['Post-disaster']='P15381',['Application case Earthquake']='P15382',['Hurricane']='P15383',['Flood']='P15384',['Objectives First-stage']='P15385',['Second-stage']='P15386',['Decisions First-stage']='P15387',['Second-stage2']='P15388',['Uncertainty on the first-stage']='P15389',['Special features']='P15390',['Problematic assumptions']='P15391',['Uncertainty in the first-stage']='P15392',['Features']='P15393',['Problematic assumption']='P15394',['Solution method']='P15395',['Solution Exact']='P15396',['Non-exact']='P15397',['Problem-tailored heuristic']='P15398',['Metaheuristic']='P15399',['Matheuristic']='P15400',['Motivation']='P15401',['Spatial structure/population heterogeneity']='P15402',['Population structure']='P15403',['Population size']='P15404',['Recombination Within island']='P15405',['Migration']='P15406',['Aging']='P15407',['Self-adaptation']='P15408',['Important implementation parameters / factors']='P15409',['Other facts']='P15410',['Definition']='P15411',['Middle-income range: thresholds']='P15412',['Database']='P15413',['Time period']='P15414',['Number of MIT countries']='P15415',['egions most affected by the MIT']='P15416',['Method/Technique(s)/ Database']='P15417',['Result/ Accuracy']='P15418',['Conclusion']='P15419',['Future scope']='P15420',['Types']='P15421',['Objective/estimate(s) process systems']='P15422',['Systems applied']='P15423',['Positive highlights']='P15424',['Ranker']='P15425',['Computational complexity']='P15426',['Density']='P15427',['Diversity']='P15428',['Close to boundary']='P15429',['Far from boundary']='P15430',['Probabilistic/ uncertainty of ranker']='P15431',['Myopic']='P15432',['Quality attribute']='P15433',['Abs. Factory']='P15434',['Builder']='P15435',['Factory Method']='P15436',['Prototype']='P15437',['Singleton']='P15438',['Adapter']='P15439',['Bridge']='P15440',['Composite']='P15441',['Decorator']='P15442',['Facade']='P15443',['Flyweight']='P15444',['Proxy']='P15445',['Chain of Resp.']='P15446',['Command']='P15447',['Interpreter']='P15448',['Iterator']='P15449',['Mediator']='P15450',['Memento']='P15451',['Observer']='P15452',['State']='P15453',['Template']='P15454',['Visitor']='P15455',['Samples']='P15456',['No. of samples']='P15457',['C. jejuni (%)']='P15458',['C. coli (%)']='P15459',['Others (%)']='P15460',['Sp']='P15461',['Comparison']='P15462',['HPLC global']='P15463',['CHG']='P15464',['CG']='P15465',['Global']='P15466',['Others']='P15467',['Gasifiers']='P15468',['Cost']='P15469',['Reported capacity(MWth)']='P15470',['Year data']='P15471',['Cost V2012 (400 MWth)']='P15472',['Scale factor']='P15473',['Reported cost']='P15474',['Reported capacity (bbl/d)']='P15475',['Reported capacity (MWth fuel)']='P15476',['Cost V2012 (150 MW unit)']='P15477',['Plant type']='P15478',['ISBL cost (MV)']='P15479',['Total capital investment (MV)']='P15480',['Published cost (V/GJ LHV)']='P15481',['Updated cost (V 2012/ GJ LHV)']='P15482',['Capacity (MWth)']='P15483',['Plant cost (MV)']='P15484',['Plant cost (MV 2012)']='P15485',['Plant cost (400 MW MV 2012)']='P15486',['Diesel (V/l']='P15487',['Diesel 400 MW (V2012/l)']='P15488',['Plant cost (M$)']='P15489',['Plant cost (M$ 2012)']='P15490',['Plant cost (1000 t/h MV 2012)']='P15491',['BEOP ($/barrel)']='P15492',['BEOP (V2012/barrel averaged coal price)']='P15493',['Diesel (V2012/l)']='P15494',['Supervised / unsupervised']='P15495',['Dependency on the underlying models']='P15496',['Assumption of data availability']='P15497',['Computational cost']='P15498',['Criterion A']='P15499',['Resources and their constraints']='P15500',['job complexity and routing flexibility']='P15501',['Sequencing']='P15502',['Mono/multi']='P15503',['Pure/hybrid']='P15504',['Country / Plant part CS']='P15505',['Collection site']='P15506',['Plant material status']='P15507',['Isolation Procedure']='P15508',['Oil yield']='P15509',['Main components (P5%)']='P15510',['Measurement type']='P15511',['Country of study']='P15512',['Data and sample size']='P15513',['Population under analysis']='P15514',['Data collec- tion']='P15515',['Over-educa- tion incidence (percentages)']='P15516',['Satellite sensor']='P15517',['Band']='P15518',['Image resolution [m] PAN MS']='P15519',['Min. size [m]']='P15520',['Methods of vessel candidate detection']='P15521',['Methods of discrimination/ classification']='P15522',['Eval. of results']='P15523',['Main purpose']='P15524',['No']='P15525',['political incentives (POLIN) - political competition']='P15526',['political incentives (POLIN) voter participation']='P15527',['political incentives (POLIN) - legislative power']='P15528',['political incentives (POLIN) - interest group competition']='P15529',['political incentives (POLIN) - government size']='P15530',['social incentives (SOCIN) - public media']='P15531',['social incentives (SOCIN) - interparty competition']='P15532',['social incentives (SOCIN) - activity']='P15533',['social incentives (SOCIN) - voter wealth']='P15534',['social incentives (SOCIN) - regional culture']='P15535',['social incentives (SOCIN) - internet access']='P15536',['social incentives (SOCIN) - voter demographic']='P15537',['financial incentives (FININ) - reliance on debt']='P15538',['financial incentives (FININ) - government wealth']='P15539',['financial incentives (FININ) - reliance on federal']='P15540',['institutional incentives (INSIN) - professionalism']='P15541',['institutional incentives (INSIN) - population size']='P15542',['institutional incentives (INSIN) - staff demographic']='P15543',['institutional incentives (INSIN) - government type']='P15544',['institutional incentives (INSIN) - staff selection']='P15545',['institutional incentives (INSIN) - IT sophistication']='P15546',['governance incentives (GOVIN) - governance power']='P15547',['governance incentives (GOVIN) - accounting quality']='P15548',['governance incentives (GOVIN) - system endorsement']='P15549',['governance incentives (GOVIN) - audit quality']='P15550',['governance incentives (GOVIN) - code of ethics']='P15551',['governance incentives (GOVIN) - disclosure regulation']='P15552',['Variables']={'P15553','P44034'},['Gender (men/women)']='P15554',['Mean age (years)']='P15555',['Pathology/diagnosis']='P15556',['Corticosteroit treatment - Corticosteroid (n)']='P15557',['Corticosteroit treatment - Noncorticosteroid (n)']='P15558',['Anastomotic leakage (AL) - Total AL (n)']='P15559',['Anastomotic leakage (AL) - corticosteroid (n)']='P15560',['Anastomotic leakage (AL) - noncorticosteroid (n)']='P15561',['Statistical analysis OR']='P15562',['95% CI']='P15563',['Type of anastomosis - Ileoileal']='P15564',['Type of anastomosis -Ileocolic']='P15565',['Type of anastomosis - Ileorectal']='P15566',['Type of anastomosis - Colorectal']='P15567',['Type of anastomosis - Colocolic']='P15568',['Type of anastomosis - Ileal pouch']='P15569',['Type of anastomosis - anal (IPAA)']='P15570',['Type of anastomosis -Handsewn']='P15571',['Type of anastomosis - Stapled']='P15572',['Surgery - Elective']='P15573',['Surgery - Emergency']='P15574',['Surgery - Right-sided colectomy']='P15575',['Surgery - Left-sided colectomy']='P15576',['Surgery - Anterior resection']='P15577',['Surgery - Colectomy']='P15578',['Surgery - Segmental']='P15579',['Product']={'P15580','P43149'},['Compound']='P15581',['Indication']='P15582',['Conc. (%)']='P15583',['Disease']='P15584',['Number of patients studied']='P15585',['N (%) with abnormal karyotype']='P15586',['N (% abnormal) with abnormal chromosome']='P15587',['N (% abnormal) with abnormal chromosome 1']='P15588',['N (%) with 2 isolated abnormalities']='P15589',['Type of abnormalities']='P15590',['SCM field']='P15591',['Critical success factors']='P15592',['Chronologic age in months']='P15593',['duration of the study in years']='P15594',['Cognitive tests Findings']='P15595',['Number of examinees']='P15596',['Chronologic age in months at the beginning of the study']='P15597',['Cognitive tests']='P15598',['Findings']='P15599',['The number of examinees']='P15600',['ADALINE/ Widrow- Hoff']='P15601',['Backpropagation']='P15602',['Perceptron']='P15603',['Radial Basis Function']='P15604',['Hopfield']='P15605',['Platform']='P15606',['Vendor']='P15607',['Comment']='P15608',['Fields']='P15609',['Artifacts']='P15610',['Invisibility']='P15611',['Payload Capacity']='P15612',['Robustness against statistical attacks']='P15613',['Tolerance to RS Steganalysis']='P15614',['Robustness against image manipulation']='P15615',['LSBreplacement style asymmetry']='P15616',['Utilization of edge areas']='P15617',['Species Order']='P15618',['Seawater']='P15619',['Analytical method']='P15620',['Freshwater']='P15621',['Brackish water']='P15622',['Follow-up time/ total observation time after MON n M/F']='P15623',['Patients']='P15624',['MS development']='P15625',['% who develop MS from MON (%)']='P15626',['Diagnostic criteria for MS (CDMS)']='P15627',['Method to detect OCBs']='P15628',['Odds ratio (95% CI)']='P15629',['Sensitivity (95% CI)']='P15630',['Specificity (95% CI)']='P15631',['[7]Region']='P15632',['Farmers']='P15633',['Total Social Welfare (million US dollar per year)']='P15634',['Social Welfare per adopted hectare (US dollars per hectare) []']='P15635',['Million adopted hectares (yearly averages) [adoption rate%]']='P15636',['Technology sellers']='P15637',['Consumer Welfare']='P15638',['Feasibility']='P15639',['Justification/ recommendation']='P15640',['inflammatory bowel disease']='P15641',['Intestinal operation']='P15642',['Recent in- hospital treatment/ operation']='P15643',['Recent antibiotic therapy']='P15644',['intermediate care unit/ Sepsis']='P15645',['Surgical procedure']='P15646',['Endoscopy']='P15647',['Treatment']={'P15648','P68101','P95004'},['Deceased']='P15649',['Property 1']='P136000',['Property 2']='P136001',['paper:provides_graph_view']='P136002',['Max. reduction']='P15650',['Speed of no reduction']='P15651',['Distance to microphone, m']='P15652',['Method/ Technique(s)/(Database)']='P15653',['Result/Accuracy']='P15654',['Future work']='P15655',['Activity']='P15656',['Functional Data specification']='P15657',['Variables (1)']='P15658',['Economies of Scale']='P15659',['Other Measurements']='P15660',['Functional specification']='P15661',['Scale economies evaluated  in the approximation point']='P15662',['Disclosures']='P15663',['Anonymistion approaches']='P15664',['Background information']='P15665',['Anonymistion algorithm/method']='P15666',['Definition of completeness']='P15667',['Measure of completeness']='P15668',['Data extraction tools']='P15669',['Reminder systems']='P15670',['Data repositories']='P15671',['For a single source only once']='P15672',['With a gold standard']='P15673',['Comparison between different tools, information systems or data task']='P15674',['Comparison among healthcare institutions']='P15675',['Before and after data quality intervention']='P15676',['During time intervals']='P15677',['Determinants']='P15678',['Name of Scheme']='P15679',['Parameters']='P15680',['Enviroment']='P15681',['Tools used for simulation']='P15682',['Tool Findings']='P15683',['First author']='P15684',['Type of test']='P15685',['Prevalence, %']='P15686',['Sample size (n)']='P15687',['Screening']='P15688',['Calculation of sample size']='P15689',['Species (developmental mode)']='P15690',['Body mass (g)']='P15691',['Egg mass (g)']='P15692',['Embryo assessment , presence only only']='P15693',['Embryo assessment, developmental stage stage']='P15694',['Incubation state/egg characteristic']='P15695',['Difference (% decrease) in shell thickness (egg region) in shell thickness (egg region)']='P15696',['test collection']='P15697',['Measure of species similarity']='P29011',['has location']='P15698',['Scalability']='P24002',['Time duration']='P30022',['has end']='P15700',['paper:published_in']='P18092',['study_date']='P18093',['reported_cases']='P18094',['Patents']='P27051',['Persons']='P27052',['upper limit']={'P15701','wikidata:P5448'},['lower limit']={'P15702','wikidata:P5447'},['has beginning']='P15699',['Cohesive energy density']='P18086',['Lower confidence limit']='P19000',['Estimated value']='P27031',['Instance Of Template']='InstanceOfTemplate',['Related Resource']='RelatedResource',['RDF dump']='P27043',['has annotated data']='P16000',['type 1']='P16001',['Type2']='P16002',['Type1']={'P16003','P16004'},['problem statement']='P28001',['Relation1']='P16005',['Relation2']='P16006',['Usage']='P16007',['Feature-Of']='P16008',['Conjunction']='P16009',['Part-Of']='P16010',['has mode of action']='P29009',['Hyponym-Of']='P16011',['Compare']='P16012',['Overall']='P16013',['Method automation']='P16014',['Supports reference extraction']='P16015',['Knowledge graph creation']='P16016',['Input format']='P16017',['Output format']='P16018',['User interface']='P16019',['Summary']='P16020',['has software']='P23031',['has amino acid change']='P23032',['For task']='P18078',['has URI']='P16021',['R0 estimates (average)']='P16022',['mean time interval between onset and hospital quarantine']='P16023',['mean incubation period']='P16024',['mean serial interval']='P16025',['study period name']='P16026',['common symptoms']='P16030',['Radiant energy']='P27058',['data collection tool']='P16027',['measurement condition 1']='P16028',['measurement condition 2']='P16029',['has roles']='P29025',['has sequencing method']='P20052',['mean of serial interval']='P16031',['standard deviation of serial interval']='P16032',['code']='P16033',['incubation SD']='P16034',['incubation period mean']='P16035',['scenario']='P16036',['dataset description']='P16037',['R0 estimated duration']='P17000',['data source']={'P17001','P112020'},['scenario 1']='P17002',['scenario 2']='P17003',['Rc estimates (average)']='P17004',['dataset alias name']='P17005',['dataset revision']='P17006',['method description']='P17007',['Related Figure']={'P20155','RelatedFigure'},['Examples']='P23007',['Supports']='P23009',['nari']='P23010',['tudy dat']='P23011',['Total (Symptomatic cases-67% of all infected cases)']='P23012',['Proportion of population (Symptomatic cases-67% of all infected cases)']='P23013',['Peak week for incidence (Symptomatic cases-67% of all infected cases)']='P23014',['Peak month for incidence (Symptomatic cases-67% of all infected cases)']='P23015',['Number of sick people on the worst day of the simulated year (Symptomatic cases-67% of all infected cases)']='P23016',['Infectious agent population']='P23107',['Basic reproducion number']='P23108',['Study design']='P23109',['Blinding of outcome assessment']='P23110',['Randomization']='P23111',['allocation concealment']='P23112',['Incomplete outcome   data']='P23113',['Selective reporting']='P23114',['other sources of bias']='P23115',['Disease definitions (characterization)']='P23116',['Study groups']='P23117',['hasInteractionwithMasterData']='P18003',['hasStakeholders']='P18004',['hasMasterDataRepresentation']='P18000',['hasMappingtoSource']='P18001',['hasDocumentation']='P18002',['ID']='P27060',['hasRepresentationMasterData']='P18005',['Data Size Support']='P24006',['Method']={'P18006','P27041','P34127','P34027','P34031','P34068','P34072','P35123','P36021','P45007','P44131','P41305','P37162','P37391','P37430','P37650','P51001','P54037','P55017','P110040'},['Has demo']='P18008',['has learning rate']='P18009',['has dropout']='P18010',['has hyperparameters']='P18011',['has activation function']='P18012',['has training epochs']='P18013',['has early stopping']='P18014',['has optimization']='P18015',['has comparisons']='P18017',['outperforms']='P18018',['has scaling parameter']='P18016',['Test']='P18019',['has test']='P18020',['has can communicate with']='P18088',['has Autonomy']='P18089',['Has way action performed on environment']='P18090',['construct']='P18030',['assign']='P18031',['update parameters']='P18032',['has countries']='P23006',['Uses metric']='P24010',['requirements']='P24014',['Training data']='P18021',['consists of']='P18023',['handles']='P18024',['represent']='P18025',['employ']='P18026',['Detects']='P18027',['treat']='P18028',['perform']={'P18029','P20132','P20167'},['Try']='P18033',['on task']='P18035',['On evaluation dataset']='P18036',['F1']='P18037',['evaluation 1']='P18034',['has Task']='P18038',['represented by']='P18040',['adopt']='P18042',['inputs of decoding layer']='P18043',['Has word embedding']='P18044',['Has lstm units in encoding layer']='P18045',['has lstm units in decoding layer']='P18046',['Has bias parameter alpha']='P18047',['accuracy']='P18048',['Bleu Score']='P18049',['mixture of']='P23067',['to']={'P23068','P23042'},['takes into account']='P23069',['optimize']='P23070',['higher NER and RC scores']='P23071',['than']='P23072',['higher EC and RC scores']='P23073',['on']={'P23074','P23084','P20119','P20031','P20048','P20186','P23036'},['provide']='P23075',['train']={'P23076','P20112'},['find']='P23077',['slightly better']='P23078',['has sequencing type']='P20051',['PubChem AID']='P18050',['Protein Target']='P18051',['status']='P18052',['Modiy Date']='P18053',['Deposit Date']='P18054',['has confirmatory assay']='P18056',['has assay format']='P18057',['Has participant']='P18058',['has role']='P18059',['is bioassay type of']='P18060',['has assay method']='P18061',['has detection method']='P18062',['has assay title']='P18063',['has temperature value']='P18064',['has incubation time value']='P18065',['has assay phase characteristic']='P18066',['has measured entity']='P18067',['has endpoint']='P18068',['has concentration unit']='P18069',['Has detection instrument']='P18070',['Data calculated with model']='P32120',['Global and annual mean surface air temperature']='P32121',['Pulse duration']='P27044',['Energy']={'P27045','P41277'},['Reviews method']='P25068',['Has']='P18071',['paper:puplication_year']='P30000',['hypothesis']={'P30001','P95001'},['stand of hypothesis']='P30002',['number of plant species']='P30003',['status ']='P18072',['Test group size']='P18073',['according to external source (not stated in paper)']='P20190',['hasGenBank accession number']='P20191',['has nucleotide substitution']='P20192',['compared to']='P20193',['has NCBI Reference Sequence accession number']='P20194',['Type']='P23139',['Inter-code agreement']='P18074',['annotated abstracts']='P18076',['Domains']='P18077',['inter-coder agreement']='P18075',['tune']='P23051',['Size of Word Embeddings']='P23052',['Number of Heads']='P23053',['patient characteristics']='P23151',['Q']='P18083',['C']='P18084',['Chemical formula']='P18082',['Role']='P30017',['Particle size range']='P30018',['Image']='Image',['N   ']='P23169',['Clients   ']='P23170',['Setting   ']='P23171',['Intervention (protocol)  ']='P23172',['Design   ']='P23173',['Primary outcomes   ']='P23174',['Qualitative findings   ']='P23175',['Journals']='P27050',['Conferences']='P27053',['API support']='P27047',['R0_estimates_(average)']='P20053',['Estimated infectious period']='P20054',['Estimated mean latent']='P20055',['Estimated removed rate']='P20056',['Initial ratio of isolating susceptible individuals']='P20057',['Swelling coefficient']='P18085',['Authors recommend']='P25069',['cleaning algorithm']='P23029',['Uses dataset']='P18087',['Radiant exposure']='P27059',['Global Mean Sea level Rise Projection']='P26002',['has likely range']='P26003',['estimated_cases']='P18095',['Topics']='P27056',['has categories']='P18096',['organization']='P18097',['Measure of disturbance']='P32117',['Type of disturbance']='P32118',['climate scenario']='P26009',['Type of Laser']='P27035',['Wavelength (λex)']='P27036',['has part ']='P27000',['has part  ']='P27001',['necessity']='P18098',['Energy Device']='P27057',['text data format']='P18100',['data resources']='P18101',['has numerical value']='P23001',['paper:Study date']='P31001',['Measure of species relationship']='P31002',['Number of non-plant species']='P31004',['Habitat']='P31005',['WOS search or Cited references']='P31006',['processing level']='P18099',['subtasks']='P18102',['Platform type']='P24000',['with']={'P23079','P20044','P23037','P23066'},['to make']='P23080',['to remove']='P23081',['compare with']='P23082',['competitive sequence model']='P23083',['by']='P23085',['further outperforms']='P23086',['improves upon other dependency-based models']='P23087',['comparing C-GCN model with the GCN model']='P23088',['compared to the PA-LSTM']='P23089',['with-entity evaluation']='P23090',['incorporating off-path information']='P23091',['mask-entity evaluation']='P23092',['effect']='P23093',['when']='P23094',['when K = 1']='P23095',['outperforming']='P23096',['confirms our hypothesis']='P23097',['level']='P18103',['strength']='P18104',['subjectivity']='P18105',['develop']='P20105',['transforms']='P20106',['has basic components']='P20107',['are']='P20108',['composed of']='P20109',['consists of three types of layers']='P20110',['transform']='P20111',['integrate']='P20113',['has two tasks']='P20114',['introduces']='P20115',['surpasses']='P20116',['obtains']='P20117',['consider']='P20118',['for']={'P20120','P23038','P23060','P71210'},['Template Component Validation Rule']='TemplateComponentValidationRule',['Template Label Format']='TemplateLabelFormat',['TemplateStrict']='TemplateStrict',['TemplateComponentOrder']='TemplateComponentOrder',['TemplateComponentOccurrenceMin']='TemplateComponentOccurrenceMin',['TemplateComponentOccurrenceMax']='TemplateComponentOccurrenceMax',['Number']='P23104',['software for consensus sequence generation']='P22060',['Face features']='P25000',['Upper confidence limit']='P19001',['has study']='P19002',['Libraries']='P27002',['has model class']='P39023',['hasMetaVisualizationDefinition']='P30027',['Case fatality ratio (CFR)']='P20000',['Cumulative Incidence (CI)']='P20001',['Infection fatality ratio (IFR)']='P20002',['average estimated ratio between the actual number of individuals that have been infected and observed cases']='P20003',['data1 description']='P20004',['data1 source']='P20005',['data2 description']='P20006',['data2 source']='P20007',['data3 description']='P20008',['data3 source']='P20009',['study dates']='P20010',['Intrinsic growth rate']='P20013',['Scaling of growth parameter']='P20014',['Ascertainment Rate (q)']='P20011',['Number of confirmed cases']='P20012',['Number of deaths']='P20015',['Percentage of total cases']='P20016',['Research Infrastructure']='P27046',['Books']='P27048',['Chapters']='P27049',['compare contribution']='compareContribution',['has previous version']='hasPreviousVersion',['has subject']='hasSubject',['has content']='hasContent',['Located in']='P23105',['Exists at']='P23106',['Scaling Types']='P20017',['Research Questions']='P20018',['Reviews']='P23103',['Si precursor']='P20019',['contacting electrode']='P20020',['counter electrode']='P20021',['(pseudo)reference electrode']='P20022',['temperature']={'P20023','wikidata:P2076'},['process specification']='P20024',['total estimated cases']='P20025',['total confirmed cases']='P20026',['susceptible']='P20027',['infected']='P20028',['removed']='P20029',['achieves']='P20030',['learn']='P20032',['recognizes']='P20033',['framework']={'P20034','P62121'},['identify']='P20035',['apply']='P20036',['implement']='P20037',['consists of two modules']='P20038',['recognize']='P20039',['identifies']='P20040',['evaluate']='P20041',['evaluate on']='P20042',['used']={'P20046','P23039'},['conduct']='P20047',['explore']='P20049',['analyze']='P20050',['reagent']='P20058',['has kit']='P20059',['has study design']='P20060',['Symptomatic persons (with visits at high risk areas) or contacts of infected persons']='P20061',['number of persons tested']='P20062',['persons with viral genome sequencing ']='P20063',['open invitation']='P20064',['random sample']='P20065',['number of persons with viral genome sequenced']='P20066',['Virus names in GISAID']='P20067',['EPI accession numbers']='P20068',['number of sequence variants']='P20069',['GISAID URL']='P20070',['Three sentence-pair similarity tasks']='P20085',['Four natural language inference tasks']='P20086',['reimplemented']='P20087',['include']='P20088',['take']='P20089',['retain beta hyperparameters']='P20090',['has decoupled weight decay']='P20091',['keep']='P20092',['deviate from the optimization']='P20093',['uses a batch size']='P20094',['done on']='P20095',['took']='P20096',['Fine-tuning is implemented based on']='P20097',['has description']='P20098',['Per-Task Results']='P20099',['exceeds']='P20100',['improves considerably']='P20101',['substantially improves']='P20102',['yields smaller improvements']='P20103',['gains']='P20104',['Use']={'P20153','P20144'},['learning mappings']='P20121',['to learn a function']='P20122',['investigate']='P20123',['show']='P20124',['present']='P20125',['experiment with']='P20126',['added']='P20127',['Augment']='P20128',['Maxpooling']='P20129',['concatenate']='P20130',['concatenation']='P20131',['Transformer Architecture']='P20133',['Weight Initialization']='P20134',['Post Transformer Layer']='P20135',['Training Epochs']='P20136',['Learning Rate (supervised)']='P20137',['Batch Size (supervised)']='P20138',['Learning Rate (few shot)']='P20139',['Batch Size (few shot)']='P20140',['adding positional information in the input']='P20141',['Aim']='P20142',['determine']='P20143',['Learning rate']='P20145',['Batch size']='P20146',['Number of steps']='P20147',['Relation representation']='P20148',['increase']='P20149',['very significant']='P20150',['Report']='P20151',['initializing']='P20152',['Max sentence length']='P20157',['Adam learning rate']='P20158',['Number of epochs']='P20159',['Dropout rate']='P20160',['compare our method, R-BERT, against']='P20161',['beats']='P20162',['MACRO F1 value']='P20163',['create']='P20164',['discard']='P20165',['observe']='P20166',['demonstrates']='P20168',['repeatedly encodes']='P20170',['consisting of']='P20171',['via']='P20172',['to learn']='P20173',['Reuse']='P20174',['trained-on']='P20175',['after pre-training']='P20176',['rate']='P20178',['encodes']='P20179',['tokenize input text']='P20180',['creates']={'P20181','creates','P45095'},['iteratively merges']='P20182',['requires']='P20183',['add']='P20184',['bias']='P20185',['TACRED dataset']='P20187',['SemEval 2010 Task 8 dataset']='P20188',['establishing']='P20189',['Computational intelligence technologie']='P34115',['has dependent variable']='P27011',['Has independent variable']='P27012',['has company']='P21000',['has SARS-CoV-2 reference genome ']='P21001',['differs to the NC_045512 reference genome']='P21002',['pant presence or action']='P22000',['type of data for model development']='P22001',['ntry']='P22002',['limate zone (köppen-geiger)']='P22003',['intended ']='P22004',['type of building']='P22005',['n of months']='P22006',['predictors/devices']='P22007',['rule-based models: schedule/profile']='P22008',['rule-based models: other']='P22009',['stochastic opa models: general/generalized linear model ']='P22010',['stochastic opa models: generalized linear mixed models']='P22011',['stochastic opa models: linear mixed models']='P22012',['stochastic opa models: linear time series model']='P22013',['stochastic opa models: markov chain model']='P22014',['stochastic opa models: agent-based model']='P22015',['stochastic opa models: survival analysis']='P22016',['stochastic opa models: probit analysis ']='P22017',['stochastic opa models: gaussian process']='P22018',['stochastic opa models: bayesian network model']='P22019',['stochastic opa models: decision tree model']='P22020',['stochastic opa models: logit analysis']='P22021',['stochastic opa models: hierarchical clustering model']='P22022',['stochastic opa models: levy process']='P22023',['stochastic opa models: monte carlo method']='P22024',['stochastic opa models: poisson process']='P22025',['stochastic opa models: bernoulli process']='P22026',['stochastic opa models: hybrid model']='P22027',['stochastic opa models: entropic-probabilistic approach']='P22028',['stochastic opa models: other']='P22029',['data-driven models: agglomerative hierarchical clustering']='P22030',['data-driven models: random forest']='P22031',['data-driven models: support vector regression']='P22032',['data-driven models: support vector machine']='P22033',['data-driven models: gradient boosting ']='P22034',['data-driven models: regularized logistic regression']='P22035',['data-driven models: linear regression']='P22036',['data-driven models: decision tree']='P22037',['data-driven models: apriori']='P22038',['data-driven models: density estimation']='P22039',['data-driven models: k-means or k-medians']='P22040',['data-driven models: bootstrap aggregation']='P22041',['data-driven models: neural networks']='P22042',['data-driven models: multilayer perceptron']='P22043',['data-driven models: naive bayes ']='P22044',['data-driven models: nearest neighbour']='P22045',['data-driven models: gaussian mixture']='P22046',['data-driven models: hidden markov model']='P22047',['data-driven models: arma, arima, etc..']='P22048',['data-driven models: multi-layer perceptron']='P22049',['data-driven models: genetic algorithm']='P22050',['data-driven models: fuzzy logic']='P22051',['data-driven models: pedestrian dead reckoning']='P22052',['data-driven models: bayesian network model']='P22053',['optimization based on the defined objective function']='P22054',['data-driven models: other']='P22055',['ity']='P22056',['dimension of the sample (n. of rooms, buildings etc.)']='P22057',['Has upper limit for 95% confidence interval']='P34110',['have nucleotide differences']='P23000',['has qualifier']='P23002',['participants (of which viral agents were sequenced)']='P23003',['has international travel']='P23005',['has compnay']='P23004',['Used to']='P23008',['Proportion of population sick on the worst day (Symptomatic cases-67% of all infected cases)']='P23017',['Total (Consultations-40% of symptomatic cases seek consultations, possibly mainly telephone/internet)']='P23018',['Proportion of population (Consultations-40% of symptomatic cases seek consultations, possibly mainly telephone/internet)']='P23019',['Total (Severe cases likely to require hospitalisation-1.0% of symptomatic cases)']='P23020',['Proportion of population (Severe cases likely to require hospitalisation-1.0% of symptomatic cases)']='P23021',['Number of people in hospital on the worst day-if capacity existed (Severe cases likely to require hospitalisation-1.0% of symptomatic cases)']='P23022',['Proportion of population in hospital on the worst day (Severe cases likely to require hospitalisation-1.0% of symptomatic cases)']='P23023',['Total (Cases likely to require ICU-25% of hospitalised cases)']='P23024',['People in ICU on the peak day-if capacities exist (Cases likely to require ICU-25% of hospitalised cases)']='P23025',['Total (Cases likely to require ventilation in ICU-50% of those in ICU)']='P23026',['Total Deaths']='P23027',['Proportion of population (Deaths)']='P23028',['type of experiment']='P30004',['( > 2 % )']='P25046',['slightly outperforms']='P25047',['significantly outperforms']='P25034',['including']={'P25035','wikidata:P1012'},['in']='P25036',['to jointly model']='P25037',['that only use']='P25038',['indicates']='P25039',['matches']='P25040',['that use']='P25041',['Biography']='P23030',['pre-training and fine-tuning']='P23033',['initialize']='P23034',['pre-trained']='P23035',['pre-trained for']='P23040',['pre-trained on']='P23041',['outperformed']='P23043',['in terms of']='P23044',['RE results']='P23045',['QA results']='P23046',['obtained']='P23047',['significantly outperformed']='P23048',['of']={'P23049','wikidata:P642'},['achieved']='P23050',['Size of Hidden Layer']='P23054',['Size of Position Embeddings']='P23055',['Size of Attention Layer']='P23056',['Number of Latent Entity Types']='P23057',['Size of Mini-Batch']='P23058',['Initial Learning Rate']='P23059',['L2 Regularization Coefficient']='P23061',['F1-score']='P23063',['except']='P23064',['incorporate']='P23065',['Niobate']='P25009',['Co-Catalyst']='P25010',['Light Source']='P25011',['Sacrificial Reagent']='P25012',['H2 Formation Rate']='P25013',['indicating']='P23098',['contextualizing']='P23099',['makes it']='P23100',['removing']='P23102',['Has TCR result']='P32123',['has lower limit for likely range']='P26005',['has upper limit for likely range']='P26006',['Atmosphere Model Basic Approximations']='P26016',['has atmosphere model name']='P26018',['has results in atmosphere']='P26019',['Atmosphere model family']='P26020',['Has sea ice model name']='P26021',['Has results for sea ice']='P26022',['Has land surface model name']='P26023',['Has prognostic land surface model variable']='P26024',['has land surface model documentation']='P26025',['Has aerosol model documentation']='P26026',['Has aerosol model scheme']='P26027',['Has prognostic sea ice model variable']='P26028',['Has atmosphere model documentation']='P26029',['Has horizontal atmosphere model resolution']='P26030',['Has results in the ocean']='P26031',['Has prognostic atmosphere model variable']='P26032',['Dynamical core of atmosphere model ']='P26017',['Has ocean model version']='P26036',['Has sea ice model documentation']='P26037',['Has sea ice model version']='P26038',['Has horizontal atmosphere model descretisation']='P26039',['Land surface model basic approximations ']='P26040',['Ocean model basic approximations']='P26041',['Sea ice model basic approximations']='P26042',['AED evaluated']='P23118',['2nd AED']='P23119',['3rd AED']='P23120',['4th AED']='P23121',['No of cats']='P23122',['Period of treatment or follow-up (months)']='P23123',['Prevalence of adverse effects']='P23124',['95% CI of cases that developed adverse effects']='P23125',['Body system affected and adverse effects']='P23126',['Most common adverse effects']='P23127',['Adverse effect type']='P23128',['Age of cats at seizure onset (years)']='P23129',['Dose of AED(s) (mg/ kg)']='P23130',['Serum levels of AED(s)']='P23131',['Pre-treatment SF (seizures/ month or year)']='P23132',['Post- treatment SF (seizures/ month or year)']='P23133',['No of cats that were failures']='P23134',['No of cats with >0% - <50% reduction in SF']='P23135',['No of cats with ≥50% - <100% reduction in SF']='P23136',['No of cats with 100% reduction in SF']='P23137',['95% CI of successfully treated cases']='P23138',['Basic reproduction number']='P23140',['Atmospheric Chemistry Basic Approximations']='P26043',['has prognostic atmospheric chemistry variable']='P26044',['Has kernel function']='P26047',['Has cost factor']='P26048',['Has gamma']='P26046',['due to']='P23141',['number of papers']='P34059',['Confidence interval (95%)']='P23142',['Confidence interval']='P23145',['Range of values']='P23146',['Condition']='P23147',['Duration']='P23149',['Estimated cases']='P23143',['Reported cases']='P23144',['Data validity condition']='P23148',['Participants\' characteristics (of which viral agents were sequenced)']='P23150',['Language/domain']='P25060',['NEs found']='P25061',['Technique used']='P25062',['Dataset used']='P25063',['Evaluation results']='P25064',['Depressive disorder']='P23152',['Age mean (SD)']='P23153',['% Female']='P23154',['% White']='P23155',['Setting']='P23156',['Recruitment']='P23157',['Most distal followup']='P23158',['Depression outcomes (sources)']='P23159',['Quality']='P23160',['Data used']='P25059',['Semiconductor']='P25017',['H2 Rate']='P25018',['Has subfields']='P25065',['Gatherable information']='P25066',['Concept']='P25067',['Population/Procedure, Sample size']='P23161',['Intervention Group(s)']='P23162',['Interventionist ']='P23163',['Study design ']='P23164',['Construct ']='P23165',['Measurement, Rater ']='P23166',['Significant Results ']='P23167',['Nonsignificant Results ']='P23168',['Nb-Based Material']='P25019',['Main Products']='P25020',['Observed Rate']='P25021',['Communication Scheme']='P24001',['Data I/O Rate']='P24003',['C Statistic']='P34119',['Apache Hadoop']='P24004',['Real-time Processing']='P24005',['hasMetaVisualization']='P30026',['Iterative Task Support']='P24007',['Describes approach']='P24008',['Has definition']='P24009',['placed in']='P24011',['applicable in']='P24012',['transient absorption:trapped holes']='P24015',['transient absorption:trapped electrons']='P24016',['conditions']='P24017',['has goal']={'P24013','wikidata:P3712'},['performs']='P25025',['yielding']='P25026',['with the exception']='P25027',['Weaknesses']='P25001',['Problems']='P25002',['Solutions']='P25003',['Algorithm and Techniques']='P25004',['precursors']='P25007',['visible-light driven photocatalysis']='P25008',['chemical doping method']='P25005',['doping elements']='P25006',['Case fatality rate']='P25022',['out-performed by']='P25028',['obtain']='P25029',['When paired with']='P25030',['performs on par with']='P25031',['adding']='P25032',['improves']='P25033',['sets']='P25048',['by gaining']='P25049',['over']='P25050',['with respect to']='P25051',['got']='P25042',['among']='P25043',['more effective than']='P25044',['without using']='P25045',['Measure of propagule pressure']='P32122',['achieve']='P25052',['relies on']='P25053',['achieving']='P25054',['get']='P25055',['already outperforms']='P25056',['demonstrating the advantage of']='P25057',['achieves slightly better performance than']='P25058',['Total Cases']='P28008',['Answer']='P25070',['Has characteristics']='P25071',['Attributes']='P25072',['Retinal Dissease']='P25073',['Learning approach']='P25074',['Sub Problem']='subProblem',['data dource']='P26000',['total cases worldwide']='P26001',['Offer functions']='P33018',['Important aspects to consider']='P33021',['Data Storage']='P33016',['Developement']='P33019',['Recent Developement']='P33020',['PubChemAID']='P29005',['has assay footprint']='P29006',['assay measurement type']='P29007',['day']='P28002',['uses detection instrument']='P29008',['month']='P28003',['has base line']='P26004',['has  start of period']='P26007',['has end of period']='P26008',['Has prognostic ocean variable']='P26010',['has ocean result']='P26011',['Ocean model family']='P26012',['Ocean vertical physics']='P26013',['has horizontal ocean model resolution']='P26014',['Has ocean model documantation']='P26015',['Has atmosphere model version']='P26033',['Has ocean model name']='P26034',['Has horizontal ocean model discretisation']='P26035',['Translation']='P29000',['has C parameter']='P26045',['Estimated_cases_with']='P26049',['has layer']='P28005',['responsible for']='P28006',['Evacuation Strategies']='P27003',['section']='P27004',['Has hypothesis']='P29013',['Study category']='P27005',['Experimental details']='P27006',['Variables that resulted in significant effects']='P27007',['Statistics used']='P27008',['Variables that resulted in non-significant effects']='P27009',['Effect size']='P27010',['Has number of votes']='P27013',['Has participants']='P27014',['Has buildings']='P27015',['Has offices']='P27016',['Length']='P27017',['Days']='P27018',['Study type']='P27019',['Continent']='P27030',['Observed value']='P27032',['Type of buildings']='P27020',['Building systems']='P27021',['Study location']='P27022',['Number of offices']='P27026',['% of female']='P27023',['Number of participants']='P27024',['Number of buildings']='P27025',['HVAC type']='P27027',['Lighting type']='P27028',['Region of data collection']='P27029',['has Wikipedia description']='P28007',['has capabilities']='P29004',['Organism']='P27034',['Growth rate']='P27033',['R59704']='P33051',['R59706']='P33052',['R59708']='P33053',['R59710']='P33054',['R59712']='P33055',['R59714']='P33056',['R59716']='P33057',['R59718']='P33058',['R59720']='P33059',['R59722']='P33060',['R59724']='P33061',['R59726']='P33062',['R60079']='P33114',['R60081']='P33115',['R60083']='P33116',['R59767']='P33067',['R59769']='P33068',['R59771']='P33069',['R59773']='P33070',['R59775']='P33071',['R59777']='P33072',['R59779']='P33073',['R59781']='P33074',['R59839']='P33078',['R59841']='P33079',['R59843']='P33080',['R59845']='P33081',['R59847']='P33082',['R59849']='P33083',['R59851']='P33084',['R59853']='P33085',['R59855']='P33086',['R59857']='P33087',['R59859']='P33088',['R59861']='P33089',['R59922']='P33090',['R59924']='P33091',['R59926']='P33092',['R59928']='P33093',['R59930']='P33094',['R59932']='P33095',['R59934']='P33096',['R59936']='P33097',['R59938']='P33098',['R59940']='P33099',['R59942']='P33100',['R59944']='P33101',['R59996']='P33102',['R59998']='P33103',['R60000']='P33104',['R60002']='P33105',['R60004']='P33106',['R60006']='P33107',['R60008']='P33108',['R60010']='P33109',['R60012']='P33110',['R60014']='P33111',['R60016']='P33112',['R60018']='P33113',['R60085']='P33117',['R60087']='P33118',['R60089']='P33119',['R60091']='P33120',['R60093']='P33121',['R60095']='P33122',['R60097']='P33123',['R60099']='P33124',['R60101']='P33125',['R60103']='P33126',['R60105']='P33127',['R60107']='P33128',['R60172']='P33131',['R60174']='P33132',['R60176']='P33133',['R60178']='P33134',['R60180']='P33135',['R60182']='P33136',['R60184']='P33137',['R60186']='P33138',['R60188']='P33139',['R60190']='P33140',['R63790']='P33143',['R63792']='P33144',['R63794']='P33145',['R63796']='P33146',['R63798']='P33147',['R63800']='P33148',['R63802']='P33149',['R63804']='P33150',['R63806']='P33151',['R63808']='P33152',['Scaling type']='P33153',['Data I/O Performance']='P33154',['R70825']='P34135',['paper: authors']='P34006',['Stakeholders']='P34020',['Potentially useful techniques']='P34019',['R70807']='P34130',['R70809']='P34131',['R70811']='P34132',['Knowledge derived from']='P34003',['Foundation for integration of']='P34018',['Has trend']='P34001',['Becoming a requirement for']='P34002',['Important for']='P34004',['Reason']='P34005',['paper: research_field']='P34007',['tissue consumed by larvae']='P34016',['Create \"has_host\"']={'P34008','P34009','P34010','P34011','P34012','P34013'},['larval habit inside or outside of host']='P34015',['has target']='P34038',['Infection']='P34021',['CI Tech']='P34022',['has toxin']='P34037',['Gesellschaft zur Zeit der Konzeptentwicklung']='P34039',['Staatsform zur Zeit der Konzeptentwicklung']='P34040',['NPV']='P34023',['has lysine catabolic pathway type']={'P34032','P34033','P34034','P34035','P34036'},['Soziale Arbeit als Institution']='P34041',['gesellschaftliche Funktion Sozialer Arbeit']='P34042',['Auftraggeber']='P34043',['Funktion Sozialer Arbeit']='P34044',['Vergesellschaftungsprozess']='P34047',['Ressourcen']='P34048',['Definitionsmacht']='P34049',['Macht von - Macht über']='P34050',['Repräsentationsform']='P34051',['Lebenslage Adressat*innen']='P34052',['Lebenslage Sozialarbeiter*innen']='P34053',['angestrebte Macht der Adressat*innen']='P34054',['Ebene der Verhandlung']='P34055',['Bewegungshintergrund']='P34056',['Adressat*innen']='P34045',['Perspektive/Ziel Sozialer Arbeit']='P34046',['Concept types']='P34062',['Dataset name']='P34063',['number concepts']='P34064',['Payment Scheme']={'P34073','P34074'},['Knowledge Graph Type']='P34075',['Knowledge Graph Semantics']='P34076',['Knowledge Graph Selection']='P34077',['Reuse Of Knowledge Graph']='P34078',['Number Of Knowledge Graphs']='P34079',['Machine Learning Input']='P34080',['Machine Learning Method']='P34081',['Machine Learning Task']='P34082',['Machine Learning Model Integration']='P34083',['Explanation Form']='P34084',['Explanation Type']='P34085',['Explanation Interpretability']='P34086',['Performance:Precision']='P34111',['Performance:Sensitivity']='P34112',['RUIHUI MU']='P34096',['do not incorporate']='P34087',['above it']='P34088',['constructs and labels']='P34089',['To capture']='P34090',['have']='P34091',['used in']='P34092',['dimensions']='P34093',['updating']='P34094',['gradient clipping']='P34095',['has time unit']='P34554',['has assay control']='P34555',['has manufacturer']='P34556',['has assay kit']='P34557',['has concentration throughput']='P34558',['has organism']='P34559',['has repetition throughput']='P34560',['has assay readout content parametricity']='P34561',['has assay readout content']='P34562',['has cell line']='P34563',['has preparation method']='P34564',['DNA construct']='P34565',['has bioassay type']='P34566',['Sentence Classifier']='P35000',['has percent response']='P34567',['has response unit']='P34568',['has assay stage']='P34569',['compound library']='P34570',['has primary assay']='P34571',['involves biological process']='P34572',['has alternate target assay']='P34573',['has purity value']='P34574',['has assay serum']='P34575',['has inducer']='P34576',['has alternate assay conditions']='P34577',['has orthogonal assay technology']='P34578',['has compound toxicity assay']='P34579',['has orthogonal assay design']='P34580',['has physicochemical profiling assay']='P34581',['has variant construct assay']='P34582',['has alternate cell line assay']='P34583',['has lead optimization assay']='P34584',['has alternate assay format']='P34585',['primary cell']='P34586',['has temperature unit']='P34587',['has alternate confirmatory assay']='P34588',['Mapping to other identifiers']='P34593',['Metadata schema']='P34596',['Handles imbalanced sentences']='P35001',['Only Triples Extraction Performance']='P35019',['Details']='P34589',['HAS_VISUALIZATION_DEFINITION']='HAS_VISUALIZATION_DEFINITION',['Additional Component']='P35006',['Concepts']='P35093',['Has graphical user interface']='P35094',['MVC-Based technology']='P35024',['Entity type']='P34590',['Augments with silver-labeled test data']='P35002',['Scientific Terms and Relations Extraction']='P35003',['Category 1']='P35007',['Category 4']='P35011',['provides API']='P34591',['uses identifier system']='P34592',['Number of entities']='P34594',['Data dump']='P34595',['provided services']='P34597',['Is based on']='P35097',['Pipelined Triples Extraction Performance F-score']='P35033',['Semi-pipelined Triples Performance F-score']='P35029',['Used by']='P34598',['SOA Integration technology']='P35025',['has topic']='P35071',['Has purpose']='P35095',['Concentration']='P35036',['total_cochlear_length']='P35038',['Total_cochlear_area']='P35039',['Prox1_area']='P35040',['Sox2_area']='P35041',['Medial_to_lateral_area_ratio']='P35042',['OHC_count']='P35043',['End-to-end system performance']='P35014',['Only Phrase Extraction Performance']='P35015',['Only Phrases Extraction Performance']='P35016',['Semi-pipelined Triples']='P35017',['Semi-pipelined Triples Performance']='P35018',['hazard ratio']='P35004',['Category 5']='P35012',['Category 2']='P35008',['data proportion']='P35009',['Has ORKG Paper']='P35034',['Real time support']='P35026',['Heterogeneous Data Sources']='P35027',['Dynamic UI']='P35028',['Triples Extraction']='P35005',['Economy']='P35045',['Education']='P35046',['Environment and climate change']='P35047',['Finance']='P35048',['Governance']='P35049',['Health']='P35050',['Housing']='P35051',['Population and social conditions']='P35052',['Category 3']='P35010',['Author(s) ID']='P35074',['Source title']='P35075',['Volume']='P35076',['Issue']='P35077',['Category 6']='P35013',['Pipelined Phrases Extraction Performance']='P35020',['Pipelined Triples Extraction Performance']='P35021',['Only Phrases Extraction Performance %F-score']='P35022',['Only Phrases Extraction Performance F-score']='P35023',['Element of the City Model Canvas']='P35068',['Only Triples Extraction Performance F-score']='P35030',['End-to-end System Performance F-score']='P35031',['Pipelined Phrases Extraction Performance F-score']='P35032',['Team Name']='P35035',['Page start']='P35078',['Page end']='P35079',['Cited by']='P35080',['Author Keywords']='P35081',['Publication Stage']='P35082',['Open Access']='P35083',['EID']='P35084',['includes a concept']='P35070',['days_in_vitro']='P35037',['IHC_count']='P35044',['Art. No.']='P35086',['People']='P35067',['Index Keywords']='P35085',['Society and culture']='P35066',['visualizes information of']='P35069',['Recreation']='P35053',['Safty']='P35054',['Solid waste']='P35055',['Sport and culture']='P35056',['Telecommunication']='P35057',['Transportation']='P35058',['Urban/local agriculture and food security']='P35059',['Urban planning']='P35060',['Wastewater']='P35061',['Water']='P35062',['Planet']='P35063',['Prosperity']='P35064',['Number of indicators']='P35065',['Supports tasks']='P35096',['Page count']='P35087',['Has research method']='P35088',['Human values']='P35089',['Human values or emotions']='P35090',['Group 1 using ReqVidA']='P35141',['Group 2 using text editor']='P35142',['Electrode design']='P35149',['Lowest Electric field  (V/cm)']='P35150',['Provides funtionality']='P35098',['W-value']='P35129',['Has experimental procedure']='P35125',['is supported by']='P35099',['has research question']='P35101',['has dependent variables']='P35109',['has rewards']='P35112',['Statistical tests']='P35133',['has test results']='P35134',['has descriptive statistics']='P35135',['has answer to research question']='P35104',['has hypotheses']='P35105',['Treatments']='P35108',['Has information granularities']='P35170',['Group']='P35126',['Background']='P35127',['Inferential statistic results']='P35139',['Number of surveyed papers']='P35100',['has sample']='P35102',['has results']='P35103',['has subject selction methods']='P35111',['Tests']='P35115',['number of groups']='P35116',['Null hypothesis']='P35106',['Alternative hypothesis']='P35107',['has subject selection method']='P35110',['scale type']='P35113',['Significance level']='P35117',['Associated Data']='P35138',['Visitor effect']='P36017',['Normal distribution']='P35114',['Application field']='P35118',['U-value']='P35143',['Number of ontologies referenced']='P35119',['scientific papers mentionned describing the ontology']='P35120',['Sentences Extraction Performance F-score']='P35137',['Shapiro-Wilk results']='P35128',['is significant']='P35130',['Interpretation']='P35131',['t-value']='P35132',['Descriptive statistic results']='P35140',['has section']='HasSection',['has link']='HasLink',['HQS']='P35136',['Baseline']='P36029',['Group 1 using the vision video']='P35144',['Ionic liquids']='P35160',['Circulation ratio f']='P35166',['Compound of interest']='P35147',['Absorption cycles']='P35161',['Group 2 using the image set']='P35145',['Test data count']='P35224',['Vegetable source']='P35148',['Highest Electric field (V/cm)']='P35151',['Information granularity']='P35171',['Information granularities']='P35172',['Graph top-level nodes']='P35173',['training data triples']='P35174',['Training data triples proportion']='P35175',['Test data triples proportion']='P35176',['Software features']='P35146',['Binary systems']='P35162',['The cycle components temperature']='P35165',['Lowest number of pulses']='P35152',['Highest number of pulses']='P35153',['Pulse width (ms)']='P35154',['Treatment temperature (°C)']='P35155',['Best treatment electric field (V/cm)']='P35156',['Best treatment specific energy (kJ/kg)']='P35157',['Antioxidant activity increase (%)']='P35158',['Bioactive compound increase (%)']='P35159',['Participating teams']='P36045',[' Coefficient of performance COP']='P35163',['Thermodynamic properties']='P35164',['Has repository']='P35177',['has selectivity assay']='P35167',['Year of study']='P35182',['Molecular Weight of Chitosan']='P35186',['Github']='P35178',['Repository']='P35179',['prevention strategies']={'P35168','P35169'},['has paper']='HasPaper',['Published']='P35183',['Type of essential oil']='P35185',['Female']='P35188',['Females']='P35189',['Males']='P35190',['Elderly']='P35191',['confidence interval (99%)']='P35180',['Lead compound']='P35194',['Online competition']='P35181',['storage temperature']='P35187',['Has evaluation metrics']='P35217',['Type of sample']='P35184',['Dietary patterns ']='P35201',['Dietary pattern derivation methods']='P35202',['Dietary pattern asscoiated with obesity']='P35204',['RO estimate']='P35206',['95% confidence interval lower limit']='P35207',['95% confidence inteval upper limit']='P35208',['Ant Colony Optimisation algorithms']='P35192',[' SPARQL SELECT queries ']='P35193',['Type of natural additive']='P35195',['Performance ranks']='P36037',['Compared time before the COVID-19 pandemic']='P36094',['Average Spearman\'s rank correlation']='P36039',['Food groups associated with obesity']='P35203',['Time frame']='P35205',['Has word features']='P36000',['Dietary Pattern']='P35196',['Prinicpal component Analysis']='P35197',['Malaysia']='P35198',['Obesity']='P35199',['factors influencing bullying victimization']='P36012',['Age group']='P35200',['Methods of Characterizations used in Study']='P35209',['Materials used in Study for Composite Fabrication']='P35210',['Electroactive Monomer Basis of Fabricated Composite Used in Study']='P35211',['Optoelectrochemical Studies']='P35212',['Dates']='P36084',['Type of Polymerization']='P35213',['Has example']='P35214',['Subtask 1']='P35215',['Subtask 2']='P35216',['Subtask 3']='P35218',['Subtask 2 Part 2']='P35220',['Data annotation granularities']='P35221',['Training data count']='P35222',['has count']='P35223',['Subtask 2 Part 1']='P35219',['Pearson Uncentered Correlation']='P36015',['Organizational factors influencing evidence-based decision-making']='P35225',['Environmental factors influencing evidence-based decision-making']='P35226',['Individual factors influencing evidence-based decision-making']='P35227',['Utilities in CrowdRE']='P36057',['Nigeria']='P35228',['Has preprocessing steps']='P35229',['Has features']='P36001',['Potassium Binding Energy']='P36010',['Total teams']='P36002',['Average length of different types of sentences of Training set']='P36003',['Average length of different types of sentences of Dev set']='P36004',['Average length of different types of sentences of Test set']='P36005',['Corpora']='P36030',['RE activties']='P36006',['Perspective']='P36007',['Binding Energy']='P36008',['Deformation Energy']='P36009',['Potassium/Sodium Binding Energy difference']='P36011',['Code respositories']='P36040',['statistical significance']='P36013',['spanning']='P36032',['calculates']='P36014',['Has heuristic solution method']='P36047',['Distributional word vectors']='P36048',['Direct-defines']='P36023',['harmonic mean of Spearman and Pearson correlation between predicted scores and average manual scores']='P36016',['Approach name']='P36081',['measured']='P36033',['alternative label']='P36018',['Data annotations']='P36022',['Bioassays conducted']='P37002',['Total submissions']='P36024',['Operationalisation of dependent variable']='P36090',['Best Accuracy']='P36079',['Submissions per subtask']='P36025',['Languages']='P36026',['Best team']='P36028',['Total members']='P36027',['Social Dimension']='P37031',['spans']='P36031',['Best Spearman Correlation']='P36080',['Number of isolated compounds']='P37001',['has abbreviation']='P37019',['DBSPB']='P37020',['RE activities with crowd involvement']='P36056',['location of study']='P37004',['Participated in']='P36035',['Evaluation tracks']='P36034',['Performance rank']='P36036',['Elicited information']='P36095',['Average accuracy']='P36038',['Code repositories']='P36041',['Average Score']='P36042',['70.3']='P36058',['Track name']='P36043',['Best teams']='P36044',['Problem type']='P36049',['Dataset statistics']='P36083',['Participating systems']='P36046',['Control variables']='P36107',['Best systems']='P36050',['Animal model']='P36051',['Local Search Algorithm']='P36053',['Local search algorithm Variable Neighbourhood Search']='P36052',['Problem Classification']='P36055',['Table 1: Statistics of datasets']='P37025',['Task Time Type']='P36054',['F(Beta) measure']='P36076',['Beta-T value']='P36077',['Described Ontology']='P41879',['Framework for static optimization of Basic Graph Patterns']={'P36059','P36063','P36067','P36071'},['a set of heuristics for the selectivity estimation of joined triple patterns']={'P36060','P36064','P36068','P36072'},[' a proposal for summary statistics of RDF data']={'P36061','P36065','P36069','P36073'},['A query performance evaluation']={'P36062','P36066','P36070','P36074'},['Machine learning feature']='P36075',['Best F1']='P36078',['Examined (sub-)group']='P36088',['Corpus statistics']='P36087',['Location index']='P36091',['Hoover Coefficient of Concentration']='P36092',['Sustainability Sub-Index']='P36093',['Identification method']='P36101',['Used models']='P36096',['Equipment used']='P37000',['Means of evaluation']='P36082',['Corpus sources']='P36086',['Corpus genres']='P36085',['Incentive/Motivation']='P36097',['Standard drugs used']='P37003',['Indicator for well-being']='P36089',['Performed by']='P36098',['Media/Channel']='P36099',['Run-time purpose']='P36100',['Mean value well-being pre-Corona ']='P36102',['Well-being: mean value during lockdown']='P36104',['Well-being: mean value before COVID-19 pandemic']='P36105',['Well-being: mean value pre-Corona ']='P36103',['Economic Dimension']='P37032',['Well-being: mean value during COVID-19 pandemic']='P36106',['LUBM']='P37021',['SNIB']='P37022',['YAGO2']='P37023',['SP2B']='P37024',['plant material']='P37005',['Result and Conclusion']={'P37011','P37013'},['Implication']={'P37012','P37014'},['Internal identifier']='P37033',['Has end']='P37006',['Environmental dimension']='P37030',['has benchmark']={'hasBenchmark','HAS_BENCHMARK'},['has model']={'hasModel','HAS_MODEL'},['Has evaluation']='HasEvaluation',['Discussion']='P37010',['Exact reaction']='P37028',['covalent linking']='P37027',['CPU']='P37017',['RAM']='P37018',['Operating System']='P37016',['Abstract']='P37015',['CPU Clock rate']='P37026',['Classification category']='P37029',['Effect size - explanation']='P37034',['Measurement of cosmological parameters']='P69006',['Number of questions']='P45108',['Country ']='P46004',['contextualization']='P46002',['extension']={'extension','P45089'},['abbreviation']={'P45085','abbreviation'},['study year']='P46005',['citation']={'P45087','citation'},['developer']={'P45091','developer','wikidata:P178'},['virtual']='P45103',['physical']='P45104',['Asynchronous']='P45105',['Synchronous']='P45106',['applied']='P45082',['specification']={'specification','P45093'},['deposits']='P45097',['video']={'P45098','SCHEMAORG:video','wikidata:P10'},['Results Geographic word Classes']='P45116',['NLP tasks']='P45118',['surveyed neural architecture types']='P45112',['Number of training tokens']='P45061',['softwareConference']='softwareConference',['application']='application',['plugin']='plugin',['operatingSystem']='operatingSystem',['alternativeName']={'alternativeName','P45083'},['license']={'license','P45086','SCHEMAORG:license'},['Guideline']='P45079',['Software entity types']='P45071',['Distinct relation types']='P45144',['Coarse-grained Entity type']='P45067',['Fine-grained Entity type']='P45068',['Supported natural language']='P45069',['release']={'release','P45090'},['plugIn']='P45092',['numericValue']='P45075',['has accuracy']='P45080',['softwareType']={'P45094','softwareType'},['Equipment']='P45072',['hasQuantityKind']='P45074',['qudt:ucumCode']='P45081',['quantityValue']='P45073',['Introduced in']='P45107',['Producer']='P45077',['Dataset type']='P45047',['Guide']='P45078',['Number of development tokens']='P45063',['Number of test tokens']='P45065',['Token-match']='P45052',['Exact match']='P45053',['Token match']='P45054',['Named entity']='P45055',['Result Geographic Location']='P45114',['Number of entity types']='P45056',['Theoretical background']='P46000',['Sample characteristics']='P46001',['Data source timestamp']='P45048',['Slot error rate']='P45046',['contains benchmark']='P45045',['has addition to']='P45044',['gold-standard corpora']='P45057',['Silver-standard corpora']='P45058',['Software types']='P45070',['Triple']='P45130',['Quad']='P45131',['Navigational']='P45134',['Join']='P45135',['Annotation type']='P45051',['programmingEnvironment']='programmingEnvironment',['shared task']='P45012',['Number of complexes']='P45013',['Number of training data events']='P45038',['Number of test data events']='P45039',['Dataset download url']='P45032',['Event types']='P45033',['Bacteria extraction']={'P45015','P45019','P45023','P45027'},['Cellular component extraction']={'P45016','P45020','P45024','P45028'},['Biological Process extraction']={'P45017','P45021','P45025','P45029'},['Molecular function extraction']={'P45018','P45022','P45026','P45030'},['Fine-grained Entity types']='P45049',['Number of mentions in training data']='P45034',['Number of development data mentions']='P45036',['Number of test data mentions']='P45037',['Number of identifiers']='P45066',['Number of training sentences']='P45060',['Number of development sentences']='P45062',['Number of test sentences']='P45064',['Number of training data relations']='P45041',['Number of development data relations']='P45042',['Number of test data relations']='P45043',['Annotation theme']='P45000',['Annotation format']='P45001',['subcategories']='P45003',['Ontology used']='P45002',['Number of fine-grained entity types']='P45050',['sub-event/relations']='P45011',['Annotation approach']='P45010',['RDoC construct']='P44177',['Number of training data mentions']='P45035',['Ontologies used']='P45009',['super domain']='P45014',['Number of Identity Chains']='P44175',['Number of documents']='P44180',['Directly Fine-tune']='P44185',['Number of training documents']='P44188',['Number of discontinuous mentions']='P44176',['Licensing']='P45004',['Number of images']={'P44191','P44198','P44205'},['Number of training images']={'P44192','P44199','P44206'},['Number of validation images']={'P44193','P44200','P44207'},['Number of test images']={'P44194','P44201','P44208'},['Has ontology']={'P44195','P44202','P44209'},['Has nodes']={'P44196','P44203','P44210'},['Has leaf nodes']={'P44197','P44204','P44211'},['Has subset']='P44212',['has aligned entities']='P45059',['Source domain']='P44183',['Target domains']='P44184',['Secondary arguments']='P44167',['Pre-train then Fine-tune']='P44186',['Jointly train']='P44187',['Has project']='P44164',['Number of events']='P44168',['Number of development documents']='P44189',['Number of test documents']='P44190',['Primary argument']='P44166',['Jia and Zhang 2020 + DAPT (Span-level & Integrated)']='P44181',['Top-1 Accuracy (VisE-Bing)']='P45031',['Event / Relation Types']='P44165',['Number of proteins']='P44169',['Baseline score']='P44182',['Number of modifications']='P44170',['Annotation scheme']='P44215',['Coreferences']='P44172',['Annotation guidelines']='P44158',['Number of core entities']='P44171',['Coarse-grained Entity types']='P44162',['Learner Features']='P44157',['Number of mentions']='P44149',['Data format']='P44150',['sub-relations']='P45008',['Has theory']='P44163',['Supported natural languages']='P44156',['Step 2.1.1']='P44161',['Step 2.1']='P44160',['Task name']='P44145',['Best score']='P44146',['Number of articles']='P44152',['Has simulation results']='P44179',['Entity types']='P44148',['Best method']='P44151',['Tool name']='P44153',['Number of leaf nodes']='P44214',['Supported programming languages']='P44154',['Supported functions']='P44155',['Number of nodes']='P44213',['data analysis method']={'P57099','P76003'},['Measuring concentration (ppm)']='P44126',['Sensing element nanomaterial']='P44123',['Operating temperature ( ºC)']='P44124',['Type of gas']='P44125',['language model']='P44132',['Knowledge Base']='P44140',['Answers']='P44142',['Recycling type']='P44128',['Used to predict probabilities to word classes over the whole vocabulary.']='P44133',['Used to predict probabilities to both word classes and members of the class vocabulary.']='P44134',['Evaluates how the benefit of working with smaller vocabularies for numbers and geographic locations']='P44135',['uses Micro-Models']='P44136',['inter-annotator agreement']='P44159',['question']={'P44139','P111012'},['Paraphrases']='P44143',['Processing heuristics']='P44144',['Glass-transition temperature']='P44104',['how much']='P44122',['Life span']='P44106',['minimum']='P44107',['maximum']='P44108',['Crystallinity']='P44105',['Number of paragraphs']='P44174',['Grammar']='P44138',['has melting temperature']='P44111',['Has life span']='P44114',['Formal Language']='P44141',['Has crystallinity']='P44113',['separates the predicted numbers and words']='P44137',['Experimental conditions']='P44118',['Performed at temperature']='P44120',['Processing time']='P44121',['Has result F1']='P44147',['Time to peak insulin concentration']='P44097',['Melting temperature']='P44103',['Recycling']='P44127',['standard deviation']={'P44087','P71159'},['Insulin loaded height of Microneedles']='P44090',['Microneedles structure']='P44091',['basal diameter of Microneedles']='P44088',['Enzyme']='P44117',['Minimum time']='P44109',['Maximum time']='P44110',['peak insulin concentration (Cmax)']='P44096',['Time to minimum glucose level (Tmin)']='P44100',['Relative bioavailability compared with subcutaneous injection']='P44098',['Temperature']='P44119',['has experimental results']='P44178',['has result']='HAS_RESULT',['tip diameter of Microneedles']='P44086',['Total height of Microneedles']='P44089',['Type of etching mixture']='P44060',['Primary etching solution']='P44061',['Miller index']='P44062',['Dose']='P44094',['Has concentration']={'P44066','P44067'},['Average CO2 flux']='P44071',['Average CO2 flux unit']='P44072',['Unit of CO2 flux is different in paper']='P44073',['Carrier for hot melt extrusion']='P44068',['Number of development data events']='P45040',['CO2 flux unit']='P44076',['CO2 flux (lower limit)']='P44074',['CO2 flux (upper limit)']='P44075',['Volumetric dark C fixation (lower limit)']='P44077',['Volumetric dark C fixation unit']='P44078',['Average dark C fixation']='P44079',['Average dark C fixation unit']='P44080',['Dark C fixation unit is different in paper']='P44081',['Depth integrated dark C fixation (lower limit)']='P44083',['Depth integrated dark C fixation (upper limit)']='P44084',['Volumetric dark C fixation (upper limit)']='P44082',['Depth integrated dark C fixation unit']='P44085',['Device Location']='P44129',['Sign']='P44093',['Official dissolution media (USP 40)']='P44069',['Dissolution Conditions']='P44070',['Pharmacokinetic data']='P44095',['Datasets']='P44054',['Softwares']='P44055',['Field survey']='P44056',['Features classified']='P44057',['SAM Accuracy (%)']='P44058',['Supplementry Information']='P44059',['Application area']='P44049',['Surface N2O (nM) (lower limit)']='P44046',['Surface N2O (nM) (upper limit)']='P44047',['Average surface N2O (nM)']='P44048',['Data Duration']='P44050',['Mg-Orthopyroxene']='P44051',['Low calcium Pyroxene (LCP)']='P44052',['High Calcium Pyroxene (HCP)']='P44053',['Unit is different in paper']='P44045',['Variables ']={'P44028','P44029','P44030','P44031','P44032','P44033'},['Naive Bayes']='P44035',['affects']={'P44036','affects','AFFECTS'},['associated with']='ASSOCIATED_WITH',['augments']='AUGMENTS',['causes']='CAUSES',['coexists with']='COEXISTS_WITH',['compared with']={'COMPARED_WITH','P71197'},['complicates']='COMPLICATES',['Measured in conditions']='P44064',['disrupts']='DISRUPTS',['has mesh']='HAS_MESH',['higher than']='HIGHER_THAN',['inhibits']='INHIBITS',['interacts with']='INTERACTS_WITH',['location of']='LOCATION_OF',['manifestation of']='MANIFESTATION_OF',['method of']={'METHOD_OF','P71201'},['occurs in']='OCCURS_IN',['precedes']='PRECEDES',['predisposes']='PREDISPOSES',['prevents']='PREVENTS',['process of']='PROCESS_OF',['stimulates']='STIMULATES',['treats']='TREATS',['mentioned in']='MENTIONED_IN',['isa']='ISA',['administered to']='ADMINISTERED_TO',['N2O flux (lower limit)']='P44037',['N2O flux (upper limit)']='P44038',['N2O flux unit']='P44039',['Average surface saturation of N2O (percent)']='P44040',['Average N2O flux']='P44041',['Average N2O flux unit']='P44042',['Surface saturation of N2O (percent) (lower limit)']='P44043',['Surface saturation of N2O (percent) (upper limit)']='P44044',['Viewpoint']='P44013',['Data managment']='P44016',['Visualization']='P44017',['Situational Awareness']='P44018',['Planning and Prediction']='P44019',['Integration and Collaboration']='P44020',['Type of etching']='P44065',['Etching rate']='P44063',['has previous step']='P44024',['has next step']='P44025',['has previois step']='P44023',['starts with']='P44026',['ends with']='P44027',['has value range']='P44010',['converts to']='CONVERTS_TO',['Ozone concentration']='P44001',['Has effect']='P44004',['Decomposition rate constant']='P44005',['Extinction coefficient']='P44007',['has Temporal Integration']='P44015',['has fidelity status']='P44014',['has material form']='P44115',['Has measurement value']='P44011',['Has glass-transistion temperature']='P44112',['Insulin content (mIU / needle)']='P44092',['Data management']='P44021',['Has measurement method']='P44012',['Has dielectric constant']='P44000',['Measured at temperature']='P44002',['Decomposition rate']='P44003',['At wavelength']='P44008',['has upper limit']='P43247',['has lower limit']='P43248',['Direction']='P43246',['different from']={'DIFFERENT_FROM','P71198'},['diagnoses']='DIAGNOSES',['Has pipeline']='P43249',['has reproducibility']='P43250',['key insights']='P43251',['distance from surface']='P43245',['is measured in']='P44022',['References to articles inside ACL ARC']='P43242',['Has heading level']='HasHeadingLevel',['Number of authors']='P43244',['Tagging scheme']='P43239',['Meaured in']='P43237',['Has molecular weight']='P44116',['References to articles outside ACL ARC']='P43243',['Provide Answers']='P43232',['Has list']='HasList',['Has entry']='HasEntry',['Emission lifetime']='P43227',['Ground-state reduction potential']='P43229',['https://github.com/harritaylor/torchvggish']='P43241',['Ground-state oxidation potential']='P43228',['Provide Paraphrases']='P43233',['has viewpoint']='P43234',['Thickness ']='P43222',['Strain (%)']='P43224',['Measured in']='P43238',['Error']='P43225',['Size']={'P43223','P59090'},['Wavelength of maximum emission']='P43226',['Average Prochlorococcus abundance']='P43218',['Average Synechococcus abundance']='P43219',['Average Picoeukaryotes abundance']='P43220',['Average abundance unit']='P43221',['has result in QALD-9']='P43200',['Has result in LC-QuAD 1.0']='P43201',['DNA sequencing technology']='P43204',['Channel length (nm)']='P43216',['Channel  length (nm)']='P43217',['Detection range (microstrain)']='P43202',['Sensitivity (pm/microstrain)']='P43203',['Channel (nm)']='P43212',['Frequency (MHz)']='P43213',['Minimum bending (mm)']='P43215',['Zeolites']='P43205',['Actinolite']='P43206',['saponite']='P43207',['Sulfates']='P43208',['Kieserite']='P43209',['monohydrated sulfates']='P43210',['vermiculite clays']='P43211',['Supplementary sources']='P43165',['halloysite']='P43166',['Fe-OH']='P43167',['Dolomite']='P43168',['Carbonates']='P43169',['Calcite']='P43170',['Clay']='P43171',['Kimberlite']='P43172',['Calcrete']='P43173',['Montmorillonite']='P43174',['Andesite']='P43175',['µef (cm2/ Vs)']='P43214',['Suuplimentary Information']='P43179',['Pyroxene']='P43180',['Olivine']='P43181',['Hydrated mineral']='P43182',['Hydroxylated silica']='P43183',['Molecular water']='P43184',['Fe/Mg-OH']='P43185',['Phyllosilicates']='P43186',['Fe (Chamosite)']='P43187',['Mg']='P43188',['Prehnite']='P43189',['Monohydrate']='P43190',['Sulfate']='P43191',['Hydrated silica']='P43192',['ankerite']='P43193',['serpentine']='P43194',['smectite']='P43195',['manganocalcite']='P43196',['Plagioclase']='P43197',['Supplimentary Information']='P43198',['Hematite']='P43176',['Chlorite']='P43177',['White mica']='P43178',['Field spectra']='P43158',['Techniques/Methods']='P43159',['Geothite']='P43160',['MgOH']='P43161',['(FeMg)OH']='P43162',['Talc']='P43163',['Kaolinite']='P43164',['Transfer']='P43199',['Minimum glucose level (Cmin)']='P44099',['Time to peak insulin concentration (Tmax)']='P44102',['Conversion']='P43148',['Reactor']='P43147',['Fidelity status']='P43235',['Temporal Integration']='P43236',['Efficiency']='P43156',['Photocatalyst content']='P43151',['Incident light']='P43152',['Light intensity']='P43153',['Photocatalyst']='P43150',['Degraded substance']='P43154',['BET']='P43155',['After time']='P43157',['Excited-state oxidation potential']='P43230',['Excited-state reduction potential']='P43231',['Conclusions']='P43143',['paper:key words']='P43144',['Relative pharmacological availability compared to subcutaneous injection']='P44101',['Annotators']='P43240',['provides input for']='P43145',['simulates']='P43146',['Heat of ozone dissolution']='P44009',['has disadvantages']='P43140',['Has Atomic resource']='P43137',['Has energy sources']='P43135',['hasGoal']='P43138',['has time frame']='P43139',['Has target group (learners)']='P43121',['Has learning objectives']='P43122',['Has location of use']='P43123',['Has learning activity']='P43124',['Uses didactics']='P43125',['has photovoltaics electricity generation']='P43131',['has installed onshore wind capacity']='P43132',['Uses technological tools']='P43126',['has disadvantage']='P43141',['has didactic process']='P43127',['Has application in']='P43128',['has X-ray string']='P43117',['Has Xray resource']='P43118',['has Process areas']='P45151',['Ocular bioavailability']='P43113',['Has action duration']='P43115',['Reference Electrode']='P43096',['LOD (µM)']='P43097',['has environment']='P43104',['has form']='P43098',['has functionality']='P43099',['has process']='P43101',['has time']='P43102',['has state']='P43103',['Type of Biosensor']='P43095',['Has health']='P43100',['has miscellaneous qualitative']='P43105',['Professional and social networking opportunities']='P43116',['decreases']='P43107',['Has no effect on']='P43108',['Does not cause']='P43109',['Has installed capacity']='P43133',['increased in magnitude relative to']='P43112',['RQ']='P43094',['Belongs to material group']='P43069',['Number of unqiue entities']='P43068',['Input indicator']='P43073',['Process indicator']='P43074',['Has steps']='P43070',['Uses variant']='P43072',['Output indicator']='P43075',['Has method in related works']='P43082',['Has manufacturing process']='P43071',['Type of cyclodextrin']='P43106',['increases']='P43110',['has ocular bioavailability']='P43114',['has ion state']='P43136',['has installed photovoltaics capacity']='P43130',['paper: Theory / Construct / Model']='P43142',['paper:author']='P43083',['paper: publication_year']='P43084',['paper:publised_in']='P43085',['Qual List']='P43086',['Ranking']='P43087',['Technology']='P43088',['Focus Group']='P43089',['Emergency Management Phase']='P43090',['paper: Theory / Concept / Model']='P43091',['paper:Study Type']='P43092',['Emergency Type']='P43093',['has permeation']='P43120',['Text type']='P43063',['has research component']='P43079',['Salinity level']='P43129',['has sub sub quality']='P43080',['has sub quality']='P43081',['has system qualities']='P43078',['Specific Rules']='P43067',['Number of tokens']='P43025',['Represents SC vs SC']='P43039',['Has Variant']='P43042',['Has virus variant']='P43043',['Has Virus']='P43044',['Has incidence']='P43045',['Has hospitation rate']='P43046',['Cover level of granularity strategic (S), tactical (T) and operational (O)']='P43047',['Follows methodological approach: inspiration (IS), induction (ID), deduction (D), synthesis (S), collaboration (C) and hybrid (H); evaluation (E)']='P43048',['Scope an organizational extent: internal (I), dyadic relationship (D), external (E), inter-business network (N)']='P43049',['Covers industry sector']='P43050',['Communicates a purpose']='P43051',['Offers an application']='P43052',['Outcome indicator']='P43076',['Impact indicator']='P43077',['Label set']='P43064',['Tokenization']='P43065',['General rules']='P43066',['Assessment of acquired knowledge']='P43023',['Advantage provided by the system']='P43055',['Shows market interactions ']='P43027',['Has Host']='P43040',['Has mortality rate']='P43041',['Has physical material interactions']='P43026',['Map of software products for best practices']='P43033',['Represent vertices']='P43034',['Represent edges']='P43035',['Consider various materials']='P43036',['Distinguish supply, demand']='P43037',['Has objective (o) or subjectivist (s) conceptualization']='P43038',['has Customer Interaction']='P43000',['Has Material Transaction']='P43001',['Has Market Interaction']='P43002',['Has Various Material']='P43007',['Has Supply & Demand']='P43008',['Has SC vs SC ']='P43009',['Has Conceptualization']='P43010',['Contains standard description of process']='P43028',['Represents SCOR metrics']='P43029',['Describes best in-class management practices']='P43030',['Has best-in.class management practices']='P43031',['Has best-in-class management practices']='P43032',['has other skills']='P43022',['Has electricity generation']='P43134',['has character traits ']='P43018',['Attribute types']='P42025',['Zeta potential (mV)']='P42019',['Skin model']='P42020',['Gas response (S=Ra/Rg)']='P42018',['Permeation flux']='P42021',['Normalization types']='P42024',['Penetration depth']='P42022',['Permeation depth']='P42023',['has business competence']='P43011',['SPARQL query']='P42010',['Data formats']='P42011',['Total tags']='P42013',['Semantic roles']='P42014',['Amplification factor']='P42017',['Detection range (°C)']='P42015',['Sensitivity (nm/°C)']='P42016',['Models']='P43024',['Number of words']='P41995',['has value ']='P41999',['Has unit ']='P42000',['Number of unique words']='P42009',['Subset']='P42026',['Fill factor, FF']='P42005',['Has type ']='P42007',['Energy band gap']='P42002',['Mobility value']='P42008',['Short-circuit current density, Jsc']='P42004',['Power conversion efficiency']='P42006',['Technical challenges']='P42012',['has Process description']='P43003',['has SCOR Metrics']='P43004',['Has Management Practices']='P43005',['Has Software Products']='P43006',['Limit of the system']='P43056',['has IS/IT competence']='P43013',['has (public) policy competence']='P43014',['has organization competence']='P43012',['Chlorite (Ferrous)']='P41976',['Epidote(Ferrous)']='P41977',['Alunite (AL-OH)']='P41978',['Kaolinite (AL-OH)']='P41979',['Muscovite (Al-OH)']='P41980',['Biotite granodiorite gneiss(OH, tuff)']='P41981',['Ferrous']='P41982',['Ferric']='P41983',['Ferric/Ferrous']='P41984',['OH']='P41985',['FeO']='P41986',['Open circuit voltage, Voc']='P42003',['Top three concepts']='P41996',['Al-OH']='P41987',['Carbonate alteration zone']='P41988',['has law competence']='P43015',['Field of application']='P43019',['Source url']='P41989',['Number of unique triples']='P41990',['Number of tables']='P41991',['4-ary Relations']='P41993',['Number of 4-ary Relations']='P41994',['HOMO']='P42001',['Average mixed layer depth (meter)']='P41930',['has analytical skills']='P43020',['has self-management skills']='P43021',['Integrated abundance unit']='P41945',['Average integrated Prochlorococcus abundance']='P41946',['Average integrated Synechococcus abundance']='P41947',['Average integrated Picoeukaryotes abundance']='P41948',['Average integrated abundance unit']='P41949',['Abundance unit is different in paper']='P41950',['Volumetric primary production (upper limit)']='P41951',['Volumetric primary production unit']='P41952',['Volumetric primary production (lower limit)']='P41956',['Average primary production unit']='P41957',['Other datasets']='P41974',['Preprocesing']='P41975',['combines']='P42027',['Programmed in']='P42028',['Supplementary information']='P41966',['Clinopyroxene pigeonite (nm)']='P41968',['Clinopyroxene pigeonite(nm)']='P41969',['Clinopyroxene augite (nm)']='P41970',['Chromite(nm)']='P41971',['Number of binary relations']='P41992',['diopside (high-Ca clinopyroxene)']='P41972',['diopside (high-Ca clinopyroxene) (nm)']='P41973',['Mathematical model']='P41907',['Concept Clustering']='P41997',['Depth integrated primary production (lower limit)']='P41953',['Depth integrated primary production (upper limit)']='P41954',['Depth integrated primary production unit']='P41955',['Implemented technologies']='P41914',['Dataset URL']='P41919',['Link to the Dataset']='P41920',['question type']='P41928',['bar-baz']='P41922',['Community QA']='P41929',['foo']='P41921',['Question Types']='P41925',['Power conversion efficiency (%)']='P41903',['Average specificity']='P41892',['Average MAcc']='P41893',['Mobility type']='P41904',['Average sensibility']='P41891',['Experimental validation of mathematical model']='P41908',['Mathematical model used In-silico study']='P41909',['Example statement']='P41896',['Relationships learning']='P41915',['Instance learning']='P41916',['Taxonomy learning']='P41917',['Validation comment']='P41918',['HOMO (eV)']='P41902',['Mobility value (cm2/V.s)']='P41905',['Amount of Questions']='P41923',['Fe-bearing Mg-rich spinel (nm)']='P41967',['Theoretical guarantees']='P41911',['Robustness analysis']='P41912',['Donor']='P41897',['Acceptor']='P41898',['Number of sentences']='P41887',['teeeee']='P41888',['test']='P41889',['Symbol']='P41890',['Average F1-Score']='P41894',['Optical period (M3)']='P41958',['Data Level (M3)']='P41959',['No. of Tiles']='P41960',['Low-Ca pyroxene (nm)']='P41961',['high-Ca pyroxene (nm)']='P41962',['impact melt or melt breccias (nm)']='P41963',['Orthopyroxenes (nm)']='P41964',['Clinopyroxenes (nm)']='P41965',['Number of statements']='P41895',['CAS number']='P41906',['Type of knowledge source']='P41927',['In-vivo study']='P41910',['Energy band gap (eV)']='P41899',['Contribution description']='P41880',['Study purpose']='P41881',['Material/Method']='P41931',['Prochlorococcus abundance (lower limit)']='P41932',['Prochlorococcus abundance (upper limit)']='P41933',['Synechococcus abundance (lower limit)']='P41934',['Synechococcus abundance (upper limit)']='P41935',['Picoeukaryotes abundance (lower limit)']='P41936',['Picoeukaryotes abundance (upper limit)']='P41937',['Abundance unit']='P41938',['Integrated Prochlorococcus abundance (lower limit)']='P41939',['Integrated Prochlorococcus abundance (upper limit)']='P41940',['Integrated Synechococcus abundance (lower limit)']='P41941',['Integrated Synechococcus abundance (upper limit)']='P41942',['Integrated Picoeukaryotes abundance (lower limit)']='P41943',['Integrated Picoeukaryotes abundance (upper limit)']='P41944',['Filtering ']='P41998',['Limit']='P41885',['Annotation']='P41873',['Annotation details']='P41874',['has other competence']='P43016',['has soft skills competences']='P43017',['Relation types']={'P41866','P41868','P41870'},['Popular methods']={'P41867','P41869','P41871'},['Class learning']='P41913',['Components ']='P41882',['Issue(s) Addressed	']='P41883',['Technologies Deployed']='P41884',['LUMO']='P41900',['LUMO (eV)']='P41901',['Number of coreference links']='P41876',['Number of coreference clusters']='P41877',['Data domains']='P41878',['Information Units']='P41886',['Has measurement']='P41861',['Data coverage']='P41872',['Mobility (cm2 /V.s)']='P41862',['Subthreshold Swing  (mV/dec)']='P41863',[' Threshold Voltage (V)']='P41864',['current ratio (Ion/Ioff)']='P41865',['Area']='P41850',['Step 1']='P41857',['Step 2']='P41858',['Paper type']='P41847',['Research objective']='P41848',['has system characteristics']='P41860',['paper:caategory']='P41852',['Acronym_in_literature']='P41853',['Transitions']='P41854',['Ionization_state']='P41855',['Comparison  to']='P41856',['Number of relations']='P41875',['has transitions']='P41813',['Ontology domains']='P41828',['described by']='P41816',['Epidemiological surveillance tool']='P41824',['Epidemiological surveillance architecture']='P41823',['Epidemiological surveillance software']='P41825',['Linked Ontology']='P41818',['news headlines (HDL)']='P41851',['Rules']='P41849',['Requirements Satisfied']='P41830',['Qualified by']='P41846',['Non-Requirements']='P41831',['Modules']='P41832',['implements']='P41833',['function']='P41834',['Documentation']='P41835',['Focus on']='P41836',['captures']='P41837',['Evaluated on']='P41838',['applied on']='P41845',['trained for']='P41844',['Ontologies which have been reused as imported']='P41811',['Epidemiological surveillance users']='P41821',['Statistical analysis techniques']='P41822',['Epidemiological surveillance approach']='P41826',['Epidemiological software development approach']='P41827',['properties']='P41769',['properties/Atomic_property/type']='P41770',['properties/Atomic_property/type/Isoelectronicity/type']='P41771',['properties/Atomic_property/type/Ionization_state/type']='P41772',['properties/Atomic_property/type/transitions/type']='P41773',['properties/Spectroscopy_property/type']='P41774',['properties/Spectroscopy_property/type/spectral_range/type']='P41775',['properties/Plasma_property/type']='P41776',['properties/Plasma_property/type/plasma_discharge/type']='P41777',['properties/Plasma_property/type/Te/value']='P41778',['properties/Plasma_property/type/Te/unit']='P41779',['properties/Plasma_property/type/Ne/value']='P41780',['properties/Plasma_property/type/Ne/unit']='P41781',['Surface functionalized with']={'P41782','P41783'},['Epidemiological surveillance process']='P41820',['Properties/Atomic_properties/type/Isoelectronicity/value']='P41786',['Properties/Atomic_properties/type/Ionization_state/value']='P41787',['Properties/Atomic_properties/type/transitions/value']='P41788',['Properties/Spectroscopy_properties/type']='P41789',['Properties/Spectroscopy_properties/type/spectral_range/value']='P41790',['Properties/Plasma_properties/type']='P41791',['Properties/Plasma_properties/type/plasma_discharge/value']='P41792',['Properties/Plasma_properties/type/Te/value']='P41793',['Properties/Plasma_properties/type/Te/unit']='P41794',['Properties/Plasma_properties/type/Ne/value']='P41795',['Properties/Atomic_properties/type*']='P41799',['Properties/Atomic_properties/type/Isoelectronicity/value*']='P41800',['Properties/Atomic_properties/type/Ionization_state/value*']='P41801',['Properties/Atomic_properties/type/transitions/value*']='P41802',['Properties/Spectroscopy_properties/type*']='P41803',['Properties/Spectroscopy_properties/type/spectral_range/value*']='P41804',['Properties/Plasma_properties/type*']='P41805',['Properties/Plasma_properties/type/plasma_discharge/value*']='P41806',['Properties/Plasma_properties/type/Te/value*']='P41807',['Properties/Plasma_properties/type/Te/unit*']='P41808',['Properties/Plasma_properties/type/Ne/value*']='P41809',['Properties']='P41814',['Research_objetive']='P41812',['Hypothesis type']='P41703',['Effect compared to non-functionalized nanoparticles']='P41796',['Phenological traits']='P41707',['Life history traits']='P41708',['Other Species Traits']='P41709',['Trait evolution']='P41710',['Niche shift']='P41711',['Abundance / density']='P41712',['Community composition']='P41713',['Species interactions']='P41714',['Cities are dynamic']='P41719',['Evolutionary biology']='P41730',['Restoration/Conservation ecology']='P41731',['Genetics']='P41732',['Fusion protein']='P41735',['Cargo']='P41736',['Loading effeciency']='P41737',['In vitro effects']='P41738',['Has R-value']='P41810',['Bias (V)']='P41829',['Output/Application']='P41742',['Photoresponsivity (A/W ) ']='P41839',['Quantum efficiency (%) ']='P41840',['Rise time (s)']='P41841',['Decay time (s)']='P41842',['contribution:research_problem/Line broadening in plasmas/Research_objetive']='P41744',['paper:type']='P41745',['Atomic_property']='P41746',['Atomic_property/Isoelectronicity/type']='P41747',['Atomic_property/Ionization_state/type']='P41748',['Atomic_property/transitions/type']='P41749',['Spectroscopy_property']='P41750',['Spectroscopy_property/spectral_range/type']='P41751',['Plasma_property']='P41752',['Plasma_property/plasma_discharge/type']='P41753',['Comparison_to']='P41754',['Plasma_property/Te/value']='P41755',['Plasma_property/Te/unit']='P41756',['Plasma_property/Ne/value']='P41757',['Plasma_property/Ne/unit']='P41758',['Line broadening in plasmas/Research_objetive']='P41759',['Isoelectronicity/type']='P41760',['Ionization_state/type']='P41761',['transitions/type']='P41762',['spectral_range/type']='P41763',['plasma_discharge/type']='P41764',['Te/value']='P41765',['Te/unit']='P41766',['Ne/value']='P41767',['Ne/unit']='P41768',['In vivo effects']='P41739',['scores']='P41859',['research_problem/Line broadening in plasmas/Research_objetive']='P41784',['Properties/Atomic_properties/type']='P41785',['Emission maximum (nm)']='P41733',['also known as']='P41843',['Efficiency compared to non-functionalized nanoparticles']='P41797',['Cities are ecosystems']='P41720',['Cities are spatially heterogeneous']='P41721',['Membrane protein']='P41734',['Epidemiological surveillance system purpose']='P41819',['Si-O-Si symmetric stretching']='P41682',['Antisymmetric Si-O stretching']='P41683',['Antisymmetric Mg-OH translation']='P41684',['Symmetric Mg-OH vibration']='P41685',['Supplements']='P41686',['Si-O-Si bending']='P41687',['Si-O-Si translation']='P41688',['Ti-Clinohumite']='P41690',['two-layer chondrodite']='P41691',['sonolite']='P41692',['silicate norbergite']='P41693',['Mg2SiO4']='P41694',['Mg2SiO5']='P41695',['BO stretching vibrations']='P41696',['SiO apical stretching']='P41697',['ferroaxinite']='P41698',['OBO bending']='P41699',['ferroaxinite (FeO)']='P41700',['ferroaxinite (OH)']='P41701',['Joaquinite (OH)']='P41702',['Type of nanocarrier']='P41740',['Strain range (%)']='P41670',['Nanomaterials']='P41671',['Gauge Factor (GF)']='P41669',['limit of detection (mM)']='P41673',['Sensor Measurements']='P41674',['Testing corpus']='P41656',['Relationships']='P41724',['Invasion biology']='P41725',['Climate change biology']='P41726',['Community and population ecology']='P41727',['Behavioral ecology']='P41728',['Biogeography']='P41729',['Therapeutic effects of the carrier']='P41743',['Techniques/Analysis']='P41662',['Training corpus']='P41655',['Ontologies which has been used as referenced']='P41665',['Referenced as metadata']='P41658',['Instruments']='P41676',['Clinohumite']='P41689',['Ecological processes are still at work and are important in cities']='P41722',['Human and natural processes interact in cities']='P41723',['Sensors']='P41659',['Fieldwork']='P41660',['Outcomes']='P41661',['QUDT']='P41622',['qu']='P41623',['muo']='P41624',['ucum']='P41625',['OM']='P41626',['oldssn']='P41627',['om']='P41628',['Goodrelations']='P41629',['vaem']='P41630',['dc']='P41631',['VANN']='P41632',['VANN ontology']='P41634',['dc ontology']='P41635',['Geonames']='P41621',['Ontology ID']='P41663',['Ontology IRI']='P41664',['Ontologies which have been used as referenced']='P41666',['Ontologies which have been used as imported']='P41667',['Ontologies which have been used as referenced as metadata']='P41668',['OWL-Time']='P41616',['Social-ecological processes']='P41704',['Focal entity']='P41705',['Behavioral traits']='P41706',['research_problem/Line broadening in plasmas/Research_objetive*']='P41798',['Timezone']='P41618',['Geo']='P41619',['GeoSPARQL']='P41620',['muo ontology']='P41641',['qu ontology']='P41642',['QUDT ontology']='P41643',['Geonames ontology']='P41644',['GeoSPARQL ontology']='P41645',['Geo ontology']='P41646',['Timezone ontology']='P41647',['Timeline ontology']='P41648',['SKOS ontology']='P41633',['ucum ontology']='P41640',['OWL-Time ontology']='P41649',['vaem ontology']='P41636',['Goodrelations ontology']='P41637',['om ontology']='P41638',['oldssn ontology']='P41639',['Schema ontology']='P41653',['DUL ontology']='P41654',['Dcterms ontology']='P41650',['FOAF ontology']='P41651',['prov ontology']='P41652',['Habitat quality']='P41715',['Ecosystem functioning and services']='P41716',['Driver of change']='P41717',['Principles']='P41718',['Imaging modality ']='P41600',['Validation tool']='P41615',['Vaccine Name']='P41607',['Target antigen']='P41608',['Delivery Vehicle']='P41609',['Delivery Route']='P41610',['Phase']='P41611',['Link to research paper']='P41613',['Minerals in consideration']='P41675',['Raman laser used']='P41677',['Orthosilicate']='P41678',['silicate glasses']='P41679',['symmterical alumina tetrahedral network']='P41680',['[AlO4]-']='P41681',['Related work']='P41612',['Sensitivity CAD-System']='P41593',['Specificity CAD-System ']='P41594',['Sensitivity Radiologist']='P41595',['Chemical group']='P41601',['Rise time']='P41597',['AUC (with artificial intelligence)']='P41603',['AUC without AI ']='P41598',['AUC with AI ']='P41599',['AUC (without artificial intelligence)']='P41602',['referenced ontology']='P41657',['95% confidence interval (without AI)']='P41604',['95% confidence interval (with AI)']='P41605',['Taxonomic learning']='P41614',['Typical prefix']='P41741',['Self-referencing']='P41591',['IS Electronic Health Record-based']='P41587',['Number of Target Health care Facilities']='P41588',['Components of the smart city governance_Stakeholders']='P41572',['Components of the smart city governance_Structures and organisations']='P41573',['Components of the smart city governance_Processes']='P41574',['Components of the smart city governance_Roles and responsibilities']='P41575',['Components of the smart city governance_Technology and data']='P41576',['Components of the smart city governance_Legislation and policies']='P41577',['Components of the smart city governance_Exchange arragements']='P41578',['Measurements_Aggregate-based measures']='P41579',['Measurements_Component-based measures']='P41580',['Contextual factors_Degree of autonomy']='P41581',['Contextual factors_Local conditions']='P41582',['Readout']='P41589',['Temporal character']='P41590',['Surface roughness (nm)']='P41571',['Outcomes_Substantive outputs']='P41583',['Outcomes_Procedural changes']='P41584',['Ratiometric']='P41606',['Timeline']='P41617',['Registry Established Year']='P41585',['vuvspec_irradiance [Al I, Al II, C$$_x$$F$$_y$$, Ne,I, Xe I, He I]']='P41554',['vuvspec_irradiance [H I,H$$_2$$N I,N$$_2$$,O I]']='P41555',['Maximum temperature (C)']='P41557',['Has a unit']='P41558',['Minimum temperature (C)']='P41556',['Components']='P41560',['vuvspec_irradiance [Al I, Al II, C_xF_y, Ne,I, Xe I, He I]']='P41562',['vuvspec_irradiance [H I,H_2,N I,N_2,O I]']='P41563',['Geographic scale (Km²)']='P41568',['vuvspec_irradiance [H I,H_2, N I,N_2,O I]']='P41565',['Film thickness (nm)']='P41569',['Film orientation']='P41570',['Number of identified species with current taxonomy']='P41567',['Figure for']='P41544',['Target gas concentration']='P41546',['Nanomaterial']='P41552',['vuvspec_irradiance [Ar I, Ar II]']='P41553',['Outcome']='P41534',['Impact']='P41535',['Developed at']='P41530',['Developed by']='P41531',['Evaluation metrics']='P41532',['Response (%)']='P41549',['has novel approach']='P41533',['Target gas concentration (ppm)']='P41547',['unitLabel']='unitLabel',['Patient cohort ']='P41592',['Reponse (%)']='P41548',['Components of smart city governance']='P41561',['Specificity Radiologist']='P41596',['published by']='P41566',['vuvspec_irradiance']='P41526',['Unit_vuvspec_irradiance']='P41527',['Pressure']='P41528',['Unit_pressure']='P41529',['NO3 uptake (lower limit) (fall inter-monsoon)']='P41472',['NO3 uptake (upper limit) (fall inter-monsoon)']='P41473',['NH4 uptake (lower limit) (fall inter-monsoon)']='P41474',['NH4 uptake (upper limit) (fall inter-monsoon)']='P41475',['Urea uptake (lower limit) (fall inter-monsoon)']='P41476',['Urea uptake (upper limit) (fall inter- monsoon)']='P41477',['Total N uptake (lower limit) (fall inter-monsoon)']='P41478',['Total N uptake (upper limit) (fall inter-monsoon)']='P41479',['NO3 uptake (lower limit) (spring inter-monsoon)']='P41486',['NO3 uptake (lower limit) (summer monsoon)']='P41487',['NO3 uptake (upper limit) (spring inter-monsoon)']='P41488',['NO3 uptake (upper limit) (summer monsoon)']='P41489',['NH4 uptake (lower limit) (spring inter-monsoon)']='P41490',['NH4 uptake (lower limit) (summer monsoon)']='P41491',['NH4 uptake (upper limit) (spring inter-monsoon)']='P41492',['NH4 uptake (upper limit) (summer monsoon)']='P41493',['Urea uptake (lower limit) (spring inter-monsoon)']='P41494',['Urea uptake (lower limit) (summer monsoon)']='P41495',['Urea uptake (upper limit) (spring inter-monsoon)']='P41496',['Urea uptake (upper limit) (summer monsoon)']='P41497',['Total N uptake (lower limit) (spring inter-monsoon)']='P41498',['Total N uptake (upper limit) (spring inter-monsoon)']='P41499',['Sampling depth (meter) (lower limit)']='P41511',['Sampling depth (meter) (upper limit)']='P41512',['Average N2 fixation rate']='P41513',['Average N2 fixation rate unit']='P41514',['Sea surface temperature (degree Celsius) (lower limit)']='P41500',['Sea surface temperature (degree Celsius) (upper limit)']='P41501',['Sea surface salinity (lower limit)']='P41502',['Sea surface salinity (upper limit)']='P41503',['NO3 uptake (lower limit) (austral summer)']='P41505',['NO3 uptake (upper limit) (austral summer)']='P41506',['NH4 uptake (lower limit) (austral summer)']='P41507',['NH4 uptake (upper limit) (austral summer)']='P41508',['Total N uptake (lower limit) (austral summer)']='P41509',['Total N uptake (upper limit) (austral summer)']='P41510',['Total participants']='P41538',['Total systems']='P41539',['Other resources']='P41540',['as']='P41541',['Depth integrated N2 fixation rate (lower limit)']='P41515',['Depth integrated N2 fixation rate (upper limit)']='P41516',['Depth integrated N2 fixation rate unit']='P41517',['Volumetric N2 fixation rate (lower limit)']='P41518',['Volumetric N2 fixation rate (upper limit)']='P41519',['Volumetric N2 fixation rate unit']='P41520',['Average N2 fixation rate (summer)']='P41521',['Average N2 fixation rate (spring)']='P41522',['N2 fixation rate unit is different in paper']='P41523',['vuvspec_irradiance [Al I, Al II, C_xF_y, Ne I, Xe I, He I]']='P41564',['Consumption and income ']='P41430',['Land and ecosystems']='P41431',['Air quality']='P41432',['Financial capital']='P41435',['Labour']='P41436',['Physical capital']='P41438',['Subjective well-being']='P41443',['Nutrition']='P41444',['Trust']='P41441',['Physical safety']='P41442',['Knowledge capital']='P41445',['Thickness of the dielectric layer (microns)']='P41446',['Relative dielectric constant']='P41447',[' Apparent capacitance - Ca (pF)']='P41448',['Real down-state capacitance - Cr (pF)']='P41449',['Capacitances ratio (Cr/ Ca)']='P41450',['Degree of autonomy']='P41464',['Legislation and policies']='P41457',['Exchange arragements']='P41458',['Procedural changes']='P41463',[' MEMS switch type']='P41452',['Executive']='P41586',['Technology and data']='P41456',['Target gas']='P41545',['Geographic scale ($$Km^2$$)']='P41542',['Spectral_lines']='P41543',['Local conditions']='P41465',['Sensitivity of the glucose sensor (mA/cm². mM)']='P41672',['Response time (s)']='P41550',['Recovery time (s)']='P41551',['Energy resources']='P41433',['Climate']='P41437',['Leisure']='P41439',['Contact area  (microns2)']='P41451',['Hard smartness']='P41536',['Soft smartness ']='P41537',['Aggregate-based measurements']='P41459',['Aggregate-based measures']='P41460',['Component-based measures']='P41461',['Substantive outputs']='P41462',['Greyish brown loam (nm)']='P41424',['Kaosmec altered mineral (nm)']='P41425',['Pigeonite (nm)']='P41409',['Augite (nm)']='P41410',['Albite (nm)']='P41411',['Mirabilite (nm)']='P41412',['Salt (nm)']='P41413',['Scolecite (nm)']='P41414',['Gray hematite (nm)']='P41415',['Banded Hematite Quartz (BHQ) (nm)']='P41416',['Blue hematite (nm)']='P41417',['Laminated ore (nm)']='P41418',['Lateritic ore (nm)']='P41419',['Geothite (nm)']='P41420',['OH (nm)']='P41421',['Al-OH (nm)']='P41422',['H2O (nm)']='P41423',['Dolomite (nm)']='P41426',['Phlogopite (nm)']='P41427',['has composite indicator']='P41559',['Language Genus']='P41429',['NO3 uptake (lower limit) (winter monsoon)']='P41480',['NO3 uptake (upper limit) (winter monsoon)']='P41481',['NH4 uptake (lower limit) (winter monsoon)']='P41482',['NH4 uptake (upper limit) (winter monsoon)']='P41483',['Total N uptake (lower limit) (winter monsoon)']='P41484',['Total N uptake (upper limit) (winter monsoon)']='P41485',['Amphibolite (nm)']='P41340',['Anorthosites (nm)']='P41341',['Charnockite (nm)']='P41342',['Pink Magmatite (nm)']='P41343',['Hornblende biotite gneiss  (nm)']='P41344',['Granite (nm)']='P41345',['Fluvial (nm)']='P41346',['Limestone (nm)']='P41350',['Magnetite quartzite  (nm)']='P41351',['Garnetiferrous pyroxene granulite  (nm)']='P41352',['Garnetiferrous pyroxene granulite (nm)']='P41353',['Magnetite (ferric ion) (nm)']='P41354',['Magnetite (ferric iron) (nm)']='P41355',['Dunite (nm)']='P41356',['Orthoclase (nm)']='P41357',['Biotite (nm)']='P41358',['Muscovite (nm)']='P41359',['Iron oxide (nm)']='P41360',['Country rocks (nm)']='P41361',['Remark']='P41504',['Uses Climate Scenario']={'P41362','P41366','P41370','P41374'},['Average Global Mid-Century Warming']={'P41363','P41367','P41371','P41375'},['Average Global End-Century Warming']={'P41364','P41368','P41372','P41376'},['Has Ensemble Size']={'P41365','P41369','P41373','P41377'},['Mineral resources']='P41434',['Type of nanoparticles']='P41524',['Mechanism of Antiviral Action']='P41525',['Total N uptake (lower limit) (summer monsoon)']='P41466',['Total N uptake (upper limit) (summer monsoon)']='P41467',['Uptake rate unit']='P41468',['Mixed layer depth (meter) (lower limit)']='P41469',['Mixed layer depth (meter) (upper limit)']='P41470',['Uptake rate unit is different in paper']='P41471',['Argillized rock (nm)']='P41390',['Kaolinite ( Argillized rock) (nm)']='P41391',['Hematite (nm)']='P41392',['Silicified rock (Si-O) (nm)']='P41393',['Phyllite (Si-O) (nm)']='P41394',['Calcite (nm)']='P41396',['Si-O-H (nm)']='P41397',['Playa (nm)']='P41398',['Tuff (nm)']='P41399',['illite (nm)']='P41400',['Chlorite (nm)']='P41401',['Carbonate (nm)']='P41402',['Clay minerls (nm)']='P41403',['Learning method']='P41325',['Relationship learning']='P41326',['Phyllosilicates (nm)']='P41347',['Fe-OH bearing minerals (nm)']='P41348',['Mg-OH bearing minerals (nm)']='P41349',['Terms learning']='P41319',['Axiom learning']='P41320',['Properties learning']='P41321',['Properties hierarchy learning']='P41322',['Rule learning']='P41323',['Learning tool']='P41327',['Implemented framework']='P41328',['Application site']='P41330',['RDBM name']='P41331',['OWL type']='P41332',['Class hierarchy learning']='P41324',['Expressivity']='P41329',['Integrity constraints']='P41333',['Existing ontologies']='P41334',['Field instrument']='P41404',['Field work']='P41405',['Quartz (nm)']='P41406',['Actinol (nm)']='P41407',['Jarosite (nm)']='P41408',['Buddingtonite (nm)']='P41395',['Field data']='P41335',['Minerals mapped']='P41385',['Phyllite (nm)']='P41386',['Si-O (nm)']='P41387',['Alunite (Opalized rock) (nm)']='P41388',['Opalized rock (nm)']='P41389',['Institutions']='P41440',['Article']='P41313',['has a stage']='P41299',['has a subject domain']='P41300',['has dubject domain']='P41306',['has mentors']='P41309',['has research domain']='P41310',['Has evaluation task']='P41318',['Coastal ocean sampling']='P41378',['Open ocean sampling']='P41379',['Sampling depth covered (m)']='P41380',['Lower limit (total N uptake)']='P41381',['Upper limit (total N uptake)']='P41382',['Uptake rate HAS_UNIT']='P41383',['Uptake unit is different in paper']='P41384',['L1-L2 pairs']='P41428',['Colitis model']='P41315',['Structures and organisations']='P41453',['Processes']='P41454',['Roles and responsibilities']='P41455',['Unit of the particle size of nanoparticle']='P41314',['Processing']='P41207',['Water/hydrous (nm)']='P41208',['Ferric/hydroxides (nm)']='P41209',['Fayalitic olivine (nm)']='P41210',['Iron-magnesium smectites (nm)']='P41211',['Iron-rich nontronite (nm)']='P41212',['Magnesium-rich saponite (nm)']='P41213',['Ferrous (Fe-smectite clays / olivine) (nm)']='P41214',['Al-bearing phyllosilicates (Al-OH) (nm)']='P41222',['Opal (nm)']='P41223',['Dickite (nm)']='P41224',['Nanophase ferric oxide (nm)']='P41229',['Fine-grained olivine  (nm)']='P41230',['High calcium Pyroxene (nm)']='P41231',['Molecular water (nm)']='P41232',['Mg-Carbonate (nm)']='P41225',['Ca-Carbonate (nm)']='P41226',['Fe-Carbonate (nm)']='P41227',['Carbonates (nm)']='P41228',['Unaltered hydrated glass (nm)']='P41235',['Mono/polyhydrated sulfate mixture (nm)']='P41236',['Crystalline ferric oxide (hematite) (nm)']='P41237',['Water overtone (nm)']='P41238',['Absorbed water (nm)']='P41239',['Water ice (nm)']='P41233',['Carbon-di-oxide Ice (nm)']='P41234',['Users\' engagement']='P41240',['Number of perspectives']='P41241',['Museum involved']='P41242',['Language of smart objects\' description']='P41243',['Has number of user interactions']='P41246',['Has users\' engagement estimate']='P41244',['Has user interaction modality']='P41245',['Has number of perspectives']='P41247',['Technology architecture']='P41272',['Goethite (nm)']='P41336',['Gibbsite (nm)']='P41337',['Bauxite dominant laterite bauxite (nm)']='P41338',['Band ratio']='P41339',['Transport']='P41276',['Education, culture, innovation & science']='P41278',['Health, well-being & safety']='P41279',['Governance and citizen engagement']='P41280',['ICT']='P41281',['Natural environment']='P41273',['Built environment']='P41274',['Water and waste']='P41275',['Bandwidth (Hz)']='P41287',['has size of area to be renovated in sq.m.']='P41283',['Power (mW)']='P41288',['Temperature sensor type']='P41289',['Resolution/ noise (mg)']='P41290',['Sensitivity (mV/g)']='P41291',['Linearity range (g)']='P41292',['Link']='P41267',['Prototype extraction tool']='P41196',['Carbon footprint']='P41195',['has stakeholder']='P41259',['discusses method']='P41256',['performance title']='P41316',['dance group']='P41317',['Type of industry']='P41197',['Decision-making level']='P41199',['Energy aspect']='P41201',['Resolution methods']='P41203',['Interest in carbon emissions']='P41205',['museum collection']='P41251',['has pageviews']='P41248',['has subject domain']='P41249',['digtal resource observation length']='P41250',['OH stretch/overtone (nm)']='P41215',['Volcanic glass (nm)']='P41216',['Saponite (nm)']='P41217',['Montmorillonite (nm)']='P41218',['High-Fe chlorites (nm)']='P41219',['Mica minerals (illite and/or muscovite) (nm)']='P41220',['Kaolinite (nm)']='P41221',['ResearchGate ID']='researchGateID',['LinkedIn ID']='linkedInID',['Carbon print']='P41194',['Sensing material']='P41181',['Linear range (mM)']='P41183',['Limit of detection']='P41184',['Limit of detection (ppm)']='P41185',['Minimum experimental range']='P41186',['Maximum experimental range']='P41187',['Sensing environment']='P41188',['Maximum experimental range (ppm)']='P41189',['Minimum experimental range (ppm)']='P41190',['Type xml document']='P41191',['has cross-border region']='P41253',['heritage site']='P41262',['Learning purpose']='P41193',['RDF Graph']='P41192',['Data architecture']='P41270',['has sources']='P41257',['type of contested heritage']='P41258',['Positioning in the logistics chain']='P41198',['Type of process']='P41200',['Muscovite']='P41266',['VUVS']='P41180',['Plasma_discharge']='P41179',['VUV']='P41156',['Input_power']='P41157',['Unit_input_power']='P41158',['Unit_frequency']='P41159',['Feed_gases']='P41160',['Ambient_atmosphere']='P41161',['Te']='P41162',['Unit_Te']='P41163',['Ne']='P41164',['Unit_Ne']='P41165',['OES']='P41166',['Gas _flow _rate']='P41167',['Unit_gas_flow_rate']='P41168',['T_gas']='P41169',['Unit_gas']='P41170',['Part_density{O,N,OH,O_3,Ar*}']='P41171',['Unit_part_density']='P41172',['PROES']='P41173',['TALIFF']='P41174',['OAS']='P41175',['Mass spectrometry']='P41176',['Unit_wllow']='P41177',['Unit_wlup']='P41178',['Google Scholar ID']='googleScholarID',['Illite']='P41265',['has smart city isntance']='P41293',['has smart city instance']='P41294',['Plagioclase-1 (cm-1)']='P41099',['Plagioclase-2 (cm-1)']='P41100',['RE-Whitlockite-2(cm-1)']='P41101',['Clinopyroxene-3 (augite) (cm-1)']='P41102',['Pyroxene-1 (cm-1)']='P41103',['Pyroxen3 (cm-1)']='P41104',['Orthopyroxene-4 (cm-1)']='P41105',['Plagioclase-4 (cm-1)']='P41106',['RE-Whitlockite-1 (cm-1)']='P41107',['Clinopyroxene (augite)-1 (cm-1)']='P41108',['Epoxy resin (cm-1)']='P41109',['Baddeleyite (cm-1)']='P41110',['Apatite (cm-1)']='P41111',['Quartz-2 (cm-1)']='P41112',['Cristobalite-1(cm-1)']='P41113',['Cristobalite-2 (cm-1)']='P41114',['Plagioclase-3 (cm-1)']='P41115',['Anorthite (cm-1)']='P41116',['Agglutinates-2 (Glass) (cm-1)']='P41117',['ilmenite (cm-1)']='P41118',['K-Feldspar-2 (cm-1)']='P41119',['Quartz-1 (cm-1)']='P41120',['Pigeonite (cm-1)']='P41121',['Business architecture']='P41206',['Reused model']='P41146',['materal']='P41263',['has communication channel']='P41264',['Ontology name']='P41128',['Upper-level ontology']='P41129',['Reused ontology']='P41130',['Safety and risk management level']='P41140',['Environmental level']='P41141',['Ontology availability']='P41142',['Technology level']='P41136',['Administration level']='P41137',['Service level']='P41138',['Ontology file availability']='P41143',['Type of inorganic nanoparticles']='P41150',['Agent level']='P41144',['Other levels']='P41145',['Application architecture']='P41271',['Workshop type']='P41202',['Carbon emission']='P41204',['High Calcium Pyroxene (HCP-nm)']='P41078',['Study cohort']='P41147',['Outcome assessment']='P41148',['Aims']='P41149',['Samples source']='P41079',['Techniques/ Analysis']='P41080',['Excitation Frequency/Wavelngth (nm)']='P41081',['Grain size (mm)']='P41082',['Raman Stokes-shift range (cm-1)']='P41083',['Raman-spectral resolution (cm-1)']='P41084',['Infrared range (cm-1)']='P41085',['Rock type']='P41086',['Olivine-2 (cm-1)']='P41087',['Orthopyroxene-3 (cm-1)']='P41088',['Clinopyroxene-2 (augite) (cm-1)']='P41089',['Pyroxene-2 (cm-1)']='P41090',['Pyroxene-4 (cm-1)']='P41091',['Agglutinates-1 (Glass) (cm-1)']='P41092',['Agglutinates-3 (Glass) (cm-1)']='P41093',['Relavance']='P41094',['K-Feldspar-1 (cm-1)']='P41095',['Olivine-1 (cm-1)']='P41096',['Orthopyroxene-1 (cm-1)']='P41097',['Orthopyroxene-2 (cm-1)']='P41098',['spatial level']='P41131',['Physical level']='P41132',['Socio-economic level']='P41133',['Activity level']='P41134',['Information level']='P41135',['Transportation level']='P41139',['Research_objective']='P41151',['Research_plan']='P41152',['Spec_wllow']='P41153',['Unit_spec']='P41154',['Spec_wlup']='P41155',['Mission']='P41041',['Launch Year']='P41042',['Instrument']='P41043',['Spectral range (nm)']='P41044',['Spectral resolution-VNIR (nm)']='P41045',['Spectral resolution-SWIR (nm)']='P41046',['Imager/ Non-Imager']='P41047',['Spatial resolution (m)']='P41048',['No. of Bands']='P41049',['No. of datasets']='P41050',['Swath (km)']='P41051',['Low Calcium Pyroxene (LCP-nm)']='P41052',['Olivine (nm)']='P41053',['Pyroxene (nm)']='P41054',['Plagioclase (nm)']='P41055',['Orthopyroxene (nm)']='P41056',['Clinopyroxene (nm)']='P41057',['Reference data']='P41058',['Swath']='P41059',['Ferrous (nm)']='P41060',['High Alumina basalt (nm)']='P41061',['High Calcium Pyroxene (LCP-nm)']='P41062',['Mafic Silicate (nm)']='P41063',['Fe-rich spinels (nm)']='P41064',['Cr/Fe-rich spinels (nm)']='P41065',['Mg-rich spinels (nm)']='P41066',['Elemental abundance maps']='P41067',['Total sampling stations']='P41068',['Lower limit (integrated primary production)']='P41069',['Upper limit (integrated primary production)']='P41070',['Unit (integrated primary production)']='P41071',['Primary production unit is different in paper']='P41072',['Lower limit (primary production)']='P41075',['Upper limit (primary production)']='P41076',['Unit (primary production)']='P41077',['uses Recommendation approach']='P41034',['Exploited data']='P41039',['Surfactant']='P41000',['Piezoresistive Material']='P41021',['Response time (ms)']='P41022',['Average primary production']='P41073',['Unit (average primary production)']='P41074',['Addresses Smart city Action']='P41029',['Technology type']='P41284',['Heater material']='P41285',['Working fluid']='P41286',['Knowledge source']='P41002',['Sensitivity of the glucose biosensor (mA/cm². mM)']='P41182',['has Implementation level']='P41040',['Has Datasets']='P41003',['LPR Channel used(MHz)']='P41004',['Correction methods']='P41005',['Preprocessing']='P41006',['Structural Information']='P41007',['Sensitivity (/kPa)']='P41023',['Ontology construction']='P41001',['addresses Smart city action']='P41027',['has Target users']='P41032',['has Recommended items']='P41033',['Layer']='P41008',['Average Thickness (m)']='P41009',['Density (g/cm^3)']='P41010',['Average Permittivity (Ch-4)']='P41011',['Validation']='P41012',['Datatype']='P41013',['Total datasets (Channel-2)']='P41014',['Avg. Dielectric constant']='P41015',['LPR Channel used (MHz)']='P41016',['Average Permittivity (Ch-3)']='P41017',['Relative Permittivity (Ch-3)']='P41018',['Relative Permittivity (Ch-4)']='P41019',['Total datasets (Channel-1)']='P41020',['Number of RDF triples ']='P37035',['Number of RDF Datasets']='P37036',['Is based on Explicit User Preferences']='P41037',['Is based on Implicit User Preferences']='P41038',['has Data Source']='P41031',['Ideality factor']='P40057',['Electrical contacts']='P40058',['Nanoparticles preparation method']='P40059',['uses Recommendation Method']='P41035',['has Impact type of Indicators, share']='P40064',['is based on User Preferences Type']='P41036',['has been evaluated in the City']='P41024',['has been evaluated in the Country']='P41025',['has Application Scope']='P41030',['belongs to Smart City Dimension']='P41026',['helps achieve Smart city Goal']='P41028',['ZnO film deposition method']='P40048',['resource:city']={'P40040','P40033'},['Structure of the diode']='P40041',['Qeury']='P40066',['Intended_Application']='P40049',['Excitation_type']='P40050',['Excitation_frequency']='P40051',['Feed_gas']='P40052',['Gas _flow _rate[slm]']='P40053',['Input_power[W]']='P40054',['Specific Energy Density[J/L]']='P40055',['Temperature[K]']='P40056',[' Rectification ratio (RR) ']='P40044',['Series resistance, Rs (Ohm)']='P40045',['has contribution type']='P40065',['Voltage (V)']='P40047',['Conventional']='P40036',['ZnO thickness (nm)']='P40043',['Barrier height (eV)']='P40046',['resource:occupant presence or actions']='P40032',['has Input type of indicators, share']='P40060',['has Process type of indicators, share']='P40061',['has Output type of Indicators, share']='P40062',['has Outcome type of Indicators, share']='P40063',['Support statistics']='P40025',['Cristobalite-1 (cm-1)']='P41127',['resource:climate zone (köppen-geiger)']='P40034',['Renewables']='P40035',['Clinopyroxene (augite)-3 (cm-1)']='P41122',['Clinopyroxene(augite)-2  (cm-1)']='P41123',['Clinopyroxene (augite)-2 (cm-1)']='P41124',['Pyroxene-3 (cm-1)']='P41125',['Excitation Frequency/Wavelength (nm)']='P41126',['Has_sample_size']='P40000',['Type_of_sample']='P40001',['Has_result']='P40002',['ZnO dopant']='P40042',['Unnamed: 0']='P40067',['HAS_VENUE']='P40068',['Extraction methods']='P40003',['recognition type']='P130001',['Electricity']='P40037',['Gas']='P40038',['Heat']='P40039',['Hidden-Markov Models']='P40004',['Type of transformation']='P40021',['Silicates Position (nm, Thermal Terrestrail Samples)']='P40023',['Silicates Position (nm, Raman Terrestrial Samples)']='P40010',['Carbonates position (nm, Mid-Infrared Terrestrial Samples)']='P40011',['R136288']='P39142',['R136290']='P39143',['R136292']='P39144',['R136306']='P39145',['R136308']='P39146',['R136310']='P39147',['Iron Position (nm, VNIR-SWIR Terrestrial Samples)']='P40009',['Pyroxene position (nm, Mid-Infrared Lunar Samples)']='P40012',['Minerals Identified (Terrestrial samples)']='P40008',['Olivine position (nm, Mid-Infrared Lunar Samples)']='P40016',['Pyroxene (nm, VNIR-SWIR Lunar Samples)']='P40017',['has components for power generation or conversion']='P39150',['has components for transfer, infrastructure or grid']='P39151',['Has components for storage']='P39152',['Photoredox catalyst']='P40018',['Main_manipulation_of_interest']='P39156',['number of results']='P39157',['mean value']='P39158',['Particle size of nanoparticles (nm)']='P39140',['Terms extraction']='P39127',['Properties extraction']='P39128',['Class hierarchy extraction']='P39129',['Properties hierarchy']='P39130',['Axiom extraction/learning']='P39131',['Rule extraction/learning']='P39138',['Concepts extraction']='P39123',['Individual extraction']='P39124',['Concepts learning']='P39125',['Individual learning']='P39126',['has source code']='HAS_SOURCE_CODE',['Class hierarchy extraction/learning']='P39132',['Concepts extraction/learning']='P39133',['Individual extraction/learning']='P39134',['Properties extraction/learning']='P39135',['Properties hierarchy extraction/learning']='P39136',['Terms extraction/learning']='P39137',['Ontology type']='P39139',['Time (hours)']='P40022',['Preprocessing required']='P40005',['Minerals identified (Lunar rock samples)']='P40007',['Ferrous/Ferric ion Position']='P40006',['occupant presence or actions']='P40026',['climate zone (köppen-geiger)']='P40027',['stochastic opa models: general/generalized linear model']='P40028',['stochastic opa models: probit analysis']='P40029',['data-driven models: gradient boosting']='P40030',['data-driven models: naive bayes']='P40031',['has file format']='P39148',['Plagioclase position (nm, Mid-Infrared Lunar Samples)']='P40013',['Silicates Position (nm, Raman Lunar Samples)']='P40014',['Iron Position (nm, VNIR-SWIR Lunar Samples)']='P40015',['geometric mean']='P39159',['has_analysis_approach']='P39153',['has link to user documentation']='P39154',['has link to developer documentation']='P39155',['has main specific properties']='P39100',['Taxonomic group studied (Biology)']='P39090',['Order (Taxonomy - biology)']='P39091',['No. of samples (sequences)']='P39092',['Class (Taxonomy - biology)']='P39093',['Additive']='P40019',['Mechanism']='P40020',['threat to validity']='P39099',['Type of Lipid-based nanoparticle']='P39088',['Uses Lipid ']='P39089',['Is used in framework']='P39149',['Descriptive-Comparative questions']='P39096',['has further properties']='P39101',['Has validation']='P39103',['is used by institution']='P39102',['Models technology']='P39104',['has temporal resolution']='P39105',['has electrical grid properties']='P39107',['Models user behaviour']='P39108',['Models demand side management']='P39109',['Silicates Position (nm, Thermal Terrestrial Samples)']='P40024',['Maximum efficiency of the solar cell  (%)']='P39117',['Time to acceptance (days)']='P39116',['Organisations']='P39115',['Particle size of nanoparticles']='P39113',['Drug entrapment efficiency (%)']='P39114',['studied taxonomic group (Biology)']='P39141',['Area of the solar cell (cm2)']='P39118',['Fill factor, FF (%)']='P39119',['Open circuit voltage, Voc (V)']='P39120',['Number of instances']='P39021',['has simulation approach']='P39030',['has exemplary research question']='P39031',['Existence questions']='P39094',['Description and Classification questions']='P39095',['Information and communications technology (ICT)']='P39066',['Environmental sustainability']='P39067',['Productivity']='P39068',['has methodical focus']='P39032',['has contact person']='P39033',['has number of developers']='P39036',['has number of users']='P39037',['has support']='P39034',['based on framework']='P39035',['Applied pressure range (kPa)']='P39064',['Accessible transport system for all']='P39072',['Participatory and Inclusive urbanization']='P39073',['World’s cultural and natural heritage protection']='P39074',['Protection of the poor and people in vulnerable situation']='P39075',['Capital enviromental impact of cities reduction']='P39076',['Access to safe and inclusive public space']='P39077',['Urban-rural linkagesages']='P39078',['Implementation of mitigation and adaptation plans and policies']='P39079',['Countries with existing local disaster reduction stratergy']='P39080',['Sustainable and resilient buildings']='P39081',['End poverty in all its forms everywhere']='P39082',['Nanomaterial layer thickness']='P39045',['Nanomaterial layer thickness (nm)']='P39046',['ZnO nanomaterial layer thickness (nm)']='P39047',['Method of nanomaterial synthesis']='P39039',['Piezoelectric coefficient measured']='P39040',['Piezoelectric coefficient measured (pm/V)']='P39041',['Piezoelectric measurements']='P39042',['ZnO form']='P39038',['Device performance']='P39043',['Device structure']='P39044',['Reponse time (ms)']='P39060',['Detection limit (Pa)']='P39061',['Loading-unloading cycles']='P39062',['Potential application of the sensor']='P39063',['Software development approach']='P39065',['Evaluation methods']='P39048',['Personalisation features']='P39049',['Structure of the sensor']='P39058',['Sensibility of the pressure sensor ( /kPa)']='P39059',['Empirical truth']='P39097',['Empirical truth stances']='P39098',['Related links']='P39050',['Has observation period']='P39106',['Models changes in efficiency']='P39110',['Includes market model']='P39111',['AUC']='P39057',['Test data']='P39051',['Reuse of existing vocabularies']='P39052',['Number of properties']='P39006',['Short-circuit current density, Jsc (mA/cm2)']='P39122',['Memory']='P39007',['Test related data']='P39056',['has typical computation time']='P39028',['has typical computation hardware']='P39029',['HasOpenness']='P39010',['HasModelIntegration']='P39011',['HasInterface']='P39012',['Has model file format']='P39013',['is integrated into model']='P39014',['integrates model']='P39015',['hasMathematicalProperty']='P39008',['hasBasicInformation']='P39009',['Quality of life']='P39069',['Equity and social inclusion']='P39070',['Physical infrastructure']='P39071',['Solar cell structure']='P39121',['has technical data anchored in the model']='P39026',['Material of the cantilever']='P39016',['Structure of the biosensor']='P39017',['Biosensor working principle']='P39018',['Theoretical analysis performed']='P39019',['Steps']='P39020',['Alligned with FAIR principles']='P39053',['Development in']='P39054',['Online data availability']='P39055',['Mode of Transportation']='P39022',['is suited for many scenarios or Monte Carlo']='P39025',['has computational requirements']='P39027',['Has further dimension']='P39112',['Counterion']='P39083',['Counterion interaction in DCM']='P39084',['Counterion interaction in Toluene']='P39085',['BLA (pm)']='P39086',['BLA evaluation method']='P39087',['Supports owl:sameAs Inference']='P37037',['Available tools']='P37076',['has_kind_of_messages']='P37038',['has_kind_of_appeal']='P37039',['Pages']='P37139',['has parameters']='P37148',['Uses (RBL) blacklists ']='P37131',['δ15N (surface PON)']='P37218',['https://doi.org/10.1186/s12544-021-00469-3']='P37040',['Metamodel revenue model & performance']='P37066',['Integration with other architectures']='P37067',['evaluates']='P37290',['Family']='P37587',['Species ']='P37588',['Ploidy of sexuals']='P37589',['Ploidy of apomicts']='P37590',['Ecological differentiation']='P37591',['Has prognostic sea ice variable']='P37061',['Has prognostic land ice model variable']='P37062',['Study Area']='P37041',['Spectral features']='P37042',['Methodology maturity']='P37074',['Availible tools']='P37075',['size of the Dataset']='P37660',['The impacts of spent engine oil on the growth performance of Okra and remediation effect of organic (poultry droppings) nutrient supplements are not properly documented in Akwa Ibom State.']='P37055',['Scale-up']='P37579',['No written documentation on the phytochemicals, median lethal dose, anti-inflammatory, and analgesic properties of the ethanolic extract of Eryngium foetidum leaves in experimental animals']='P37043',['Little or no information on the use of Cucurbita pepo to management anaemia']='P37044',['Information on the effects of ethanolic extract of Musa acuminata on haemopoietic parameters on the experimental rats are not properly documented']='P37047',['Document regarding haematological studies of Sesamum indicum leaves are scanty; hence the present study was evaluated']='P37045',['Reports regarding haematological studies of Uvaria chamae leaves are scanty; hence the present study was evaluated']='P37046',['The knowledge of S. media leaves in traditional medicine practitioners of its efficacy in treating anaemia is lacking']='P37051',['Validation of the anti-hyperglycemic effect of Dioscorea bulbifera cherished by many Nigerians as a delicacy in food accompliments']='P37048',['Research on bioaccumulation potentials of three (3) varieties of Manihot esculenta with regard to the six (6) heavy metals studied, using their leaf tissues are challenging']='P37049',['Investigation of organic and inorganic amendments of soil properties on the growth and yield components of two varieties of okra in University of Uyo Botanical Garden was not properly recorded']='P37050',['Information concerning drought stress in Vigna unguiculata during the growing stage in University of Uyo are lacking']='P37053',['Treatment of Diabetes by traditional medicine practitioners using Musa acuminata in Akwa Ibom State is not well documented']='P37052',['The nutritional and medicinal values of Sterculia tragacantha and Sesamum indicum are not well recorded in Akwa Ibom State.']='P37059',['The anti-hyperglycemic effect of Pleurotus ostreatus mushroom cherished by many Nigerians as a delicacy in soup condiment is not well recorded in Akwa Ibom State']='P37054',['No data documentation on ethanolic root extract of Baphia nitida in the treatment of anaemia in Akwa Ibom State']='P37058',['Nephrolepis biserrata are used by Akwa Ibom State indigenes to cure inflammation and pains and are not well documented']='P37056',['Anti-hyperglycaemic effect of Terminalia ivorensis leaf by traditional medicine practitioners in Akwa Ibom State are not well reported.']='P37057',['Hardware']='P37658',['Has Dataset size']='P37659',['Information regarding the bioactive components of Luffa aegyptiaca Leaf, Stem and Flowers are not properly documented']='P37060',['Technology and infrastructure']='P37129',['KM culture']='P37130',['estimated ROS intracellular level ']='P37442',['molecules detected by immunocytochemistry ']='P37567',['Peptide:Lipid effective ratio']='P37234',['Classifier accuracy']='P37119',['Organizational processes, which requires knowledge']='P37120',['Knowledge and its status']='P37123',['Thermal Resistance of Borehole']='P37341',['2020']='P37444',['implemented in']='P37644',['Metamodel maturity']='P37068',['Methodology structured procedure model']='P37071',['Methodology use case scenarios']='P37072',['Methodology best practices / reference models']='P37073',['Metamodel strategy and structure']='P37063',['Metamodel business network']='P37064',['Metamodel operations']='P37065',['Different salt tolerance of Cucurbita maxima during germination and early seedling growth in University of Uyo environment was not recorded.']='P37109',['Methodology development of BA model']='P37069',['Methodology management BA initiatives']='P37070',['is abbreviation of']={'P37077','P37079'},['has license']={'P37078','P37080'},['Has (Best )performance']='P37656',['Deepest Spectral feature']='P37081',['Atmospheric correction model']='P37082',['Geometric Correction']='P37083',['Data Dimensionality Reduction Methods']='P37084',['End Member Extraction Techniques']='P37085',['Priori Knowledge of Study Area']='P37086',['Spectral Mapping Technique']='P37087',['Ferrous (Iron) Band Position']='P37088',['Mineral Map Available']='P37089',['Minerals Mapped/ Identified']='P37090',['Comparisons']='P37091',['Software Used']='P37092',['Band Parameters']='P37093',['Removal of Bad Bands and De-striping']='P37094',['Deepest Spectral feature (µm)']='P37095',['Ferrous (Iron) Band Position (µm)']='P37096',['Deepest Spectral feature (�m)']='P37097',['Ferrous (Iron) Band Position (�m)']='P37098',['Niobate Co-Catalyst']='P37654',['Deepest Spectral feature (nm)']='P37099',['Ferrous (Iron) Band Position (nm)']='P37100',['Study Area ']='P37101',['Mineralogy']='P37102',['De-striping']='P37103',['Band Band Removal']='P37104',['Bad Bands Removal']='P37105',['Citations']='P37107',['Citation']='P37106',['Phytochemical properties and antidiabetic effect of the Newbouldia laevis ethanolic leaf extract on Albino Rats collected from University of Uyo Botanical Garden was not documented.']='P37108',['Has Citations']='P37113',['Has Maps']='P37114',['Has study area']='P37116',['Phytochemical and Anti-bacterial Activities of Brachystegia eurycoma Seed Extract in Uyo, part of Akwa Ibom State are not well reported.']='P37110',['Has Priori Knowledge']='P37115',['Has band parameters']='P37117',['Different salts supplemented with nutrients amendment as affected growth morphology of Cucurbita melo in-vitro in University of Uyo were not properly documented.']='P37111',['No available information on the cultivation of two Varieties (White and Brown) Grown Under Salinity Stress']='P37112',['AG R']='P37178',['Has Mineralogy']='P37118',['Processes (knowledge activities applied and embedded within organizational processes)']='P37128',['has parameter']='P37147',['Products and services, which requires knowledge']='P37121',['KM objectives']='P37122',['AG 4HG1']='P37176',['AG HG4III']='P37177',['Stages of knowledge development']='P37124',['Types of knowledge flows']='P37125',['Activities, behaviours, means [for knowledge development and/or for knowledge conveyance and transformation']='P37126',['Human capital (Roles and accountabilities, KM stakeholders)']='P37127',['BibliographyType']='P37133',['Type of MOOC']='P37149',['Venue']='P37334',['Has antimicrobial properties']='P37232',['chosen by']='P37185',['Open/coastal ocean']='P37217',['Has Developer']='P37132',['Identifier']='P37134',['Journal']='P37135',['Annote']='P37136',['Custom1']='P37137',['Custom3']='P37138',['ISBN']='P37140',['Address']='P37141',['Booktitle']='P37142',['Publisher']='P37143',['Howpublished']='P37144',['Note']='P37145',['Editor']='P37146',['Maximum intraspecific distances averaged']='P37282',['nearest neighbor distance averaged']='P37283',['lower nearest neighbor distance']='P37284',['mutation']='P37231',['MOOC Period']='P37150',['Sruvey participants']='P37151',['has experiment']='P37152',['Student pass rates']='P37154',['Student pass rates %']='P37155',['Type of analysis']='P37153',['guided analytics']='P37156',['Interactive Visualisation']='P37157',['social media']='P37158',['decentralized system']='P37159',['Genetically modified organisms']='P37164',['AG A']='P37174',['AG 3-PT']='P37175',['Rhizoctonia solani']='P37165',['Anastmosis groups']='P37166',['Binucleate Rhizoctonia']='P37167',['AG 3']='P37168',['AG4']='P37169',['AG 2.1']='P37170',['AG 4IIB']='P37171',['AG 5']='P37172',['AG 2.2IIIB']='P37173',['AG K']='P37179',['AG F']='P37180',['AG 1']='P37181',['AG U']='P37182',['AG I']='P37183',['Anastomosis groups']='P37184',['tool availability']='P37291',['Lower limit (nitrogen fixation rates)']='P37338',['Upper limit (nitrogen fixation rates)']='P37339',['Unit (nitrogen fixation rates)']='P37340',['Neutraceuticals present in Microdesmis puberula and Bombax buonopozense has not been properly established and documented as an alternative dietary sources of food in Akwa Ibom State, Nigeria.']='P37186',['Alleviatory effect of Calopogonium muconoides and Aspilia africana compost the growth and neutraceutical composition of C. maxima has not been reported in Akwa Ibom State, Nigeria.']='P37187',['The influence of inoculating two vegetables: Telfairia occidentalis and Cucurbita maxima with arbuscular mycorrhiza (Rhizophagus irregularis and Glomus geosporum) with poultry manure in Na+ / K+ ratio adjustment and plant mineral nutrition is not properly recorded.']='P37191',['The potential use of Arbuscular Mycorrhizal Fungi (AMF) as a buffer to mitigate phytoextraction of heavy metals by C. maxima from soils contaminated with crude oil in Akwa Ibom State has not been properly documented.']='P37188',['Reports regarding nutraceutical studies on these aquatic plants are scanty, hence the present study was conducted.']='P37193',['Phytochemical screening (quantitative) and antidiabetic effect of the T. conophorum ethanolic leaf extract on albino rat has no record in Akwa Ibom State.']='P37189',['The impacts of Rhizophagus irregularis on the biomass and physiological attributes of C. maxima through morphological and physiological vicissitudes and improved vigour to survive under severe salt stress conditions has not been documented.']='P37190',['Reports regarding nutraceutical studies on these aquatic plants are scanty, hence the present study was conducted']='P37192',['Ocean']='P37216',['Locus']='P37257',['Locus (genetics)']='P37258',['Experiment 1']='P37194',['Experiment 2']='P37195',['Season']='P37196',['Method (nitrogen fixation rate)']='P37197',['Method (primary production)']='P37198',['Incubation time']='P37199',['No. of sampling stations']='P37200',['Sampling depth covered']='P37201',['Water column zone']='P37202',['Deep chlorophyll maxima (DCM) depth']='P37203',['Mixed layer depth (MLD)']='P37204',['Sea surface temperature (SST)']='P37205',['Sea surface salinity (SSS)']='P37206',['Wind speed']='P37207',['N:P i.e., [NO3- + NO2-]:[PO43-]']='P37208',['Region N depleted/replete']='P37209',['δ15N']='P37210',['Nitrogen fixation rate']='P37211',['Depth integrated nitrogen fixation rate']='P37212',['Primary production']='P37213',['Depth integrated primary production']='P37214',['Contribution of nitrogen fixation to primary production']='P37215',['contribution:research_aplication']='P37219',['contribution:VUVSpec_wllow[nm]']='P37220',['contribution:VUVSpec_wlup[nm]']='P37221',['contribution:VUVSpec_detector']='P37222',['contribution:VUVSpec_collection']='P37223',['contribution:VUVSpec_Calibration']='P37224',['contribution:VUVSpec_CalibrationMode']='P37225',['contribution:Plasma_Type']='P37226',['contribution:Plasma_Pressure']='P37227',['contribution:Plasma_Gases']='P37228',['contribution:Plasma_TeUp[eV]']='P37229',['contribution:Plasma_Ne[cm-3]']='P37230',['Status of municipal water supply']='P37254',['VUVSpec_irradiance (s^-1 x cm^-2) x 10^15']='P37255',['Molecular Mechanism']='P37233',['paper:journal']='P37235',['research_target']='P37236',['VUVSpec_wllow[nm]']='P37237',['VUVSpec_wlup[nm]']='P37238',['VUVSpec_detector']='P37239',['VUVSpec_collection']='P37240',['VUVSpec_Calibration[Y/N]']='P37241',['VUVSpec_CalibrationMode']='P37242',['Plasma_Type']='P37243',['P_Ne_1[cm-3]']='P37244',['P_Ne_2[cm-3]']='P37245',['VUVSpec_irradiance$$(s^{-1}cm^{-2} times 10^{15}$$']='P37246',['P_Gases']='P37247',['P_Pressure_1[Pa]']='P37248',['P_Pressure_2[Pa]']='P37249',['P_Te_1[eV]']='P37250',['P_Te_2[eV]']='P37251',['Insufficient data on the effect of crude oil pollution of soil on growth parameters of cassava.']='P37252',['Data split']='P37253',['Biogeographical region']='P37256',['Phylum (Taxonomy)']='P37261',['Class (Taxonomy)']='P37262',['Phylum (Biology)']='P37266',['Effect concentration']='P37278',['Effect concentration in micromolar']='P37279',['DNA sequencing method']='P37259',['Order (Taxonomy)']='P37263',['Phylum']='P37260',['Exposure vessel']='P37277',['Taxonomic group (Biology)']='P37264',['Order (Biology)']='P37265',['Geographic scale']='P37280',['Geographic scale (Km2)']='P37281',['Class (Biology)']='P37267',['No. of species']='P37268',['Taxonomic group (Taxonomy)']='P37269',['No. of potential undescribed species']='P37270',['higher number estimated species']='P37271',['higher number estimated species (Method)']='P37272',['No. of estimated species']='P37273',['No. of estimated species (Method)']='P37274',['lower number estimated species']='P37275',['lower number estimated species (Method)']='P37276',['Apnea-hypopnea index']='P37532',['the reasons which drive variations in hill coeffcient if found']='P37533',['nearest neighbor distance lower limit']='P37285',['nearest neighbor distance upper limit']='P37286',['Maximum intraspecific distances lower limit']='P37287',['Maximum intraspecific distances upper limit']='P37288',['No. of idientified species with current taxonomy']='P37289',['Data Dimensionality Reduction Technique']='P37292',['Minerals/ Feature Mapped']='P37293',['Priori Knowledge about study area']='P37295',['The rate at which religious activities was practised during COVID-19 lockdown in the southwestern Nigeria does not suggest strict compliance to COVID-19 preventive measures. However, the findings of the study revealed strict compliance']='P37302',['Peptide:lipid ratio']='P37303',['Experiment name']='P37315',['Sampling year']='P37316',['Sampling period']='P37317',['Sampling stations']='P37318',['Coastal/open ocean']='P37319',['Experiment approach']='P37320',['Against']='P37344',['Atmospheric Correction required']='P37294',['Bioactive compounds']='P37309',['Encapsulation efficiency']='P37296',['Particle diameter (average)']='P37297',['Zeta potential']='P37298',['Minium Peptide:Lipid ratio']='P37299',['Minimum peptide:lipid ratio']='P37300',['Maximum peptide:lipid ratio']='P37301',['The type and quality of housing units in informal settlements affected mental health of residents.The findings of the study revealed that most occuring mental health problems were anxiety, depression, stress,sleeping problem and substance abuse']='P37304',['The general notion is that the installation of Close-Circuit Television (CCTV) in gated communities can forestall crime, nonetheless, its vicious anticipated capacities is not certain']='P37305',['data collection']={'P37308','P56008'},['Econometric model']='P37306',['supported data modelling language']='P38000',['Number of dependent variables']='P37307',['Aims and Objectives']='P37332',['Uses drug']='P37578',['IC50']='P37310',['Inhibition Constant']='P37311',['Identified Factors ']='P37312',['Location ']='P37537',['Analyzed Number of Publications']='P37313',['Future Challenges']='P37314',['Incubation period (hours)']='P37321',['Method (nitrogen fixation rates)']='P37322',['Nitrogen fixation rates']='P37323',['Surface nitrogen fixation rates']='P37324',['Depth integrated nitrogen fixation rates']='P37325',['Surface primary production']='P37326',['N:P i.e., [NO3 + NO2]:[PO4]']='P37327',['Delta15N (of surface PON)']='P37328',['Principal producing species']='P37423',['Major cations']='P37457',['Major anion']='P37458',['Control conditions']='P37348',['has class']='P37647',['optimal level of non wheat flour']='P37574',['qPCR n value ']='P37483',['water-cement ratio']='P37329',['Complexity']='P37596',['research  question ']='P37330',['ethanol exposure']='P37331',['Research Area']='P37333',['Software name']='P37360',['Impact Factor']='P37335',['neutron spectrum']='P37356',['nuclear reactor coolant']='P37357',['Nuclear reactor name']='P37361',['Change in species richness']='P37350',['usesExogenousTimeSeries']='P37585',['Scale']='P37598',['Yield']='P37413',['Has bound calculations']='P37501',['Has the time complexity']='P37502',['View existing property: Can be used to find the group of size k with the highest GBC in a given network']='P37506',['Methodology scope_Management of BA initiatives']='P37497',['Uses RDF store']='P37342',['Metamodel Integration with other architectures']='P37449',['Has type']='P37343',['Experimental treatment']='P37347',['Paricle size of nanoparicles']='P37402',['Carbon source concentration (% w/v)']='P37417',['Physical space size']='P37420',['Nitrogen source concentration (% w/v)']='P37422',['Publication date']='P37345',['Publication location']='P37346',['Degree of warming (degrees C)']='P37349',['Change in vegetation cover']='P37351',['Change in vegetation biomass']='P37352',['Bibliographic data source']='P37353',['Scientific network(s)']='P37354',['Social network analysis']='P37355',[' Block oriented dynamic query plan generation']='P37378',['Brain Imaging modality']='P37372',['Brin imaging modality']='P37379',['Nuclear reactor type']='P37362',['Area of study']='P37364',['3D modeling']='P37359',['2D modeling']='P37358',['experimental facility']='P37363',['hasEmpricialData']='P37583',['Number of cognitive states']='P37373',['Number of subjects considered for the analysis']='P37374',['Average classification accuracy']='P37375',['Machine learning classifier used']='P37376',['Classification scheme']='P37377',['Change in species richness due to warming']='P37366',['Change in vegetation biomass due to warming']='P37367',['Change in vegetation cover due to warming']='P37368',['Change in species richness due to warming (%)']='P37369',['Change in vegetation cover due to warming (%)']='P37370',['Change in vegetation biomass due to warming (%)']='P37371',['Number of cognitive tasks']='P37380',['refered to as']='P37455',['What drive variation (if applicable)?']='P37456',['source of ion']='P37459',['Actuation Method']='P37381',['Fabrication methods']='P37382',['System components']='P37383',['Software']='P37386',['Levelized cost of energy']='P37387',['System location']='P37384',['Optimization method']='P37385',['Solver']='P37388',['Polymer FDA approval']='P37394',['IC50 of Drug loaded nanoparticles']='P37396',['unanimity principle']='P37397',['Analysis']='P37450',['Contributation-1']='P37451',['Contributation-2']='P37452',['Model Prediction']='P37453',['Curve fitting']='P37454',['Poly dispercity index (PDI)']='P37403',['Drug entrapment efficiency']='P37404',['Biodegredable or organic polymer']='P37393',['Cytotoxicity assay']='P37395',['Polymer charachterisation']='P37400',['Nanoparicles preparation method ']='P37401',['Nanoparticle visualisation']='P37407',['Isolation source']='P37414',['IC50 of Drug solution']='P37398',['Biodegredable or inorganic polymer']='P37399',['has  drug release studies']='P37408',['Critical micelle concentration (CMC)']='P37405',['Drug loading']='P37406',['Carbon source']='P37411',['Time to acceptance']='P37416',['Incubation time in hours']='P37419',['Principal producing strain']='P37409',['LD50 of Drug solution']='P37410',['Nitrogen source']='P37412',['Histopathological analysis']='P37415',['Furniture setting']='P37421',['Orgsnisations']='P37418',['Yield percentage (CDW)']='P37424',['User roles']='P37428',['Film deposition method']='P37433',['Material structure']='P37431',['Device type']='P37432',[' Film structure']='P37434',['reasons that drive variations in hill coeffcient if found']='P37503',['median mHLA-DR expression in ICU patients at admission']='P37463',['Metamodel scope_Revenue model and performance']='P37488',['median mHLA-DR expression in ICU patients at day 20']='P37493',['funder']={'P37436','wikidata:P8324'},['conducted ELISA']='P37437',['Western blot']='P37438',['number of references']={'P37439','wikidata:P10676'},['Data presentation']='P37440',['qPCR statistical analysis ']='P37441',['used Western blot']='P37443',['2017']='P37445',['calculated']='P37447',['Correlation Coefficient']='P37448',['Processor']='P37634',['Treatment given to patients for sleep apnea']='P37527',['Risk factors for OSA']='P37528',['Treatment given to patients for OSA']='P37529',['hasAssumption']='P37582',['antimicobials used in study']='P37475',['reasons that drive variations in hill coefficient']='P37476',['Method used to calculate minimum inhibition concentration']='P37478',['Metamodel scope_Business network']='P37485',['median mHLA-DR expression in ICU patients at admission to ICU']='P37466',['median mHLA-DR expression in ICU patients at day 3 to ICU']='P37467',['median mHLA-DR expression in ICU patients']='P37462',['median mHLA-DR expression in ICU patients at day 5']='P37465',['Summarization Type']='P37515',['Automatic Evaluation Scores']='P37518',['land use type']='P37460',['Number of studied patients']='P37461',['median mHLA-DR expression in ICU patients at day 3']='P37464',['median mHLA-DR expression in ICU patients at day 5 to ICU']='P37468',['drive variation']='P37470',['antibiotics']='P37473',['antibiotics used in study']='P37474',['Bacterial strains used in study']='P37471',['antimibiotics']='P37472',['pharmacodynamic model used for calculation']='P37477',['software used to analyze the dose response data']='P37513',['value of hill coefficient']='P37514',['Hill coefficient value']='P37469',['p-value of atherosclerotic lesion sizes']='P37490',['median mHLA-DR expression in ICU patients at day 7']='P37491',['median mHLA-DR expression in ICU patients at day 12']='P37492',['Organism Source']='P37510',['used qPCR']='P37479',['kit used for RNA extraction ']='P37480',['genes detected by qPCR ']='P37481',['kit used for reverse transcription ']='P37482',['Metamodel scope_Strategy and structure']='P37487',['atherosclerosis incidence']='P37489',['Dosage of interferon-γ']='P37494',['Virus']='P37507',['Compound name']='P37508',['Metamodel scope_Operations']='P37486',['What is the meaning of בן אדם in the book of Ezekiel and what is the intention of its use by God.']='P37594',['Methodology scope_Development of BA initiatives']='P37495',['Methodology scope_Development of BA model']='P37496',['Class of compound']='P37509',['Has exact calculation']='P37500',['Can be used to find the group with the highest GBC']='P37504',['Has exact solution method or providesi bounds']='P37498',['Has exact solution method or provides bounds']='P37499',['hasFactsAbout']='P37586',['designed to']='P37645',['Can be used to find the group of size k with the highest GBC in a given network']='P37505',['share RE']='P37617',['Source name']='P37511',['Biblical passages']='P37593',['Machine Learning Paradigm']='P37516',['Sleep efficiency']='P37525',['Data Size']='P37512',['Automatic Evaluation Metrics']='P37517',['Human Evaluation Aspects']='P37519',['Data Language']='P37520',['Data Domain']='P37521',['Has frequency']='P37522',['Risk factors for sleep apnea']='P37526',['Has method ']='P37523',['study location (country)']='P37524',['Has frequency (%)']='P37530',['hasScenario']='P37581',['has new aspects']='P37664',['has transformation path']='P37667',['Built on top of']='P37657',['Sleep efficiency (%)']='P37534',['The estimated value of Hill coefficient']='P37535',['Number of triples']='P37615',['has potential']='P37616',['has development']='P37618',['has assumptions for post-processing']='P37620',['Emission reduction']='P37621',['Apnea-hypopnea index (events/hour)']='P37536',['Nuclearity']='P37540',['Metals employed']='P37538',['Metal used']='P37539',['Homo or heterometallic complex']='P37542',['Ligand']='P37541',['Application ']='P37544',['geographical scope']='P37545',[' Ecosystem services investigated']='P37546',['Location of the research group']='P37549',['the reasons which drive variations in hill coeffcient']='P37547',['The reasons that drive variations in Hill coefficient']='P37548',['Reaction yield']='P37553',['proteins detected by western blot ']='P37552',['Reaction time']='P37558',['western blot n value  ']='P37550',['proteins detected by westernblot ']='P37551',['Solvent']='P37555',['Minimmum inhibition concentration (MIC) average']='P37554',['Precursor of cobinamide']='P37556',['Major reactant']='P37557',['Special conditions']='P37563',['Index Structure and Operators']='P37630',['Reaction yield (%)']='P37560',['Temperature (°C)']='P37561',['molecules detected by ELISA']='P37562',['Reaction time (minutes)']='P37559',['Scale-up (mg)']='P37564',['data availability ']='P37566',['conducted immunocytochemistry ']='P37568',['Safety hazard']='P37565',['Semantic representation in Music']='P37580',['method for Ros determination ']='P37569',[' concentration of ethanol exposure ']='P37570',['non wheat flour']='P37571',['Lower range of non wheat flour']='P37572',['Upper range of non wheat flour']='P37573',['factors affecting bacterial growth rate']='P37575',['conducted RNA sequencing']='P37576',['genes quantified by qPCR ']='P37577',['has post-processing']='P37619',['models energy sector']='P37668',['models demand sector']='P37669',['includes technologies']='P37671',['Has query']='P37624',['Has access pattern']='P37625',['Queries']='P37636',['Energy savings']='P37584',['Has cost']='P37628',['Query Optimization']='P37631',['Implemented Language']='P37606',['PC Configuration']='P37610',['Has Triples']='P37612',['Has Entities']='P37613',['Has (Best) Performance']='P37655',['Has operations']='P37627',['has Statistic']='P37632',['has case']='P37638',['Backend Storage']='P37609',['Implemented queries']='P37601',['Sample shape and dimensions']='P37592',['has advantage']='P37640',['Performence Study']='P37603',['What purpose has Ezekiel\'s inaugural vision?']='P37595',['Crowd']='P37597',['Has Configuration']='P37604',['Implemented query Q1']='P37602',['Level of Knowledge, skills, and expertise']='P37599',['Prototype System Name']='P37614',['Considers technological innovation']='P37622',['SPARQL queries']='P37623',['research_problem']='P32',['Has compared with']='P37607',['Name of system']='P37608',['RDF datasets']='P37611',['has term query']='P37646',['is combination of']='P37648',['uses ']='P37651',['Index Structure and Operatos']='P37626',['Best Average Recall']='P37652',['has symbol']='P37629',['Number of distinct subject']='P37633',['Number of threads']='P37637',['Clock rate']='P37635',['has Input']='P37639',['has component']='P37641',['Form']='P37643',['Best Mean Average Precision']='P37653',['Notation']='P37642',['has synonym']='hasSynonym',['show property']='ShowProperty',['has entity']='HasEntity',['Proof robustnees']='P37661',['is comparable']='P37662',['uses benchmark']='P38001',['includes economic foci']='P37672',['has endogenous variables']='P37674',['has source of funding']='P37663',['has spatial coverage']='P37665',['has target year']='P37666',['has economic (behavioural) rationale']='P37670',['includes social foci']='P37673',['is used in study']='P37675',['has approach to uncertainty']='P39024',['Query']='P38002',['dataset size']='P38003',['Is compared with']='P39000',['Uses Computer Hardware']='P39002',['Predicates']='P39004',['Uses hardware']='P39001',['Uses computer software']='P39003',['MAP multiple access patterns']='P39005',['representation']='P45099',['subject']={'P47028','P110024'},['mean']='P47000',['interactionType']='P45100',['audience']='P45101',['individual']='P45102',['production']='P45119',['Property table']='P45127',['Graph-based']='P45128',['Number of training passages']='P45109',['Number of development passages']='P45111',['Number of test passages']='P45110',['Results Number Word Classes']='P45115',['Results Geographics Location Word Classes']='P45117',['has maturity levels']='P45152',['Method2']='P47011',['LossMethod']='P47012',['Query rewriting']='P45143',['Matrix-based']='P45129',['Entity']='P45132',['surveyed NER architecture types']='P45113',['Used Technique']='P45155',['video type']='P47006',['video URL']='P47008',['Time period for data collection']='P48007',['origin']='P45150',['ontologylearningsource']='P45147',['Experiment environment setting']='P45122',['applicable Unit']='P45120',['code repository']='P49000',['runtime platform']='P49001',['target product']='P49002',['application category']='P49003',['Experiment setting']='P45121',['Engine']='P45123',['Triple Table']='P45124',['Quad Table']='P45125',['Vertical Partitioning']='P45126',['Property']='P45133',['Structural']='P45136',['Pairwise']='P45137',['Multiway']='P45138',['Number of distinct relations']='P45139',['Worst case optimal']='P45140',['Linear algebra']='P45141',['Relational']='P45142',['is anonymized']='IsAnonymized',['ontology learning approach']='P45148',['training data size']='P45145',['test data size']='P45146',['has application framework']='P45154',['ontology learning source']='P45149',['study_design']='P47001',['statistical_methods']='P47002',['open_access_medium']='P47003',['research_field_investigated']='P47004',['country_investigated']='P47005',['has scope']='P45153',['used datasets']='P45156',['round-trip time']='P47009',['peak signal-to-noise ratio (std) dB']='P47022',['round-trip time (average ms)']='P47015',['Method1']='P47010',['round-trip time (average)']='P47013',['round-trip time (average millisecond)']='P47014',['round-trip time (average) millisecond']='P47016',['round-trip time (std) ms']='P47017',['round-trip time (std) millisec']='P47018',['motion-to-photon (average) millisec']='P47019',['motion-to-photon (std) millisec']='P47020',['peak signal-to-noise ratio (average) dB']='P47021',['network']='P47023',['round-trip time (average) millisec']='P47026',['playability']='P47024',['payability']='P47025',['visual quality']='P47027',['software suggestions']='P49045',['maintainer']='P49046',['cont integration']='P49047',['build instructions']='P49048',['development status']='P49049',['embargo date']='P49050',['funding']='P49051',['issue tracker']='P49052',['reference publication']='P49053',['readme']='P49054',['Environmental intercations']='P49042',['Application interactions']='P49043',['Data access modality']='P49044',['Method of dependencies extraction']='P48001',['Dynamic']='P48002',['Multi-actor consideration']='P48003',['Type of considered dependencies']='P48004',['Subject Label']='P47029',['Subject ID']='P47030',['Relationship']='P47031',['Oxygen barrier properties']='P49063',['water barrier conditions']='P49064',['oxygen barrier conditions']='P49065',['Coating thickness']='P49066',['Coating substrate']='P49067',['Fabrication method']='P49068',['Object']='P47032',['Object ID']='P47033',['release notes']='P49010',['software help']='P49011',['software requirements']='P49012',['software version']='P49013',['Location']='P48005',['Time preiod']='P48006',['maxValue']='P47034',['minValue']='P47035',['Industrial Energy Loadprofile']='P47036',['Training Requirement']='P49076',['Method of dependencies modeling']='P48000',['Duration of use the AR app']='P48008',['Reasoning engine']='P106000',['conflict resolution']='P106020',['date created']='P49020',['date modified']='P49021',['date published']='P49022',['encoding']={'P49023','SCHEMAORG:encoding'},['file format']={'P49024','wikidata:P2701'},['provider']='P49025',['sponsor']={'P49026','wikidata:P859'},['is accessible for free']='P49027',['is part of']='P49028',['position']='P49029',['application sub category']='P49004',['download url']='P49005',['install url']='P49006',['memory requirements']='P49007',['permissions']='P49008',['processor requirements']='P49009',['storage requirements']='P49014',['supporting data']='P49015',['contributor']='P49016',['copyright holder']='P49017',['copyright year']='P49018',['creator']={'P49019','SCHEMAORG:creator','wikidata:P170'},['name']={'P49030','SCHEMAORG:name','CSVW_Name','wikidata:P2561'},['related link']='P49031',['given name']='P49032',['family name']='P49033',['Interoperability']='P49034',['Data aquisition']='P49035',['Dependencies consideration']='P49036',['Dependencies management']='P49037',['Heterogeneity consideration']='P49038',['Exposed services']='P49039',['Consumed services']='P49040',['Intercation within the physical environment']='P49041',['has negative association with']='P49084',['average precision CEA']='P98000',['everage precision CTA']='P98001',['average precision CTA']='P98002',['average precision CPA']='P98003',['average recall CEA']='P98004',['average recall CTA']='P98005',['average recall CPA']='P98006',['Hardware platform']='P49055',['Software platform']='P49056',['target population']='P49081',['Clustering algorithms']='P106021',['peer-reviewed']='P49080',['geographical coverage']='P49082',['academic disciplines']='P49083',['Prediction accuracy rate']='P49058',['bearing type']='P106022',['Best machine learning or deep learning approach/algorithm']='P49057',['Performance metrics']='P49059',['Filler material']='P49060',['Polymer material']='P49061',['Water barrier properties ']='P49062',['Prediction accuracy results']='P49069',['Oxygen barrier properties, cm3 m−2 day−1 bar−1']='P49070',['Water barrier properties, g m−2 day−1']='P49071',['Coating thickness, micrometers']='P49072',['higher confidence limit']='P49073',['animal']='P49074',['Intrusion Detection Type']='P49075',['Attack Type']='P49077',['Optimization criteria']='P49078',['Optimization function']='P49079',['Total Frames extracted']='P50000',['short name']='wikidata:P1813',['urban boundaries of study']='P98007',['racial groups']='P98008',['proportion to the population']='P98009',['white people']='P98010',['black people']='P98011',['bearing position']='P106023',['access control concept']='P106024',['Key frames extracted']='P50001',['levels names']='P52000',['ISO/ IEC 15504']='P52001',['Number of levels']='P52002',['record identifier']='P52003',['test year']='P52004',['age']={'P52005','P59214'},['Excercise']='P52006',['Language model vocabulary']='P52039',['multi modal feature handling']='P52008',['Result Semantification']='P52009',['Explainable Results']='P52010',['Software Resource Link']='P52011',['Probabilistic Similarity Approach']='P52012',['Scalability Framework']='P52007',['has levels']='P52013',['attributes number']='P52015',['has attribute']='P52014',['Maturity Definition']='P52016',['Practicality']='P52017',['number of closed question']='P98012',['number of open-ended questions']='P98013',['Phase of pandemic']='P53000',['Data source content']='P52019',['Number food category']='P52020',['Calorie-annotated recipe']='P52018',['Evaluation data size']='P52021',['Absolute error']='P52022',['Relative error']='P52023',['Relative error (%)']='P52024',['Absolute error (kcal)']='P52025',['Number of food recipe']='P52026',['testing data size']='P52028',['standard error']='P52027',['Validation data size']='P52029',['Machine learning framework']='P52030',['Carbohydrates']='P52034',['Relative error (kcal)']='P52031',['Fat']='P52033',['Protein']='P52032',['formal description']='P106025',['proportion of population']='P98014',['numeric value']={'wikidata:P1181','numericValue'},['Construction of food photo dataset']='P52035',['same as ']='P98015',['quantitative value']='P98016',['Number of classes']='P52036',['Association']='P52038',['Vocabulary Size']='P52040',['has text']='P52041',['eats']='P54001',['Direct logistic']='P54007',['Reverse logistic']='P54008',['indirectly negatively regulates quantity of']='P54009',['Dataset Sample Size']='P54021',['Number of triple patterns']='P55029',['Number of files']='P55030',['Environemental aspect']='P54004',['1st Dataset Training Size']='P54026',['2nd Dataset url']='P54027',['Inventory model']='P54015',['instance of']={'P54000','wikidata:P31'},['Economic aspect']='P54003',['Social aspect']='P54005',['Method resolution']='P54002',['E-waste management']='P54006',['directly negatively regulates quantity of']='P54012',['Cap-and-trade policy ']='P54010',['Publish year']='P54011',['publish in the journal']='P54013',['Journal impact factor']='P54014',['Attributes Count']='P55004',['Maturity has Levels']='P55008',['Practicability']='P55009',['Maturity has Definition']='P55007',['Decision variable']='P54019',['Sustainability factor']='P54017',['Objective fucntion']='P54018',['Production energy consumption function']='P54020',['Number of echelon']='P54016',['2nd Dateset Size']='P54022',['1st  Dataset Sample Size']='P54023',['2nd  Dataset Sample Size']='P54024',['1st  dataset Testing Size']='P54025',['no need to learn query language']='P55011',['semiotics']='P55003',['self-healing']='P54028',['Levels Count']='P55006',['Bacteria (concentration )']='P54029',['Nutrition broth +food']='P54030',['Immobilizer material /polymer']='P54031',['Focus/concept']='P54032',['Future reccomendation']='P54033',['Missing values']='P54034',['critical theory']='P55001',['psychoanalysis']='P55002',['Domain Name']='P55005',['automatic data mapping']='P55010',['mass media analysis']='P55000',['automatic generation of domain objects']='P55013',['count']='P55023',['Query Text']='P55028',['speed']='P55025',['Workload taxonomy']='P55026',['measures of central tendency']='P57005',['element']='P106026',['no need to write queries']='P55012',['semantic data support']='P55014',['relation type']='P106027',['Has published']='P56000',['Submodels']='P55019',['subquestion']='P57000',['predictive question']='P57002',['Experimental tool']='P55020',['cores']='P55024',['Strong points of the research']='P58077',['package']='P55021',['Hardware configuration']='P55022',['between subject']='P57018',['within subject']='P57019',['has research paradigm']='P55027',['Number of peers']='P55032',['contains triangular pattern']='P55031',['action research']='P57020',['research question answer']='P57004',['Online published']='P56002',['computes solution to']='wikidata:P2159',['study data']='P55033',['hidden in text']='P55038',['hypothesis testing']='P56044',['Young Modulus']='P58036',['Negative']='P59007',['internal validity']='P55035',['conclusion validity']='P55036',['construct validity']='P55037',['external validity']='P55034',['influencing factor']='P56001',['highlighted in text']='P55039',['has engine']={'P106028','P106029','P106030','P106031','P106032','P106033','P106034','P106035','P106036','P106037','P106038','P106039'},['controls']='P56003',['gender']='P56004',['claim causality']='P56007',['seniority']='P56005',['region']='P56006',['observation number']='P56010',['type study']='P56011',['observation type']='P56009',['has_name']='P57022',['gross sample']='P56014',['survey type']='P56012',['population']={'P56013','wikidata:P1082'},['response rate']='P56015',['start field phase']='P56016',['end field phase']='P56017',['Indicator']='P57024',['event detection method']='P56025',['causality acquisition method']='P56019',['causality representation']='P56018',['explanation ranking method']='P56022',['invents']='P106040',['copyright license']='wikidata:P275',['explanation evaluation']='P56023',['explanation personalization']='P56024',['causality inference method']='P56020',['explanation extraction method']='P56021',['Measurement noise']='P56053',['Process noise']='P56054',['academic discipline']='P56026',['loading time']='P56042',['influencing factor description']='P56027',['PyPI project']='wikidata:P5568',['association description']='P56028',['number of testbeds']='P106041',['outcome description']='P56029',['controls description']='P56030',['relation']='wikidata:P2309',['target population description']='P56031',['data collection method description']='P56032',['observation type description']='P56033',['background empirical evidence']='P56034',['measures of dispersion or variation']='P57008',['content analysis']='P57014',['grounded theory']='P57015',['machine learning']='P57016',['background theory']='P56035',['theory description']='P56036',['Accuracy']={'P58020','P71081'},['open_access_models']='P57023',['variance']='P57009',['Fake News']={'P58021','P67038'},['Traditional Spam Bot']='P58091',['has constraints']='P56051',['Type of considered system']='P56052',['data source description']='P56037',['ROC area']='P58121',['Precision-Recall Curve (PRC) area']='P58122',['Correctly classified instance']='P58124',['Prop 1']='P56038',['Prop 2']='P56039',['Prop 3']='P56040',['Spam Acount']='P58042',['data-driven approach']='P56041',['median']='P57006',['secondary research']='P57021',['exploratory question']='P57001',['research paradigm']='P57003',['measures of position']='P57010',['CPA']='P97161',['Matthews Correlation Coefficient (MCC)']='P58063',['percentile rank']='P57011',['quartile rank']='P57012',['thematic analysis']='P57013',['hypothesis statement']='P56046',['inferential statistics']='P56043',['descriptive analysis']='P56047',['descriptive statistics']='P56048',['regression analysis']='P56045',['measures of frequency']='P56049',['percent']='P56050',['classification type']='P57017',['result_detail']='P57025',['mass']='wikidata:P2067',['1st Dataset Size']='P58006',['2nd Dataset Size']='P58007',['Kind of Research']='P107000',['radius']='wikidata:P2120',['Traffic Effect']='P57027',['Encryption Type']='P57028',['measured physical quantity']='wikidata:P111',['drought type']='P107001',['Key Scheme']='P57026',['conclusion']='P15419',['objective']='P15051',['error']='P107005',['Supervised Learning Problem Type']='P58064',['Measurment']='P58065',['Data Scaling Type (normalization method)']='P58066',['Data scaling (normalization method)']='P58067',['Performance measurment']='P58068',['Supervised learning']='P58070',['1st Dataset url']='P58113',['Applicable flow pattern']='P58108',['scientific_block_compared']='P57029',['Average']='P57030',['Lowest']='P57031',['Highest']='P57032',['World region']='P57033',['interview']='P57034',['question number']='P57035',['survey']='P57036',['research data']='P57037',['qualitative ']='P57038',['quantitative ']='P57039',['study']='P57040',['target class']='sh:targetClass',['property']='sh:property',['path']='sh:path',['min count']='sh:minCount',['max count']='sh:maxCount',['closed']='sh:closed',['min inclusive']='sh:minInclusive',['max inclusive']='sh:maxInclusive',['pattern']='sh:pattern',['datatype']='sh:datatype',['Fake news with propagation network']='P58030',['Cost Effectiveness']='P59096',['Applicable condition']='P58109',['3rd Dataset F1-score']='P58015',['3rd Dataset Precision']='P58016',['3rd Dataset Recall']='P58017',['1st Dataset Recall']='P58018',['1st Dataset F1-score']='P58019',['In Original Query']='P57041',['First Run of Optimization']='P57042',['has triplestore']='P57043',['Research weak point(s)']='P58078',['False Positive']='P58045',['has published in']='P58106',['Social Spam Bot #1']='P58088',['Social Spam Bot #2']='P58089',['Social Spam Bot #3']='P58090',['Fake Accounts']='P58093',['Rea News']='P58024',['Q3 has Value']='P57045',['Q1 has Value']='P57044',['Q7 has Value']='P57046',['Against PDStore']='P57048',['has cost model']='P57047',['Against RDF-3X']='P57049',['Against BitMat']='P57050',['Against Triplerush']='P57051',['Q2 has Value']='P57052',['Q4 has Value']='P57053',['Q5 has Value']='P57054',['Q6 has Value']='P57055',['Number of machine learning algorithms']='P58079',['F1 entity level']='P58033',['Real Accounts']='P58039',['SpamBots']='P58040',['Fake Followers']='P58041',['used in project']='P58053',['available in']='P58054',['Has predictors']='P57056',['Backward Compatibility']='P59097',['Repair and Maintenance']='P59098',['Overhead']='P59099',['Security Level']='P59100',['variables used']='P57061',['Solution approach']='P58107',['Web of science ResearcherID']='P58083',['period of data collection']='P57057',['has yearly pattern']='P57058',['has daily pattern']='P57059',['is particularly strong deterrent for ']='P57065',['on cycling trips']='P57064',['has weekly pattern ']='P57060',['hash']='P58095',['replay protection']='P58097',['Multiple transportation modes']='P58102',['is larger than']='P57062',['deterrents to cycling']='P57066',['daily variations']='P57067',['association with cycling trips']='P57063',['Capacitated facilities']='P58103',['Multiple facilities in each echelon']='P58104',['case study']='P58105',['Fake Account']='P58092',['1st Dataset']='P58001',['2nd Dataset']='P58002',['3rd Dataset']='P58003',['is plural of']='P57069',['Real News']={'P58022','P67037'},['has influence on ']='P57068',['Test-Data Languages']='P58000',['3rd Dataset Size']='P58008',['Accuracy (%)']='P58112',['Publons ID']='P58082',['Scopus']='P58084',['is explained in']='P57070',['on weekdays']='P57072',['has turning point at ']='P57071',['on weekends']='P57073',['male adult human']='P57075',['negative effect for ']='P57074',['increase of ridership']='P57076',['decrease of ridership']='P57077',['R189274']='P57079',['is measured in ']='P57078',['R189276']='P57080',['R189278']='P57081',['R189280']='P57082',['R189282']='P57083',['R189286']='P57085',['R189284']='P57084',['is calculated from']='P57086',['Target variable']='P57089',['mean values are calculated from']='P57087',['Predictor variable']='P57088',['Limiations']='P58076',['is described by']='P57090',['Environemental control']='P58125',['Bagging']='P58116',['JRip']='P58117',['J48']='P58118',[' Partial Decision Tree (PART)']='P58119',['Universities']='P58038',['Algorithm(s) used']='P58074',['Application field(s)']='P58075',['True News with propagation network']='P58031',['Drawbacks']='P58110',['Function ']='P58111',['OntologyName']='P58047',['associated with project']='P58049',['UsedIn']='P58050',['availableIn']='P58051',[' Macro F1 word-level']='P58034',['Micro F1']='P58035',['# of Recordings']='P59000',['online accessible']='P58055',['plpl']='P58057',['Random Forest']='P58059',['Support Vector Machine (SVM)']='P58060',['MyScienceWork']='P58085',['Semantic Scholar']='P58086',['In Use']='P59001',['operates on']='P57091',['authentication method']='P59101',['1st Dataset  training/test url']='P58114',['ExperimentExperimental data']='P58126',['Crosslinker']='P57092',['Toughness (MJ/m3)']='P57096',['Binder']='P57093',['strength (MPa)']='P57094',['Modulus (GPa)']='P57095',['targets']='P57097',['Limiation']='P58071',['Spam Accounts']='P58043',['conclusion(s)']='P58087',['Named Entity Recognition']='P58032',['Number of network echelons']='P58098',['Multi-objective approach']='P58099',['Multiple periods']='P58100',['Multiple products']='P58101',['Solid Use Case']='P59009',['False Negative Rate']='P57098',['Algorithm used']='P58069',['has domain']='P58056',['key']='P58096',['1st Dataset Precision']='P58004',['Number of application fields']='P58080',['Number of performance measures']='P58081',['Receiver Operating Characteristic (ROC) area']='P58123',['True Positive rate']='P58120',['True newswith propagation network']='P58025',['Fakenewswith propagation network']='P58026',['Tweets']='P58027',['Retweets']='P58028',['triangulation']='P59059',['semantic analysis']='P59062',['no of data properties']='P58062',['no of object properties']='P58061',['delete']='P58044',['mentions']='P57100',['1st Datasset Size']='P58005',['1st Dataset Accuracy']='P58009',['Logistic Regression']='P58058',['has number of classes']='P57101',['patient age']='P57106',['type of persisten identification']='P118041',['type of persistent identification']='P118042',['1976 - 2017']='P118043',['beginning']='P57102',['end']='P57103',['hypothesis supported']='P57105',['COVID-19 patients with gastrointestinal symptoms']='P57107',['False Positive Rate']='P58046',['has number of instances']='P58048',['accessible online']='P58052',['2nd Dataset Accuracy']='P58010',['3rd Dataset Accuracy']='P58011',['2nd Dataset Recall']='P58012',['2nd Dataset Precision']='P58013',['Topology Authentication']='P59002',['Path Authentication']='P59003',['Origin Authentication']='P59004',['Replies']='P58029',['buffered reads']='P58037',['Total number of Accounts']='P58115',['The research problem']='P58073',['2nd Dataset F1-score']='P58014',['Encryption']='P58094',['Datasets used']='P58072',['PloitiFact']='P58023',['Neutral']='P59008',['Positive']='P59006',['Overall effect of COVID-19 lockdowns on WCV']='P59072',['Images  dimensions']='P59045',['Enterprise Environment']='P59010',['regularity analysis']='P59057',['comparative analysis']='P59058',['coding']='P59061',['Mean number of WVC per month 2019 Lockdown period']='P59040',['Wordbags']='P59012',['Prediction accuracy results (%)']='P59011',['roc auc']='P59066',['category analysis']='P59060',['has review']='P59027',['skewness']={'P59063','wikidata:P10744'},['boxplot']='P59065',['Data augmentation technique']='P59046',['authorization method']='P59044',['Dataset Training Size']='P59013',['Dataset Testing Size']='P59014',['Overall effect of COVID-19 lockdowns on mammal road mortality']='P59081',['Percent change from pre-pandemic road mortality rates']='P59082',['Proposed model']='P59015',['Cost per impression Mile (CPM)']='P59020',['Mean number of WVC 2020 Non-lockdown period']='P59043',['Mean WVC Krakow']='P59032',['Mean WVC 2019']='P59033',['Mean number of WVC per month 2019 Non-lockdown period']='P59041',['Dataset Validation Size']='P59016',['Attack Goal']='P59017',['Revenue Model Goal']='P59018',['Cost per Click (CPC)']='P59019',['Cost per Action (CPA)']='P59021',['Attack Target']='P59022',['Proposed model architecture']='P59023',['Mean WVC 2019 Non-lockdown']='P59035',['predicate_2']='P59068',['has research problem']='P59028',[' Accuracy results (Prediction %)']='P59029',['Percent change from pre-pandemic WVC rates']='P59030',['Mean WVC 2020 Lockdown period']='P59038',['Mean WVC 2020']='P59034',['Mean WVC 2019 Lockdown period']='P59036',['Mean WVC 2019 Non-lockdown period']='P59037',['Mean WVC 2020 Non-lockdown period']='P59039',['body parts']='P59026',['Mean number of WVC per month 2020 Lockdown period']='P59042',['Positive Predictive Rate']='P59024',['Negative Predictive Rate']='P59025',['Time Complexity Analysis']='P59047',['predicate_3']='P59069',['bus width']='P59071',['low result']='P59048',['high result']='P59049',['Automatically evaluating machine-translated text']='P59050',['system information']='P59051',['Industry 4.0 technology']='P59052',['Refered Supply chain resiliences phases']='P59054',['Discused Supply Chain Resiliences antecedents']='P59053',['sentiment analysis']='P59074',['Experimental data']='P59055',['kurtosis']='P59064',['Real locations']='P59056',['architecture']='P59070',['predicate_1']='P59067',['ontology component']='P59103',['ontology module']='P59104',['Taktfrequenz']='P59073',['unit conversion result']='P59075',['Learning']='P59076',['Has Links']='P59077',['used method']='P59078',[' number of self-attention heads']='P59118',['in-depth analysis']='P59094',['Multi scenario']='P59087',['Has Relations']='P59079',['Percent change from pre-pandemic mortality rates']='P59080',['Has Visualize']='P59083',['Multi-customers']='P59086',['Problem domain']='P59084',['Multi-Suppliers']='P59085',['behavioural analysis']='P59095',['Corpus name']='P59091',['Parser ']='P59088',['Evaluation method']='P59089',['self attention heads']='P59116',['total parameters']='P59117',['Compilation method']='P59092',['session']='P59102',['Is contextual']='P59107',['axioms count']='P59105',['rules count']='P59106',['hidden layer size']='P59114',['hidden size']='P59115',['has architecture']='P59111',['stakeholder analysis']='P59110',['F_β -score']='P59108',['has number of layers']='P59112',['has transformer blocks']='P59113',['reliability']='P59109',['base model']='P59119',['individual count']='P59122',['Number of annotators']='P59120',['is output of process']='P59121',['f-score']='P59137',['Media Type']='P59132',['properties count']='P59123',['aligned to']='P59139',['type of software']='P59136',['Video encoder']='P59130',['Github link']='P59134',['terms count']='P59135',['domain knowledge']='P59124',['people involved']='P59125',['literature analysis']='P59126',['Storage']='P59133',['Text encoder']='P59129',['learning poverty']='P59156',['Discourse structure']='P59127',['Fusion dimensions']='P59131',['Audio encoder']='P59128',['aligned with']='P59140',['Number of Tweets']='P59143',['ddasdasdd']='P59138',['learning loss definition']='P59151',['number of data']='P59141',['Number of topics']='P59142',['hypothesis statements']='P59169',['Average aptitude test score']='P59173',['has bandwidth usage']='P59166',['has response time']='P59165',['age unit']='P59150',['learning loss unit']='P59152',['Start date']='P59144',['End date']='P59145',['Processor clock speed']='P59163',['Feature learning channel']='P59146',['assessment test']='P59159',['Covered Countries ']='P59198',['age min']='P59147',['age max']='P59148',['sample size unit']='P59149',['learning poverty in reading']='P59157',['additional data']='P59153',['Networks\' architecture type']='P59155',['annotate guideline']='P59194',['Network architecture type']='P59154',['learning poverty in numeracy']='P59158',['Study language	']='P59189',['Dataset_name/ source']='P59190',['Dataset_volume']='P59191',['Method(s)']='P59192',['defination of bias']='P59195',['Number of catchphrases']='P59193',['research result']='P59196',['Number of machines']='P59161',['Number of peers per machine']='P59162',['Research Design']='P59160',['Average Age at testing']='P59164',['Grammatical structures correlated highly with age of arrival']='P59168',['has optimization time']='P59167',['Bias Genre']='P59187',['Range of Age of arrival in the US.']='P59170',['Average length of residence in the US.']='P59171',['Average length of residence']='P59172',['correlation measures']='P59175',['word error rate']='P59259',['has neural models']='P59188',['Average length of residence (years)']='P59174',['model testing']='P59176',['Participants\' age']='P59178',['Stimuli']='P59179',['Graph analysis support']='P59177',['language']='P59186',['defination of societal bias']='P59197',['materials for instruction']='P59180',['materials for testing']='P59182',['Participants\' age (years)']='P59181',['tested subjects']='P59184',['Focus marker']='P59183',['Subject language']='P59185',['Pre-training task(s)']='P59233',['Results on benchmark corpus']='P59234',['Results on STSbenchmark corpus']='P59235',['Results on STS benchmark corpus']='P59236',['has neural models or systems']='P59199',['Network architecture ']='P59200',['Maximum input text (tokens)']='P59237',['Dimension of text embedding']='P59238',['Maximum input text (word pieces)']='P59239',['language model setting']='P59201',['Number of relation subtypes']='P59203',['number of training pregnancy documents']='P59209',['number of test pregnancy documents']='P59210',['number of POS tags']='P59202',['number of test documnets_pergnancy']='P59204',['number of training set pregnancy']='P59208',['nuber of test set drug']='P59206',['number of test set drug']='P59207',['number of training set drug']='P59205',['Baseline results']='P59211',[' Computational Linguistics & Corpus Annotation']='P59232',['Registers compared']='P59212',['sentence error rate (SER)']='P59264',['sentence error rate']='P59265',['character error rate']='P59266',['second language']='P59216',['examined linguistic phenomina']='P59217',['amount of participants']='P59213',['native language']='P59215',['Computer Science: Computational Linguistics & Corpus Annotation']='P59231',['language domain']='P59218',['proficiency level']='P59219',['Baseline classifier result']='P59260',['Norovirus']='P59223',['Precision@1']='P59224',['Hits@5']='P59225',['Result: Cell tropism']='P59221',['Result: Organ tropism']='P59220',['Diachronic']='P59226',['Hits@1']='P59222',['dataset_source']='P59228',['dataset_size']='P59229',['dataset_type']='P59227',['dataset total size']='P59230',['Research ProblemResource Consumption']='P59269',['serialization language']='P60000',['days after infection/inoculation']='P59240',['route of infection']='P59241',['Number of participants ']='P59242',['Examined Modality']='P59243',['CPU Hours']='P59246',['GPU Hours']='P59247',['TPU Hours']='P59248',['Steps for Environmental Footprint Reduction during Development']='P59249',['Estimated CO2 Footprint']='P59250',['Native Language ']='P59251',['Benchmark Performance']='P59252',['character error rate (CER)']='P59263',['Resource Consumption']='P59244',['Designed For']='P59268',['PDF']='P59245',['Benchmark Time']='P59253',['Sampling Frequency']='P59258',['Results on STS benchmark corpus (Pearson\'s 𝒓)']='P59255',['Analyses']='P59256',['low-resource language']='P59257',['research question']='P59254',['Created For']='P59267',['Character n gram ']='P59261',['documentation link']='P60002',['Word n gram']='P59262',['software component']='P60004',['Has conditions']='P60005',['licence']='P60001',['actor']='P60003',['has input var']='P108000',['has output var']='P108001',['isPreceededBy']='P108002',['component input']='P108003',['component output']='P108004',['has corresponding pattern step']='P108005',['Qualitative Effect of Lockdown on Pollutant Concentrations']='P62001',['generalizability']='P60006',['artefact analysis']='P60007',['antigen used']='P60009',['cohens kappa']='P60008',['Measurement Location']='P62000',['Seroprevalence']='P60011',['type of environment']='P108006',['starting dilution']='P60012',['Result PM10']='P61006',['Result 1']='P61000',['Result 2']='P61001',['Result PM2.5']='P61004',['Result CO2']='P61005',['Type of Pollutant']='P61007',['immunoglobulin class']='P60010',['has upper value']='P61002',['has lower value']='P61003',['mean error (ME)']='P62076',['Calibration']='P62005',['PolitiFact_Fake']='P62006',['Training-Testing split ratio']='P62010',['GossipCop_Fake']='P62003',['root mean square error (RMSE)']='P62075',['PolitiFact_Real']='P62007',['GossipCop_Real']='P62004',['food group']='P62002',['Fake Images']='P62008',['Real Images']='P62009',['Precision (%)']='P62013',['Dataset Training Size (%)']='P62011',['Dataset Testing Size (%)']='P62012',['positive rate']='P62077',['primers']='P62078',['norovirus genotype']='P62080',['food component']='P62073',['noroviruses found']='P62079',['Amount of samples']='P62074',['INFOODS regional data center']='P62014',['food stuffs count']={'P62016','P62017'},['food component count']='P62019',['ingredient count']='P62015',['food group count']='P62020',['list food group']='P62120',['True Negative Rate']='P62018',['grains']='P62021',['sugars and sweeteners']='P62024',['pulses']='P62025',['potStarchesatoes and Starches']='P62022',['potatoes and Starches']='P62023',['nuts and seeds']='P62026',['vegetables']='P62027',['algae']='P62030',['fish and shellfish']='P62031',['meat']='P62032',['eggs']='P62033',['mushrooms']='P62029',['fats and oils']='P62035',['fruit']='P62028',['beverages']='P62037',['dairy Products']='P62034',['confectioneries']='P62036',['general food components']='P62041',['lipids']='P62042',['triacylglycerol equivalents']='P62043',['calcium']='P62048',['vitamin A']='P62056',['seasonings and spices']='P62038',['prepared and processed foods']='P62039',['minerals']='P62045',['sodium']='P62046',['magnesium']='P62049',['phosphorus']='P62050',['iron']='P62051',['zinc']='P62052',['sensitivity (recall)']='P62040',['ash']='P62044',['dietary fiber']='P62071',['vitamins']='P62055',['potassium']='P62047',['copper']='P62053',['vitamin D']='P62058',['vitamin K']='P62060',['vitamin C']='P62068',['manganese']='P62054',['vitamin A (Retinol)']='P62057',['cholesterol']='P62070',['vitamin E']='P62059',['vitamin B 1']='P62061',['vitamin B 2']='P62062',['niacin']='P62063',['vitamin B 6']='P62064',['vitamin B 12']='P62065',['folic acid']='P62066',['pantothenic acid']='P62067',['fatty acids']='P62069',['dataset format']='P62072',['research type']='P62118',['research group']='P62081',['theoretical or practical']='P62082',['diffractive optical element']='P62083',['list food components']='P62119',['list food item']='P62088',['type of diffractive optical element']='P62084',['angle']='P62097',['pixel size']='P62098',['field property']='P62086',['design of diffractive optical element']='P62089',['food group source']='P62092',['food group name']='P62085',['food group element count']='P62087',['wavelength']='P62096',['food name']='P62090',['design concept']='P62091',['constraints']='P62094',['figure of merit']='P62095',['food component name']='P62093',['phase steps']='P62101',['pixel pitch']='P62102',['element size']='P62103',['height step number']='P62105',['amplitude step number']='P62107',['horizontal quantity']='P62099',['vertical quantity']='P62100',['height step size']='P62104',['phase step number']='P62106',['f number']='P62109',['image distance']='P62108',['field of view']='P62110',['cell structure']='P62113',['feature size']='P62115',['Metasurface cell of diffractive optical element']='P62111',['metasurface cell']='P62112',['layer number']='P62114',['peak signal-to-noise ratio']='P62117',['results of diffractive optical element']='P62116',['carried out by']='P63067',['size in pixels']='P63000',['presumed lifetime of vehicle']='P63016',['presumed travel distance during lifetime']='P63017',['Disassembly line type']='P63018',['Disassembly type']='P63019',['Operation time']='P63020',['food group total']='P63001',['Aplicable for Wireless Sensor Networks (WSN)']='P63021',['Aplicable for Internet of Things (IoT)']='P63022',['food composition table']='P63002',['Cereals and their products']='P63003',['Vegetables and their products']='P63006',['Legumes and their products']='P63007',['fruits and their products']='P63008',['eggs and their products']='P63010',['sugars, sweeteners and syrup']='P63011',['beverages (alcoholic and nonalcoholic)']='P63012',['meat and poultry and their products']='P63013',['fish and their products']='P63014',['prepared foods']='P63015',['Starchy roots, tubers and their products']='P63004',['Nuts, seeds and their products']='P63005',['condiments and sauces']='P63009',['Real-time Anomally Detection']='P63042',['egg products count']='P65020',['fats and oils count']='P65022',['human milk item count']='P65035',['purchase price']='P63023',['currency']='P63024',['annual fuel costs']='P63025',['average maintenance costs']='P63026',['Inference time ']='P63038',['score calculation via']='P109000',['brand name ']='P63028',['vehicle name']='P63029',['other food count LEBTAB']='P65007',['baby fruit, vegetables, juices, instant beverages count']='P65009',['fish and shellﬁsh products count']='P65023',['vehicle type']='P63027',['life cycle fuel costs']='P63030',['total life cycle costs']='P63032',['life cycle maintenance costs']='P63031',['Configuration Issues']='P63043',['Data Dimension']='P63033',['Data range']='P63034',['Data frequency']='P63035',['Privacy-Preserving Deep Learning Type']='P63039',['study involve']={'P63065','P63066'},['required input']='P110069',['optional input']='P110070',['reduction with BEV solar']='P65043',['animal origin food']='P65003',['Inference Time']='P63037',['Annotation level']='P65000',['Privacy-Preserving Deep Learning Scheme']='P63036',['food group total IFCD 1998']='P63076',['Alcoholic and non- alcoholic beverages, coffee, tea']='P63074',['dietary supplements (per 100 g) count']='P65018',['dietary supplements (per capsule/tablet) count']='P65019',['Confidentiality and Integrity']='P63040',['Self-healing ']='P63041',['Purpose ']='P63046',['Authentication and Authorization']={'P63044','P63045'},['Implemenation']='P63048',['ChEMBL v139 RDF conversion.10']='P63050',['Heuristics']='P63047',['Paper Topic']='P63049',[' CHEMBL']='P63055',['meat, meat products and offal']={'P63070','P63071'},['sweets and sweeteners']='P63073',['miscellaneous food group']='P63075',['ChemSpider and ACD Labs Predicted Properties RDF conversion']='P63051',[' Drugbank RDF conversion provided by the Bio2Rdf project.']='P63052',[' Conceptwiki']='P63053',['Overview in terms of H4 and H5']='P63059',['sweets count']='P65029',['vegetable products count']='P65030',['live-cycle Greenhouse Gas emissions']='P65048',['ChemSpider and ACD Labs']='P63054',['Overview of Results']='P63056',['Overview of the results in terms of H1']='P63057',['Overview in terms of H2']='P63058',['Overview in terms of H3']='P63060',['Service Model']='P63062',['Fine-grained']='P63064',['results withdrawn from conclusion']='P63061',['milk and milk products']='P63072',['food of plant origin count']='P65032',['supplements food count']='P65033',['baby food count']='P65034',['Intrusion Detection']='P63063',['wind energy']='P65063',['vegetables, potatoes, pulses, herbs and spices']='P63068',['fresh, dried and preserved fruit']='P63069',['food of plant origin']='P65004',['baby food: infant formulae count']='P65008',['Entertainment (Real News)']='P67003',['infant formulae, baby food, human milk count']='P65039',['waste treatment']='P65066',['crude oil']='P65070',['commercial brand and composite food']='P63078',['dietary records count']='P63079',['basic food count']='P63077',['curated by']='P67001',['BEV']='P65057',['value of ICEV-D']='P65059',['dairy products: milk, yoghurt count']='P65017',['fast food count']='P65021',['participant count']='P63080',['baby food group count']='P63081',['Vegetable products']='P63091',['dietary supplements']='P63097',['baby fruit, vegetables, juices, instant beverages']='P63101',['baby milk-cereal-products']='P63102',['Potato products']='P63090',['Cereal grains, breakfast cereals, pasta']='P63087',['Baked products: breads, bread rolls']='P63088',['Fruit products, nuts']='P63092',['Baked products: cakes, biscuits']='P63089',['sweets']='P63094',['baby mixed dishes: ready to eat']='P63103',['Egg products']='P63084',['Juices']='P63093',['including 193 infant formulae']='P65038',['Dairy products: milk, yoghurt']='P63082',['Dairy products: cheese']='P63083',['Meat products, sausages']='P63085',['fast food']='P63096',['dietary supplements (per 100 g)']='P63098',['dietary supplements (per capsule/tablet)']='P63099',['baby food: infant formulae']='P63100',['supplements food']='P65005',['baby milk-cereal-products count']='P65010',['baked products: cakes, biscuits count']='P65013',['dairy products: cheese count']='P65016',['Fish and shellﬁsh products']='P63086',['Average Statement length (token)']='P67039',['soups, sauces, gravy']='P63095',['True']={'P67081','P67075','P68113'},['baby food']='P65006',['fruit products, nuts count']='P65024',['juices count']='P65025',['meat products, sausages count']='P65026',['potato products count']='P65027',['soups, sauces, gravy count']='P65028',['Editorial (Real News)']='P67022',['Miscellaneous (Fake News)']='P67023',['Proportion of energy generation with crude oil']='P67067',['Sports (Fake News)']='P67011',['Sports (Real News)']='P67012',['Average Recall']='P67026',['baked products: breads, bread rolls count']='P65012',['animal origin food count']='P65031',['Crime (Fake News)']='P67013',['Crime (Real News)']='P67014',['Education (Fake News)']='P67015',['Social control']='P65040',['Neutral Suppot / News']='P65080',['Negative Support / News']='P65081',['Construction Type']='P64000',['F1-Score (Unrelated)']='P67036',['electricity generation in the country']='P65061',['baby mixed dishes: ready to eat count']='P65011',['infant formulae, baby food, human milk']='P65036',['including 50 infant formulae']='P65037',['Generation method']='P65001',['Research problem description']='P65002',['beverages count']='P65014',['cereal grains, breakfast cereals, pasta count']='P65015',['Training set']='P65049',['Real News (Trainng)']='P65050',['Fake News (Training)']='P65051',['Real News (Testing)']='P65052',['Real News (Training)']='P65053',['Fake News (Testing)']='P65054',['solar energy']='P65067',['Miss Rate']='P65056',['Decision Level']='P65041',['Education (Real News)']='P67016',['Technology (Fake News)']='P67017',['Value of BEV']='P65058',['hydropower']='P65062',[' Cites / Source']='P65074',[' Friends / User']='P65075',['lowest ']='P65047',['duration']='wikidata:P2047',['reduction with PHEV']='P65044',['reduction with HEV']='P65045',['reduction with BEV']='P65046',['Lifestyle (Fake News)']='P67004',['Lifestyle (Real News)']='P67005',['National (Real News)']='P67006',['National (Fake News)']='P67007',['Finance (Real News)']='P67020',['Editorial (Fake News)']='P67021',['Miscellaneous (Real News)']='P67024',['natural gas']='P65069',['disambiguatingDescription']='SCHEMAORG:disambiguatingDescription',['Testing Set']='P65042',['International (Fake News)']='P67008',['Politics (Fake News)']='P67009',['Politics (Real News)']='P67010',['Error Rate']='P65055',['value of ICEV-G']='P65060',['nuclear energy']='P65064',['biomass']='P65065',['coal']='P65068',['suggests']='P109001',[' Publications / Source']='P65072',[' Engagements / News']='P65073',['genre']='SCHEMAORG:genre',['International (Real News)']='P67025',['Ottawa Shooting (Rumours)']='P67052',['Non-Rumors']='P67044',['Ferguson (Rumours)']='P67048',['Ferguson (Non-Rumours)']='P67049',['Ottawa Shooting (Non-Rumours)']='P67053',['F1-Score (Agree)']='P67033',['F1-Score (Disagree)']='P67034',['F1-Score (Discuss)']='P67035',[' Neu. support / News']='P65078',['Neg. support / News']='P65079',[' Deny / News']='P65076',['Report / News']='P65077',['Sydney Siege (Rumours)']='P67054',['Sydney Siege (Non-Rumours)']='P67055',['Validation Accuracy']='P67040',['Technology (Real News)']='P67018',['Finance (Fake News)']='P67019',['Entertainment (Fake News)']='P67002',['isBasedOn']='SCHEMAORG:isBasedOn',['Total Rumours']='P67056',['#News Articles']='P65082',['# Users']='P65087',['size']='SCHEMAORG:size',['Proportion of energy generation with nuclear energy']='P67061',['Proportion of energy generation with biomass']='P67062',['# Sources']='P65083',['# Samples']='P65084',['Fake samples']='P65085',['Real samples']='P65086',['Rumors']='P67043',['aaa']='P66001',['FakeNewsNet']='P66004',['Average Precision']='P66000',[' FakeNewsNet Dataset']='P66002',['COVID-19 Fake News']='P66003',['Real News (PolitiFact)']='P66007',['Fake News (PolitiFact)']='P66008',['Real News (GossipCop)']='P66005',['Fake News (GossipCop)']='P66006',['# Body texts']='P66010',['Agrees (AG)']='P66011',['Disagrees (DSG)']='P66012',['Discusses (DSC)']='P66013',[' Unrelated (UNR)']={'P66014','P66015'},['#Headlines']='P66009',['curated']='P67000',['Germanwings Crash (Rumours)']='P67051',['Total Non-Rumours']='P67057',['Agrees (AGR)']='P66016',['Fake News Accuracy']='P66021',['Macro F1-Score']='P66022',['Tokens']='P67027',['Aagree (%)']='P67031',['Barely-true']='P67078',['Real News Accuracy']='P66020',['%Root Mean Squared Error (RMSE)']='P66027',['Claim Sources']='P66017',['Total News']='P66018',['Unlabeled News']='P66019',['Average Report / Real News (Labeled Testing)']='P66037',['AUC-ROC']='P66038',['F1-Score (Fake News) ']='P66041',['Mean Squared Error (MSE)']='P66023',['Unlabeled Report']='P66028',['Average Report / News (Unlabeled)']='P66029',['Fake News (Labeled Training)']='P66030',['Real News (Labeled Training)']='P66031',['Fake News (Labeled Testing)']='P66032',['Precision (Fake News) ']='P66039',['Recall (Fake News) ']='P66040',['Precision (Real News)']='P66042',['Recall (Real News)']='P66043',['F1-Score (Real News)']='P66044',['%Mean Squared Error (MSE)']='P66024',['Macro Accuracy']='P66025',['Root Mean Squared Error (RMSE)']='P66026',['Real News (Labeled Testing)']='P66033',['Germanwings Crash (Non-Rumours)']='P67050',['Average Report / Fake News (Labeled Training)']='P66034',['Average Report / Real News (Labeled Training)']='P66035',['Average Report / Fake News (Labeled Testing)']='P66036',['Training-Testing split']='P66045',['Unrelated (%)']='P67028',['Discuss (%)']='P67029',['Disagrees (%)']='P67030',['Disagree (%)']='P67032',['alternateName']='SCHEMAORG:alternateName',['Testing Accuracy (%)']='P67041',['Validation Accuracy (%)']='P67042',['Charlie Hebdo (Rumours)']='P67045',['Charlie Hebdo (Non-Rumors)']='P67046',['Charlie Hebdo (Non-Rumours)']='P67047',['assesses']='SCHEMAORG:assesses',['Proportion of energy generation with hydropower']='P67059',['Proportion of energy generation with wind energy']='P67060',['phases of life-cycle']='P67089',['type of energy generation']='P67058',['Mostly-true']='P67076',['False']='P67079',['Pants-fire']='P67080',['Proportion of energy generation with waste treatment']='P67063',['Proportion of energy generation with solar energy']='P67064',['Proportion of energy generation with coal']='P67065',['Proportion of energy generation with natural gas']='P67066',['proportion of energy generation']='P67068',['unit for proportion of energy generation ']='P67069',['True Negative']='P67086',['True Positive']='P67087',['False Negative']='P67088',['proportion unit ']='P67070',['g2tmn 2.csv ']='P67082',['Health-related Fake News']='P67084',['sensors']='wikidata:P9192',['relation extraction']='P67071',['brand']='wikidata:P1716',['exact match']='wikidata:P2888',['Mean']='P67072',['5th percentile']='P67073',['95th percentile']='P67074',['sourceOrganization']='SCHEMAORG:sourceOrganization',['inLanguage']='SCHEMAORG:inLanguage',['sameAs']='SCHEMAORG:sameAs',['URL']='wikidata:P2699',['instance type']='P67090',['Solution']='Solution',['Half-true']='P67077',['relative to']='wikidata:P2210',['Common Words']='P67083',['female population']='wikidata:P1539',['Real News Articles for COVID-19']='P67085',['quantity']='wikidata:P1114',['training']='P67091',['exampleOfWork']='SCHEMAORG:exampleOfWork',['male population']='wikidata:P1540',['context']='P67092',['starts before']='RO:RO_0002089',['human evaluation']='P67093',['baseline evaluation']='P67094',['existence ends at start of']='RO:RO_0002593',['frame rate']='P67097',['Resource']='Resource',['Unique Tweet']='P67095',['Test set']='P67096',['Experimental testbed']='P67099',['OSI Model layer location']='wikidata:P5805',['Deployment location']='P67100',['True Negative Rate (TNR)']='P67108',['reference URL']='wikidata:P854',['Hi-Fi']='P67102',['Low-Fi']='P67103',['Mitigation strategy']='P67101',['subclass of']='wikidata:P279',['Wikimedia import URL']='wikidata:P4656',['Low Costs']='P67104',['High Costs']='P67105',['number of data properties']='P68034',['Adaptivity']='P67106',['True Positive Rate (TPR)']='P67107',['Has concept']='P67109',['content validity']='P68005',['Taxonomy classes']='P68000',['reduction with PHEV compared to ICV']='P68022',['Efficiency algorithm category']='P68001',['Decode']='P68002',['model has time complexity']='P68003',['has_classes']='P110000',['Internal Combustion Diesel Engine Vehicle ']='P68012',['Diesel internal combustion engine vehicle (ICEV-D)']='P68013',['Internal Combustion Engine Vehicles']='P68010',['Battery Electric Vehicle']='P68009',['Proportion of energy creation with thermal power']='P68004',['Competition\'s factors']='P68041',['Gasoline internal combustion engine vehicle (ICEV-G)']='P68014',['closed-loop supply chain']='P68045',['Quantity Value']='P68011',['reduction with BEV relative to ICV']='P68020',['determination method']='wikidata:P459',['reduction with BEV compared with ICV']='P68017',['reduction with PHEV compared with ICV']='P68019',['reduction with HEV relative to ICV']='P68021',['reduction with HEV compared with ICV']='P68018',['Objectif function']='P68047',['Precision score for Fake News (Fake-P)']='P68091',['High Fidelity']='P68023',['Low Fidelity']='P68024',['F1-score for Fake News (Fake-F1)']='P68093',['Recall score for Fake News (Fake-R)']='P68095',['Predictive maintenance']='P68025',['Manufacturing production line']='P68026',['F1-score (True News)']='P68127',['Precision (Macro average)']='P68128',['Precision (Weighted average)']='P68129',['Precision (False News)']='P68116',['Competition']='P68039',['Cost parameters']='P68040',['Disruption']='P68042',['Showbiz (Fake News)']='P68099',['Genuine']='P68052',['Adding Bot (Accuracy)']='P68075',['Adding Fake claim (F1-score)']='P68078',['Genuine (Tweet count)']='P68053',['has eva']='P68043',['available in dbpedia archivo']='P68029',['associated project']='P68030',['number of equivalent classes']='P68035',['F1-score (Other)']='P68125',['F1-score (Partially False)']='P68126',['Eecall score for Fake News (Fake-R)']='P68092',['number of disjoint classes']='P68036',['DBpedia Archivo Status']='P68037',['has serialization']='P68027',['reused ontologies']='P68028',['no of classes']='P68031',['no of instances']='P68032',['associated in project']='P68038',['has baseline']='P68044',['number of object properties']='P68033',['Samples per Class']='P68142',['Unique Tokens']='P68143',['Fake Claim (Bot)']='P68068',['Real News (Bot)']='P68072',['Fake News (Bot)']='P68070',['Real News (Human)']='P68071',['Original Features (Accuracy)']='P68073',['Original Features (F1-score)']='P68074',['Accuracy for Bag of Words (BOW)']='P68139',['Accuracy for Part-of-speech tag (POS)']='P68140',['Accuracy for BOW+POS']='P68141',['closed-loop ']='P68046',['Control']='P68100',['Health (Real News)']='P68081',['Health (Fake News)']='P68082',['Precision (Other)']='P68117',['Recall (Weighted average)']='P68131',['F1-score (Weighted average)']='P68133',['Social spam bot #2 (Tweet count)']='P68056',['Social spam bot #2 (User count)']='P68057',['Social spam bot #3 (Tweet count)']='P68058',['Social spam bot #3 (User count)']='P68059',['Traditional Spam Bot (Tweet count)']='P68060',['Traditional Spam Bot (User count)']='P68061',['Fake Follower (Tweet count)']='P68062',['Adding Bot (F1-score)']='P68076',['Adding Fake claim (Accuracy)']='P68077',['Economy (Real News)']='P68079',['Economy (Fake News)']='P68080',['Science (Real News)']='P68083',['Science (Fake News)']='P68084',['Society (Real News)']='P68087',['Sport (Real News)']='P68089',['Legume Treatment']='P68110',['Real News (Testing size)']='P68134',['Fake News (Testing size)']='P68135',['Fake News (Training size)']='P68136',['Real News (Training size)']='P68137',['Business (Real News)']='P68096',['Business (Fake News)']='P68097',['Showbiz (Real News)']='P68098',['Facilities states']='P68048',['Capacity planning']='P68049',['Soil Nutrient']='P68102',['Cropping System']='P68103',['Test Set Fake-F1']='P68094',['Network redesign']='P68050',['Expansion']='P68051',['Fake News (Human)']='P68069',['Accuracy fo English']='P68144',['Social spam bot #1 (Tweet count)']='P68054',['Social spam bot #1 (User count)']='P68055',['Real Claim (Human)']='P68065',['Real Claim (Bot)']='P68066',['Fake Claim (Human)']='P68067',['Fake Follower (User count)']='P68063',['Genuine (User count)']='P68064',['Partially False']='P68114',['Other']='P68115',['Security (Real News)']='P68085',['Security (Fake News)']='P68086',['Society (Fake News)']='P68088',['Sport (Fake News)']='P68090',['Accuracy with BERT embedding']='P68151',['Accuracy with BERTO embedding']='P68152',['measurementTechnique']='SCHEMAORG:measurementTechnique',['Test Accuracy']='P68148',['Accuracy in Development set (Dev_Acc)']='P68149',['Accuracy with GLOVE embedding']='P68153',['Accuracy for Portuguese Language']='P68145',['Accuracy for English Language']='P68146',['Accuracy for Spanish Language']='P68147',['number of replicates']='P68109',['Control Result Nutrients']='P68104',['Type of Soil Nutrient']='P68108',['Treatment Result Nutrients']='P68105',['Control Result Biomass']='P68106',['Treatment Result Biomass']='P68107',['Recall (Macro average)']='P68130',['F1-score (Macro average)']='P68132',['Bag of Words']='P68138',['Precision (Partially False)']='P68118',['Precision (True News)']='P68119',['Recall (False News)']='P68120',['Recall (Other)']='P68121',['Recall (Partially False)']='P68122',['Recall (True News)']='P68123',['F1-score (False News)']='P68124',['Real News (Validation)']='P68111',['Fake News (Validation)']='P68112',['elevation above sea level']='wikidata:P2044',['Accuracy with ELMo']='P68150',['NLP Techniques']='P69001',['Natural Language Processing (NLP) Technique']='P69002',['Propagation Tress Size']='P69004',['Propagation Trees Size']='P69005',['receiver operating characteristic']='P69000',['symptoms and signs']='wikidata:P780',['download link']='wikidata:P4945',['has lower limit for 68% confidence interval']='P69010',['heat treating']='wikidata:P6212',['number of participants']='wikidata:P1132',['has upper limit for 68% confidence interval']='P69009',['verification']='P69013',['is an individual of taxon']='wikidata:P10241',['Twitter username']='wikidata:P2002',['major challenges']='P70012',['AxonDB+']='P69011',['criterion used']='wikidata:P1013',['parent organization']='wikidata:P749',['threat model']='P69012',['Experimental Setup']='P69015',['Experimental Design']='P69014',['Planting design']='P69016',['Knowledge Graph Construction pahases']='P70009',['Knowledge Graph Construction phases']='P70010',['knowledge graph construction pipeline']='P70011',['external data available at']='wikidata:P1325',['area']='wikidata:P2046',['common approaches']='P70013',['Spectral Index']='P70005',['positive diagnostic predictor for']='wikidata:P3356',['feature importance score']='P69017',['Type of GAN']='P110001',['Network for fault classification']='P110002',['Input data type']='P110003',['Physics included']='P110004',['temporal range end']='wikidata:P524',['Contribution points']='P110005',['temporal range start']='wikidata:P523',['time interval']='P70001',['Evaluation metric']='P110006',['forecast horizon']='P70002',['mean absolute percentage error']='P70003',['used methodology']='P70006',['criteria']='P70007',['used dimensions for analysis']='P70008',['common applications']='P70014',['retrieved']='wikidata:P813',['Open question']='P123050',['terrain attributes']='P70004',['future direction']='P123051',['main subject']='wikidata:P921',['published in']='wikidata:P1433',['image']='wikidata:P18',['platform']='wikidata:P400',['used techniques']='P71025',['venue investigated']='P70015',['Endurance: 9-min run (m) standard deviation']='P70062',['Speed: 20 m Sprint (s) mean']='P70049',['Flexibility: Stand-and-reach (cm) mean aggregate']='P71015',['Endurance: Cycle ergometry test (PWC170) (Watt) standard deviation aggregate']='P71016',['number secretors']='P70016',['number non secretors']='P70017',['Endurance: cycle ergometry test (PWC170)']='P70024',['has system tyype']='P71045',['has Hamming Loss']='P71029',['has ML-accuracy']='P71031',['subset accuracy']='P71032',['Power: standing long jump (cm) mean']='P70028',['Speed: 20 m Sprint (s) standard deviation']='P70064',['Speed: Reaction time (s) mean aggregate']='P71007',['Phases']='P71026',['has Hierarchical loss']='P71030',['used algorithm']='P71024',['owner ']='P70021',['Power: standing long jump (cm) standard deviation']='P70029',['Power: Push-ups (repetitions in 40 s) mean']='P70030',['Power: Push-ups (repetitions in 40 s) standard deviation']='P70031',['Sit-ups (repetitions in 40s) mean']='P70032',['Model specificity']='P71036',['Speed: Reaction time (s) standard deviation aggregate']='P71006',['owner']='P70019',['ontology published']='P70018',['used algorithms']='P71039',['Endurance: Cycle ergometry test (PWC170) (Watt) mean aggregate']='P71017',['topic investigated']='P70020',['micro-averaged precision']='P71033',['micro-averaged recall ']='P71034',['micro-averaged F-measure ']='P71035',['Power: Sit-ups (repetions in 40s) mean aggregate']='P71011',['Upper- and lower- extremity muscular power: ball push (m) mean']='P70053',['Power: Ball-push (m) mean']='P70055',['Agility: Star agility run (s) mean']='P70059',['Dataset Domain']='P70022',['Dataset Subdomain']='P70023',['Coordination: star agility run (s) standard deviation']='P71001',['micro-Fmeasure']='P71043',['Representation Layer']='P71040',['Orthorgraphy-based classes']={'P70042','P70044'},['Semantics-based classes']={'P70043','P70045'},['micro-precision']='P71042',['Speed: 50-m sprint (s) mean']='P70051',['Speed: 20 m (m/s) standard deviation']='P71005',['Flexibility: Stand-and-reach (cm) standard deviation aggregate']='P71014',['Coordination: Balancing backwards (steps) standard deviation aggregate']='P71020',['Coordination: Balancing backwards (steps) mean aggregate']='P71021',['Power: Standing long jump (cm) standard deviation aggregate']='P71008',['Power: Standing long jump (cm) mean aggregate']='P71009',['Power: Sit-ups (repetitions in 40s) standard deviation aggregate']='P71010',['coordination: Star agility run (m/s) standard deviation']='P71003',['Coordination: star agility run (s) mean']='P71000',['Coordination: Jumping sideways (counts in 15 s) standard deviation']='P70037',['Flexibility: Stand-and-reach (cm) standard deviation']='P70039',['Speed: Reaction time (s) mean']='P70040',['Endurance: cycle ergometry test (PWC170) mean']='P70025',['Endurance: cycle ergometry test (PWC170) (Watt) mean']='P70026',['Endurance: cycle ergometry test (PWC170) (Watt) standard deviation']='P70027',['definition']='P71038',['Sit-ups (repetitions in 40s) standard deviation']='P70033',['Coordination: Balancing backwards (steps) mean']='P70034',['Coordination: Balancing backwards (steps) standard deviation']='P70035',['Coordination: Jumping sideways (counts in 15 s) mean']='P70036',['Flexibility: Stand-and-reach (cm) mean']='P70038',['Speed: Reaction time (s) standard deviation']='P70041',['Power: Push-ups (repetitions in 40s) mean aggregate']='P71013',['has quality type']='P71046',['Power: Sit-ups (repetitions in 40s) mean']='P70048',['Power: Sit-ups (repetitions in 40s) standard deviation']='P70047',['has unit']='P71049',['Piwer:Sit-ups (repetitions in 40s) mean']='P70046',['Power: Push-ups (repetitions in 40s) standard deviation aggregate']='P71012',['Speed: 20 m Sprint (s) mean aggregate']='P71022',['Endurance: 6-min run (m) mean aggregate']='P71023',['has types']='P71027',['Hamming loss']='P71028',['Power: Ball push (m) standard deviation']='P70056',['Power: Triple-hop (m) mean']='P70057',['Power: Triple-hop (m) standard deviation']='P70058',['Coordination: Jumping sideways (counts in 15s) standard deviation aggregate']='P71018',['Coordination: Jumping sideways (counts in 15s) mean aggregate']='P71019',['Agility: Star agility run (s) standard deviation']='P70060',['Endurance: 9-min run (m) mean']='P70061',['Endurance: 6-min run (m) standard deviation']='P70063',['Endurance: 6-min run (m) mean']='P70050',['classification ']='P71041',['Speed: 50-m sprint (s) standard deviation']='P70052',['Upper- and lower- extremity muscular power: ball push (m) standard deviation']='P70054',['Coordination: Star agility run (m/s) mean']='P71002',['Speed: 20 m (m/s) mean']='P71004',['micro-recall']='P71044',['Multi-label Classification  categorised in ']='P71037',['Dimensions author ID']='wikidata:P6178',['Scopus author ID']='wikidata:P1153',['type of task']='P71055',['Semantic Scholar author ID']='wikidata:P4012',['has binary']='P71050',['publication date']='wikidata:P577',['relatedTo']='SCHEMAORG:relatedTo',['stopwords']='P71061',['iteration']='P71065',['organizer']='wikidata:P664',['has value']='P71048',['answer provided']='P71051',['has system measurements']='P71047',['configuration setting']='P71058',['number of type']='P71066',['text feature']='P71064',['NDCG@5']='P71059',['stemming']='P71062',['answer Type prediction']='P71052',['relation linking']='P71053',['entity linking']='P71054',['data size']='wikidata:P3575',['amount of questions in the test data']='P71057',['FAIR Principle']='P110007',['amount of questions in training data']='P71056',['NDCG@10']='P71060',['lemma']='P71063',['has part(s)']='wikidata:P527',['country']='wikidata:P17',['knowledge graph name']='P71069',['compliance level 1']='P110008',['compliance level 2']='P110009',['compliance level 3']='P110010',['compliance level 1 score']='P110011',['compliance level 2 score']='P110012',['compliance level 3 score']='P110013',['data splitting method']='P71067',['reporting level']='P71068',['using an ontology']='P71070',['knowledge used']='P71071',['knowledge graph content']='P71072',['number of Least Concern']='P110014',['Number of Vulnerable ']='P110015',['Number of Endangered']='P110016',['Number of species Non Applicable ']='P110017',['African Dragonfly Biotic Index scores (ADBI)']='P110018',['owned by']='wikidata:P127',['Has-baseline']='P71073',['hasModel']='P71074',['Avg Entity']='P71089',['Avg Concept']='P71090',['hasEvaluation']='P71075',['Types of riks']='P71103',['A representative selection of keywords']='P71095',['knowledge graph language']={'P71138','P71137'},['Risk type']='P71101',['Plane']='P71076',['Controller']='P71077',['empty']='P71078',['usageInfo']='SCHEMAORG:usageInfo',['has classes']='P71085',['has training set']='P71086',['Avg Characters']='P71087',['Avg words']='P71088',['classification system']='P71094',['Avg Entities']='P71097',['Avg Length']='P71091',['has uncertainty value']='P71092',['micro-F1']='P71080',['no of labels']='P71083',['has uncertainty unit']='P71093',['Token per News']='P71100',['macro-F1']='P71082',['micro-']='P71084',['validation set']='P71096',['Has-statistics']='P71116',['reference system']='P71098',['CO2 footprint process']='P71099',['assessment']='wikidata:P5021',['biometrics ']='P71107',['R219784']='P71111',['R219786']='P71112',['F1-Score [0c-2w-0f] (Real News)']='P71128',['R219773']='P71110',['time points']='P71113',['R219771']='P71109',['risk factor']='wikidata:P5642',['Supply chain risks management process']='P71106',['Risk types']='P71102',['Quantitative methods']='P71104',['Qualitative methods']='P71105',['hash function']='P71108',['Network domination']='P71114',['Types of relationships based on business procedures']='P71115',['number of recipe']='P71134',['number of triples']='wikidata:P10209',['codomain']='wikidata:P1571',['Number of teams']='P71117',['definition domain']='wikidata:P1568',['F1-Score [1c-1w-0f] (Fake News)']='P71118',['F1-Score [1c-1w-0f] (Real News)']='P71119',['ROC-AUC  [1c-1w-0f]']='P71120',['ROC-AUC [2c-1w-0f]']='P71129',['ROC-AUC [2c-0w-0f]']='P71130',['ROC-AUC [0c-2w-0f]']='P71131',['ROC-AUC [2c-2w-2f]']='P71132',['F1-Score [2c-2w-2f] (Fake News)']='P71121',['F1-Score [2c-1w-0f] (Fake News)']='P71122',['F1-Score [2c-0w-0f] (Fake News)']='P71123',['F1-Score [0c-2w-0f] (Fake News)']='P71124',['F1-Score [2c-2w-2f] (Real News)']='P71125',['F1-Score [2c-1w-0f] (Real News)']='P71126',['F1-Score [2c-0w-0f] (Real News)']='P71127',['question answering components']='P71136',['F1-Score (Five-fold cross-validation)']='P71133',['Germanwings Crash (Non-Rumors)']='P71144',['Ottawa Shooting (Non-Rumors)']='P71146',['Sydney Siege (Rumors)']='P71149',['Total Non-Rumors']='P71150',['Test Accuracy (%)']='P71140',['rows']='CSVW_Rows',['titles']='CSVW_Titles',['question answering task']='P71135',['Number of sites']='P143033',['Subject area classifications']='P71139',['Charlie Hebdo (Rumors)']='P71141',['Sydney Siege (Non-Rumors)']='P71148',['Total Rumors']='P71151',['geographical dataset']='P71186',['Ferguson (Rumors)']='P71143',['Germanwings Crash (Rumors)']='P71145',['Ottawa Shooting (Rumors)']='P71147',['orientation']='wikidata:P7469',['Ferguson (Non-Rumors)']='P71142',['comment']='SCHEMAORG:comment',['evaluation item']='P71154',['textValue']='P71153',['hasKind']='P71152',['number of databases']='P71155',['has Quality Aspects']='P71168',['WOS CC']='P71157',['Dimensions']='P71156',['research intervention']='wikidata:P4844',['Wind power calculated?']='P71190',['has_specified_input']='OBI:OBI_0000293',['Subject sizes']='P71158',['Input Type ']='P71169',['data processing workflow']='P71182',['Commons category']='wikidata:P373',['camera setup']='wikidata:P4312',['turbine data']='P71185',['spatial resolution']='P71180',['model type']='P71176',['Availibility Type']='P71167',['steps']='SCHEMAORG:steps',['has specified value']='OBI:OBI_0002135',['cells']='CSVW_Cells',['Input type']='P71170',['columns']='CSVW_Columns',['number']='CSVW_Number',['Location of']='P71199',['data acquisition workflow']='P71183',['weather/climate dataset used']='P71184',['What would be the ideal Key Performance Indicators (KPIs) in the organizational design of a research institute for commercial agriculture development?']='P110019',['Maine: An Encyclopedia ID']='wikidata:P7697',['mean absolute error']='P71161',['major phases']={'P71205','P71206'},['Deployment']='P71227',['Parameter estimation method']='P143034',['network attacks']='P71222',['Cereal Crop']='P71160',['has_specified_output']='OBI:OBI_0000299',['hasName']='P71166',['is denoted by']='P71165',['has input dataset']='P71162',['has input model']='P71163',['has output dataset']='P71164',['bonding type']='P71171',['number of disjoint ']='P71173',['calculation period']='P71178',['expertise index']='P110022',['reused']='P71172',['Process of']='P71203',['hardware']='P71193',['number of parameters']={'P71194','P103002'},['avg number of column']='P71217',['made from material']='wikidata:P186',['number of relational table']='P71215',['climate exposure']='P110020',['production system']='P110021',['wind rose input']='P71188',['roughness data used']='P71187',['F1-Score']='P71208',['Robustness report']='P71195',['Extra training data']='P71192',['hardware burden']='P71196',['Wind speed calculated?']='P71189',['compliance test']='P112006',['model workflow']='P71191',['Real News (Validation size)']='P72000',['temporal resolution']='P71177',['wind speed height']='P71179',['API']='P71181',['has url ']='P71174',['has result ']='P71175',['has components']='P71207',['Ontology learning component']='P71211',['content injection']='P71219',['cross-site request forgery (CSRF)']='P71220',['cookie forcing']='P71221',['avg number of rows']='P71216',['object']='P110025',['modelling software']='P110026',['simulation software']='P110027',['time period']='wikidata:P2348',['Start']='P110028',['End']='P110029',['scenarios']='P110030',['Electric Vehicles Penetration rate']='P110031',['Energy demand']='P110032',['usability']='P71223',['compatibility']='P71224',['ranking']='wikidata:P1352',['approximate f1 score']='P71212',['approximate precision']='P71213',['models']='P71209',['table source']='P71214',['Number of layer']='P71218',['Goal']='P71225',['Deploymen']='P71226',['Unit of deception']='P71228',['column']='CSVW_Column',['connects with']='wikidata:P2789',['pseudo f-measure']='P110023',['below linear trajectory']='P115016',['above linear trajectory  ']='P115017',['Predictors (indipendent variables)']='P110041',['Predictors (independent variables)']='P110042',['Models (Estimators)']='P110043',['Dataset split']='P110044',['Hyperparameter tuning']='P110045',['Specific goals of the research']='P110046',['Model evaluation']='P110047',['Data observation stations']='P110048',['Time framework (planning, modeling)']='P110049',['cites repository']='P114000',['Time step']='P110050',['AIS data']='P110051',['multi-fidelity']='P71231',['instance']='P71232',['has command line option']='wikidata:P4837',['Number of unique words (Real News)']='P72002',['has subquality type']='P110067',['cost']='wikidata:P2130',['test machine']='P110052',['off-axis loads?']='P110053',['Did WECs occur?']='P110054',['Lubrication']='P110055',['Lubrication Regime']='P110056',['suggests semantic standard languages']='P114001',['complex hyperparameter space']='P71229',['multi-objective']='P71230',['parallel computing']='P71233',['time to failure']='P110057',['source of material']='wikidata:P2647',['dependability']='P71237',['loading cycles until failure']='P110058',['WEC-critical lubricants used?']='P110118',['statement']='P111000',['significant event']='wikidata:P793',['#wikidata:Q2995644']='P110059',['investigated relation']='P110060',['related concept']='P110061',['flexibility']='P71234',['count of corpora\'s sentense']='P110062',['number of words']='wikidata:P6570',['BLEU']='P110063',['Translation error rate']='P110064',['Translation error rate (%)']='P110065',['source']='P110066',['lifecycle management']='P71235',['effectiveness']='P71236',['ecological study system']='P115000',['official name']='wikidata:P1448',['input method']='wikidata:P479',['frequency']='wikidata:P2144',['other results']='P110100',['slide-to-roll-ratio']='P117000',['maximum number of parameters (in Million)']='P110076',['is automatic']='P110071',['Number of unique words (Fake News)']='P72003',['ontology editor']='P110068',['number of standard FAIR assessments']='P110072',['standard FAIR assessments']='P110073',['custom FAIR assessments possible']='P110074',['API endpoint URL']='wikidata:P6269',['source code repository URL']='wikidata:P1324',['has application object']='P110075',['coordinate location']='wikidata:P625',['Knowledge exchange']='P114002',['Fake News (Validation size)']='P72001',['Real News (labels)']='P72004',['Information exchange']='P114003',['Fake News (labels)']='P72005',['number of features']='P72007',['Sub-category']='P113000',['described by source']='wikidata:P1343',['full work available at URL']='wikidata:P953',['number of trees']='P72006',['Electric Vehicle Penetration Rate(%)']='P110077',['Projected Year']='P110078',['electricity demand/consumption (GWh)']='P110079',['has Proof']='P110080',['has implementation']='P110081',['training samples']='P72008',['Student`s condition']='P110082',['Hand-tailored ICT']='P110083',['Offline use']='P110084',['Immersive technology ']='P110085',['Time per session with ICT']='P110086',['Mentor presence']='P110087',['Skills development  ']='P110088',['point in time']='wikidata:P585',['Type of participant']='P110089',['Interview type ']='P110090',['Data management (analysis) system']='P110091',['Statistical method']='P110092',['genomic or gene analysis results']={'P110101','P110102'},['Ontology Language']='P110093',['current collector']='P114004',['Sample']='P110094',['Location of sample']='P110095',['Taxonomic affiliation of isolated strain']='P110096',['Arsenite oxidation couple to']='P110097',['Strain name']='P110098',['Culture conditions']='P110099',['kernel width parameters']='P72009',['pointAnomaly']='P110103',['sequenceAnomaly']='P110104',['Missing rate (%)']='P110105',['single point anomaly AUC-ROC']='P110106',['multiple point anomalies AUC-ROC']='P110107',['sequence anomaly AUC-ROC']='P110108',['point anomaly AUC-ROC']='P110109',['trend']='P111001',['relative difference']='P111002',['amount of explained triples']='P110110',['amount of triples taken into account']='P110111',['decrease']={'P111003','P111006','P111005','P111004','P111008','P111007'},['Failure occurred?']='P110119',['main techniques used']='P110112',['reuse of other ontologies']='P110113',['domain of application']='P110114',['supported by tool']='P110115',['alternative name']='wikidata:P4970',['Electrical Current Applied?']='P110116',['current year']='P111009',['comparison year']='P111010',['Participant: signer with different hand size']='P118061',['current value']='P111011',['answer']='P111013',['comparsion operator']='P111014',['Hertzian contact pressure [MPa]']='P110117',['start time']='wikidata:P580',['continent']='wikidata:P30',['investigated_quality']='P110120',['measurement']='P110121',['year of measurement']='P110122',['measurement value']='P110123',['relative difference to 1990']='P110125',['task type']='P110126',['target value']={'P110127','P138014'},['raw data']='P110128',['writing language']='wikidata:P6886',['accessibility statement URL']='wikidata:P9494',['authority']='wikidata:P797',['Available Ontology Language Formats']='P112007',['trained parameter']='P112000',['Type of system']='P74001',['Validation Method']='P112008',['permanent duplicated item']='wikidata:P2959',['Authors with affiliations']='P74027',['Correspondence Address']='P74028',['has evaluation tool']='P118014',['has input parameters']='P118015',['has implementation type']='P118016',['has ecological organizational scale']='P115001',['ecological organizational scale']='P115002',['end time']='wikidata:P582',['Discuss (Training size)']='P74011',['Capacity']='P74000',['Specific energy consumption  function']='P73002',['human-readable data']='P112004',['machine-readable data']='P112005',['Specific energy consumption ']='P73001',[' Energy components']='P73000',['Fine-tuning Task']='P116000',['diameter']='wikidata:P2386',['thickness']='wikidata:P2610',['composition']='P112009',['Accuracy (Disagree)']='P74018',['composition reference']='P112010',['anode']='P112011',['cathode']='P112012',['battery separator']='P112013',['nominal capacity']='P112014',['electrochemical cell']='P112015',['electric current']='P112016',['charge capacity']='P112017',['charge efficiency']='P112018',['Unrelated (Training size)']='P74012',['Agree (Testing size)']='P74013',['Disagree (Testing size)']='P74014',['Total Events']='P74022',['Average Posts per Event']='P74023',['Minimum Posts per Event']='P74024',['Maximum Posts per Event']='P74025',['ISSN']='P74029',['Number of training instances']='P74007',['Number of training headlines']='P74005',['Number of test headlines']='P74006',['Number of test instances']='P74008',['Total Posts']='P74021',['mass loading']='P112019',['question template']='P74002',['generated question']='P74003',['Affiliations']='P74026',['CODEN']='P74032',['Training loss']='P74004',['PubMed ID']='P74033',['Language of Original Document']='P74030',['Abbreviated Source Title']='P74031',['title']='wikidata:P1476',['Agree (Training size)']='P74009',['Disagree (Training size)']='P74010',['Discuss (Testing size)']='P74015',['Unrelated (Testing size)']='P74016',['Accuracy (Agree)']='P74017',['Accuracy (Discuss)']='P74019',['Accuracy (Unrelated)']='P74020',['Editors']='P74034',['tool type']='P112021',['Average retweet per story']='P74035',['Average words per source tweet']='P74036',['is fully developed']='P112022',['required expertise']='P112023',['guidance']='P112024',['easy to use']='P112025',['time investment']='P112026',['type of input']='P112027',['applicability']='P112028',['type of output']='P112029',['improvement suggestion']='P112030',['habitat']='wikidata:P2974',['approximated estimate']='P112035',['has rendered model']='P112031',['Soil quality Parameter']='P121012',['incentive system']='P112032',['blockchain type']='P112033',['similarity metric']='P119081',['project state']='P112034',['maintains linking to']='wikidata:P10568',['F1-score (Micro average)']='P74037',['proportion']='wikidata:P1107',['sector']='P112036',['power']='P112037',['competency question']='P74038',['spatial grain']='P115003',['Average time length per event (in hours)']='P84018',['Average post per event']='P84019',['Maximum post per event']='P84020',['learning technique']='P75000',['cites work']='wikidata:P2860',['percent of stimulation intensity']='P114005',['percent of stimulation intensity (min value)']='P114006',['percent of stimulation intensity (max value)']='P114007',['spatial replication']='P115004',['has spatial replication']={'P115005','P115006'},['observation unit']={'P115007','P115008'},['Minimum post per event']='P84021',['GC-Content']={'P115009','P115011','P115012','P115013','P115014','P116001'},['Bacteria']='P115010',['common analysis method']='P76000',['common methods']='P76001',['significance']='P76002',['supports hypothesis']='P116006',['partition label']='P76004',['participant']='wikidata:P710',['energy consumption type']='P115015',['CO 2eq w/o Use and EoL knitted fabric']='P86017',['CO 2eq w/o Use and EoL knitted fabric Nylon']='P86018',['CO 2eq w/o Use and EoL knitted fabric acryl']='P86019',['Twitter Results']='P85000',['intended public']='wikidata:P2360',['Review and advance the state of knowledge regarding the evaluation of soundscape resources for landscape planning']={'P116010','P116015','P116020'},['provide a planning-oriented soundscape resource evaluation (PSRE) framework']={'P116011','P116016','P116021','P116025'},['Synthesize evidence of people’s preferences for soundscape compositions in green spaces']={'P116012','P116017','P116022'},['Examine the health and well-being values of various natural sounds']={'P116013','P116018','P116023'},['Propose an initial assessment approach, which could be a supplement to the current landscape aesthetic quality assessment and environmental impcat assessments in landscape planning']={'P116014','P116019','P116024'},['examine the values of various natural sounds, based on the effect sizes of natural sounds on human health and well-being']={'P116026','P116027'},['test method']='wikidata:P4988',['outcome variable(s)']='P116002',['Weibo Results']='P85001',['product or material produced']='wikidata:P1056',['number of units']='P85002',['CO 2eq w/o Use and EoL POLYESTER KNIT SHIRT']='P86014',['CO 2eq w/o Use and EoL cotton knit shirt']='P86015',['CO 2eq w/o Use and EoL t-shirt']='P86016',['CO 2eq w/o Use and EoL knitted fabric PET']='P86020',['CO 2eq w/o Use and EoL knitted fabric elastan']='P86021',['describes a project that uses']={'wikidata:P4510','P126001'},['medical condition']='wikidata:P1050',['Difference w/ Use and EoL polyester knit shirt']='P86026',['Difference w/ Use and EoL cotton knit shirt']='P86027',['NGSO operational challenges']='P84000',['Waveform design and access schemes']='P84001',['Software-defined satellites']='P84002',['Resource optimization']='P84003',['NGSO space missions']='P84004',['Constellation design methods']='P84005',['Inter-satellite connectivity']='P84006',['Interference management']='P84007',['Secure communications']='P84008',['In-space backhauling']='P84009',['NGSO active antenna systems']='P84010',['Satellite network slicing']='P84011',['keyword metadata']='P91014',['ontology design pattern']='P83000',['Accuracy (Real News)']='P84012',['Accuracy (Fake News)']='P84013',['main outcome measures']='P116003',['Dialog management component']='P83010',['Ambiguity handling']='P83011',['Data handling']='P83012',['Error handling']='P83013',['Backend']='P83014',['Response generation component']='P83015',['intervention duration']='P116004',['COD removal (%)']='P86005',['COD /BOD5']='P86006',['TOC removal (%)']='P86007',['COD (mg O2⋅L−1)']='P86004',[' Misleading Content (Training size)']='P85006',['Imposter Content (Testing size)']='P85010',['Manipulated Content (Training size)']='P85015',['Manipulated Content (Testing size)']='P85016',['linear indicative trajectory']='P116005',['Difference w/ Use and EoL t-shirt']='P86028',['Satire (Testing size)']='P85004',['Satire (Validation size)']='P85005',[' Misleading Content (Testing size)']='P85007',[' Misleading Content (Validation size)']='P85008',[' Initial pH of the treatment']='P86001',['BOD5 (mg O2⋅L−1)']='P86002',['BOD5 removal (%)']='P86003',['Satire (Training size)']='P85003',['minimum value']='wikidata:P2313',['False Content (Training size)']='P85013',['False Content (Validation size)']='P85014',['Manipulated Content (Validation size)']='P85017',['maximum value']='wikidata:P2312',[' Imposter Content (Training size)']='P85009',['Detailed Architectural Design']='P83004',['Retrieval-based']='P83006',['Generative-based']='P83007',['CO 2eq w/o Use and EoL knitted']='P86029',['pages metadata']='P93005',['task']='P83002',['CO 2eq w/o Use and EoL triclosan']='P86022',['CO 2eq w/o Use and EoL nanosilver-FSP']='P86023',['Difference w/ Use and EoL wool knit']='P86025',['question answering type of system']='P80004',['user query']='P80005',['dietary preference']='P80006',['health guidelines']='P80007',['mention Type']='P80009',['number of Post']='P80010',['dietary preferences']='P81000',['propose an initial assessment approach, which could be a supplement to the current landscape aesthetic quality assessment and environmental impact assessments in landscape planning']='P116028',['has boundary']='wikidata:P4777',['Total Impact Category w/ Climate Change']='P86010',['CO 2eq w/o Use and EoL']='P86011',['Difference w/ Use and EoL']='P86012',['CO 2eq w/o Use and EoL WOOL KNIT SWEATER']='P86013',['classifier']='wikidata:P5978',['major classes']='P82003',['User Engagements (Training size)']='P84015',['User Engagements (Testing size)']='P84016',['User Engagements (Validation size)']='P84017',['Satire News']='P84014',['score']='P82004',['type of enhancement']='P130050',['Evaluation Datasets']='P130051',['Imposter Content (Validation size)']='P85011',['False Content (Testing size)']='P85012',['used operation']='P83001',['Spell checker']='P83009',['translator']='wikidata:P655',['type of evaluation']='P82001',['experimental unit']='P77000',['Number of experimental units']='P77001',['CO 2eq w/o Use and EoL nanosilver-plaSpu']='P86024',['year created']='P80000',['Promlem']='P79008',['age minimum including']='P80002',['age maximum including']='P80003',['machine or human evaluation']='P82002',['average number of answer']='P79005',['average raw query length']='P79003',['average expanded query length']='P79004',['average number of constraint']='P79006',['Mean Average Recall']='P79007',['WEC initiation mechanism']='P142007',['granularity created']='P80001',['dataset config']='P81001',['method evaluated']='P82000',['Has resu']='P78030',['scenario modelled']='P78031',['Study']='P79001',['Has res']='P78032',['geographical extent']='P116007',['considered aspect']='P79002',['invader taxon']='P116008',['has ecological study design']='P116009',['User message analysis component']='P83008',['orkg:P78000']='P78016',['orkg:P78001']='P78017',['orkg:P78002']='P78018',['orkg:P78009']='P78019',['orkg:P78010']='P78020',['orkg:P78011']='P78021',['orkg:P78012']='P78022',['orkg:P78013']='P78023',['orkg:P78014']='P78024',['orkg:P78015']='P78025',['note']='P78015',['orkg:P78005']='P78026',['orkg:P78006']='P78027',['orkg:P78007']='P78028',['orkg:P78003']='P78029',['evaluation setting']='P116029',['do']='P79000',['Wikidata item of this property']='wikidata:P1629',['Wikidata ID']='P76020',['Goal and Scope']='P77002',['has output statement']='P117001',['has output figure']='P117002',['has lmm fitting']='P117003',['has response variable']='P117004',['has object of interest']='P117005',['has matrix']='P117006',['is constrained by']={'P117007','P117008'},['investigation area']='P117009',['travel behavior']='P117010',['type of sources']='P77003',['tend to reside in urban areas']='P117011',['No significant difference between young and older adults.']='P117012',['Intervention']='P77004',['attitude towards car use']='P117013',['attitude towards walking']='P117014',['travel mode frequeny']='P117015',['travel model frequency']='P117016',['residential location']='P117017',['https://www.wikidata.org/wiki/Q58083078']={'P117018','P117051'},['Intervention Type']='P77005',['more positive']='P117019',['compared to ']='P117020',['young adults']='P117021',['compared to older adults']='P117022',['has fixed effect term I']='P117023',['The type of the questionnaire']='P117024',['Type of questionnaire']='P117025',['Survey administration ']='P117026',['L2']='P117027',['Tasks to achieve the goal']='P117028',['Text collection type']='P117029',['Text collection title']='P117030',['Student degree']='P117031',['Text collection tailored']='P117032',['Texts type']='P117033',['Corpus tailored']='P117034',['Corpus/Text collection title']='P117035',['Corpus manager']='P117036',['Linguistic unit']='P117037',['Linguistic phenomena']='P117038',['Children’s Short Stories in English ']='P117039',['more likely']='P117040',['comapred to']='P117041',['multiple mobility tools']='P117042',['less likely']='P117043',['data transformation']='P117044',['data scaling']='P117045',['input shape']='P117046',['output shape']='P117047',['modeling specifics']='P117048',['has precision']='P117049',['mineral association']='P77006',['Abstract Architectural Design']='P83003',['Rule-based']='P83005',['Critique d\'art ID']='wikidata:P6325',['ground truth answer']='P80008',['intraburst frequency ']='P78001',['stimulation intensity selection approach']='P78002',['threshold-estimation strategies ']='P78003',['hreshold measurement']='P78004',['threshold measurement']='P78005',['amplitude of the motor evoked potential in microvolt']='P78006',['travel mode frequency']='P117050',['type of rTMS']='P78000',['threshold ratio']='P78007',['percentage or the amplitude of the motor threshold contraction']='P78008',['maximum stimulator output']='P78009',['stimulator company']='P78010',['stimulator model ']='P78011',['coil shape']='P78012',['coil size']='P78013',['coil model']='P78014',['Impact categories']='P86000',['Turbidity removal (%)']='P86008',['Color removal (%)']='P86009',['microbe']='P86031',['type of toxin']='P86032',['Site selection']='P86030',['toxin effect']='P86033',['field of work']='wikidata:P101',['% of respondents']='P87000',['UML ID']='P88001',['color shade']='P91016',['industry']='wikidata:P452',['Question Answering category']='P87001',['RoBERTa-BiLSTM-CRF']='P92001',['volume metadata']='P93008',['editor metadata']='P93001',['organization metadata']='P93014',['number metadata']='P93015',['date metadata']='P91006',['type of the paper']='P91000',['web or url metatada']='P91008',['degree metadata']='P91009',['ref-marker metadata']='P93010',['radiation resolution']='P90000',['status metadata']='P93012',['affiliation metadata']='P91003',['address metadata']='P91004',['metadata dataset type']='P93009',['phone number metadata']='P91007',['abstract metadata']='P91012',['introduction metadata']='P91013',['page metadata']='P91015',['ISSN metadata']='P91010',['note metadata']='P91011',['institution metadata']='P93002',['journal metadata']='P93003',['location metadata']='P93004',['school metadata']='P93019',['publisher metadata']='P93006',['tech metadata']='P93007',['Benchmark Corpus']='P92000',['To delete']='P89000',['language metadata']='P93013',['book title metadata']='P93000',['chapter metadata']='P93017',['department metadata']='P93020',['person-first metadata']='P93021',['venue metadata']='P93011',['title metadata']='P91001',['author metadata']='P91002',['email metadata']='P91005',['#description']='P89001',['series metadata']='P93016',['thesis metadata']='P93018',['person- middle metadata']='P93022',['person-last metadata']='P93023',['person-affix metadata']='P93024',['number of fields ']='P94000',['number of records']='wikidata:P4876',['testing records']='P94002',['training records']='P94001',['method type']='P94003',['Overpotential']='P94032',['corpus origin']='P117054',['corpus tiers']='P117055',['explanation ']='P117056',['sign language']='P117057',['Project title']='P117058',['Signers involved']='P117059',['signer`s requirements']='P117060',['Corpus Cardinality']='P117061',['neighbor feature']='P94009',['numeric feature']='P94010',['word feature']='P94004',['external feature']='P94008',['line feature']='P94005',['spatial feature']='P94006',['formatting feature']='P94007',['objective key-insight']='P94011',['method key-insight ']='P94012',['hypothesis key-insight']='P94020',['motivation key-insight']='P94021',['goal key-insight']='P94022',['object key-insight']='P94023',['experiment key-insight']='P94024',['observation key-insight']='P94026',['gap key-insight']='P94027',['purpose key-insight']='P94028',['approach key-insight']='P94030',['outcome key-insight']='P94031',['model key-insight']='P94025',['hours of video']='P117062',['signs and phrases']='P117063',['running words']='P117064',['Number of signs and phrases']='P117065',['problem key-insight']='P94018',['process key-insight']='P94019',['challenge key-insight']='P94029',['Number of running words']='P117066',['Number of signs']='P117067',['Number of singletons']='P117068',['captured with']='wikidata:P4082',['conclusion key-insight ']='P94014',['future work key-insight']='P94017',['captured with cameras, number']='P117069',['result key-insight']='P94013',['background key-insight']='P94015',['related work key-insight']='P94016',['Annotation software']='P117070',['Transcription sstem']='P117071',['Transcription system']='P117072',['number of videos']='P117073',['Clusters']='P95000',['vertical depth']='wikidata:P4511',['Sampling Design']='P94033',['Medical Relation Extraction(MRE)']='P95002',['R-script']='P94034',['Medical Problems']='P95003',['Total']='P95005',['underlying model']='P95006',['Producer’s accuracy']='P96009',['Zone Mapping']='P96000',['Roles']='P96005',['Users']='P96006',['Service']='P96001',['Offering']='P96003',['Context Predicate']='P96004',['User’s accuracy']='P96008',['Conference metadata']='P97030',['text-body metadata']='P97032',['StudyStartDate']={'P96010','P97190','P97183'},['StudyEndDate']={'P96011','P97182','P97189'},['green space per capita']='P96007',['k(from KNN)']='P96047',['k']='P96050',['Conference']='P97006',['FirstAuthor']='P96012',['City']='P96013',['GeographicalRegion']='P96014',['StringencyIndex']={'P96015','P97188'},['PM25_prcnt_change']={'P96016','P97143','P97146'},['PM25_ugm3_Reference_avg']={'P96017','P97181','P97186'},['PM25_ugm3_Reference_sd']={'P96018','P97187'},['PM25_ugm3_Lockdown_avg']={'P96019','P97184','P97179'},['PM25_ugm3_Lockdown_sd']={'P96020','P97185','P97180'},['precipitation height']='wikidata:P3036',['descriptive validity']='P97000',['t']='P96051',['AdditionalDetails']='P96021',['NO2_prcnt_change']='P96022',['NO2_ugm3_Reference_avg']='P96023',['NO2_ugm3_Lockdown_avg']='P96024',['NOX_prcnt_change']='P96025',['O3_prcnt_change']='P96026',['O3_ugm3_Reference_avg']='P96027',['O3_ugm3_Lockdown_avg']='P96028',['NO2_ugm3_Reference_sd']='P96029',['CO_prcnt_change']='P96030',['CO_mgm3_Reference_avg']='P96031',['CO_mgm3_Reference_sd']='P96032',['CO_mgm3_Lockdown_avg']='P96033',['PM10_prcnt_change']='P96034',['AQI_prcnt_change']='P96035',['NO2_prcnt_change_er']='P96036',['PM10_prcnt_change_er']='P96039',['O3_prcnt_change_er']='P96040',['O3_ugm3_Reference_sd']='P96041',['CO_prcnt_change_er']='P96037',['PM25_prcnt_change_er']='P96038',['SO2_prcnt_change']='P96042',['SO2_prcnt_change_er']='P96043',['NO2_ugm3_Lockdown_sd']='P96044',['repeatability']='P97002',['Dataset']='P96045',['Standford NLP']='P96046',['R']={'P96048','P96049'},['theoretical validity']='P97001',['Place']='P97007',['task facet']='P97003',['research facet']='P97004',['contribution facet']='P97005',['str1']='P117074',['str2']='P117075',['Category type']='P117076',['primary task']='P117077',['acquisition type']='P117078',['biography metadata']='P97011',['caption']='P97012',['drop-cap']='P97013',['reader-service metadata']='P97023',['synopsis metadata']='P97024',['abstract-body metadata']='P97008',['abstract-heading metadata']={'P97010','P97009'},['highlight metadata']='P97014',['drop-cap metadata']='P97015',['caption metadata']='P97016',['keyword-body metadata']='P97017',['keyword-heading metadata']='P97018',['pseudo code metadata']='P97021',['text-body']='P97025',['author affiliation metadata']='P97026',['membership metadata']='P97019',['page number metadata']='P97020',['publication-info metadata']='P97022',['author affiliation mapping metadata']='P97027',['table of content metadata']='P97028',['other metadata']='P97029',['Place metadata']='P97031',['approch']='P97034',['tool']='P97039',['tool advantages']='P97040',['tool  description']='P97041',['tool benefits']='P97042',['similar tools']='P97044',['geometrical feature']='P97033',['annotation challenge']='P97125',['approach advantages']='P97038',['ground truth provided']='P97055',['Aligned with FAIR principles']='P97116',['Knowledge Graph used for annotation']='P97110',['tool URL']='P97043',['approach description']='P97036',['approach benefits']='P97037',['has effect']='wikidata:P1542',['# row']='P97112',['starting date']='P97047',['ending date']='P97048',['semtab systems']='P97056',['challenge name']='P97046',['# CPA target']='P97122',['challenge track']='P97051',['first prize']='P97102',['second prize comment']='P97106',['ReferenceCount']='P97058',['CitationCount']='P97059',['InfluentialCitationCount']='P97060',['IsOpenAccess']='P97061',['tool disadvantages']='P97045',['Easy-to-Learn']='P97080',['third prize comment']='P97107',['source of assessment']='P97075',['Memorywise-Effortless']='P97076',['knowledge graph']='P97052',['# participants']='P97053',['challenge platform']='P97054',['# round']='P97049',['tasks']='P97050',['FieldsOfStudy']='P97062',['PublicationTypes']='P97063',['PublicationDate']='P97064',['paper:publicationDate']='P97073',['Easy-Recovery-from-Loss']='P97083',['Accessible']='P97084',['Negligible-Cost-per-User']='P97085',['property of the dataset']='P97123',['paper:venue']='P97065',['paper:year']='P97066',['paper:referenceCount']='P97067',['paper:citationCount']='P97068',['paper:influentialCitationCount']='P97069',['paper:isOpenAccess']='P97070',['paper:fieldsOfStudy']='P97071',['paper:publicationTypes']='P97072',['paper:abstract']='P97074',['# classes']='P97113',['# predicate']='P97114',['# entity']='P97115',['dataset annotation type']='P97124',['# table']='P97109',['# avg column']='P97119',['# CTA target']='P97121',['Themes']='P117079',['edition number']='wikidata:P393',['# column']='P97111',['type of table']='P97117',['# avg row']='P97118',['split into']='P97126',['Resilient-to-Phishing']='P97096',['Resilient-to-Theft']='P97097',['No-Trusted-Third-Party']='P97098',['Requiring-Explicit-Consent']='P97099',['Scalable-for-Users']='P97077',['Resilient-to-Leaks-from-Other-Verifiers']='P97095',['Unlinkable']='P97100',['Nothing-to-Carry']='P97078',['Physically-Effortless']='P97079',['Server-Compatible']='P97086',['Browser-Compatible']='P97087',['Mature']='P97088',['Non-Proprietary']='P97089',['Efficient-to-Use']='P97081',['Infrequent-Errors']='P97082',['Resilient-to-Physical-Observation']='P97090',['Resilient-to-Targeted-Impersonation']='P97091',['Resilient-to-Throttled-Guessing']='P97092',['Resilient-to-Unthrottled-Guessing']='P97093',['Resilient-to-Internal-Observation']='P97094',['# CEA target']='P97120',['# accepted submission']='P97127',['# rejected submission']='P97128',['# poster']='P97129',['tabular dataset']='P97130',['second prize']='P97103',['third prize']='P97104',['first prize comment']='P97105',['# core participant']='P97108',['Memorywise-Effortless 2']='P97101',['column property annotation']='P97133',['matching strategy']='P97135',['system module']='P97136',['column entity annotation']='P97131',['column type annotation']='P97132',['# submission']='P97134',['label generation technique']='P97139',['spliting technique']='P97140',['table selection']='P97137',['table selection technique']='P97138',['CTA']='P97160',['# annotated column']='P97162',['co-located with']='P97147',['city']={'P97141','P97144'},['Bacterium']='P117080',['lesson learn']='P97148',['lesson learned']='P97149',['participated challenge']='P97167',['cta method']='P97164',['cea method']='P97165',['cpa method']='P97166',['computational evaluation']='P97168',['publisher']='wikidata:P123',['submitted papers']='P117081',['accepted papers']='P117082',['acceptance rate']='P117083',['part of the series']='wikidata:P179',['hasExtendedVersion']='P117084',['entity ']='P97159',['# DBpedia properties']='P97150',['# Schema.org property']='P97151',['# schema.org class']='P97152',['# CEA participant']='P97154',['CPA participant']='P97155',['# CTA participant']='P97153',['average F1 CEA']='P97156',['average F1 CTA']='P97157',['average F1 CPA']='P97158',['recall CEA']='P97202',['precision CEA']='P97203',['precision CTA']='P97205',['types of change']='P117085',['change in species due to climate change']='P117086',['allows for attribution to climate change']='P117087',['# data source']='P97163',['recall CTA']='P97204',['round participated']='P97208',['# Avg. Cols (target CPA)']='P97196',['# Avg. Rows (target CEA)']='P97193',['# Avg. Cols (target CEA)']='P97194',['# Avg. Cols (target CTA)']='P97195',['# min row']={'P97169','P97170','P97171','P97172'},['# max column']='P97175',['# max row']='P97173',['# min column']='P97174',['limit of existing']='P97176',['# NILs mention']={'P97177','P97178'},['Data gathering procedure']='P117088',['recall CPA']='P97206',['precision CPA']='P97207',['other awarded']='P97191',['other awarded comments']='P97192',['element extracted']='P97197',['table language']='P97198',['has evaluation']='wikidata:P5133',['linked cells']='P97199',['# linked cells']='P97200',['# typed cols']='P97201',['comment on the challenge']='P97209',['property of the system']='P97210',['Average Hierarchical Score']='P97211',['Average Perfect Score']='P97212',['Cloud computing']='P117089',['official website']='wikidata:P856',['ideal execution time']='P102000',['current execution time']='P102001',['f1 CEA']='P99000',['f1 CTA']='P99001',['f1 CPA']='P99002',['ratio of jobs per working age population larger than 0.2 reached with public transport in  a max. 45 minutes period']='P100000',['most important restriction to job accessibility  ']='P100001',['accessibility levels']='P100002',['GINI coefficient for time of travel ']='P100003',['GINI Coefficient for number of transfers ']='P100004',['GINI coefficient for transportation costs']='P100005',['has category']={'P100006','P100007'},['has implementation approach']='P118017',['is lower than accessibility for ']='P100008',['coverage annotation ratio']='P100009',['has basic parameters']='P117090',['smaller']='P101000',['London\'s GINI coefficient for time of travel ']='P101001',['Sap Paulo\'s GINI coefficient for time of travel ']='P101002',['London\'s GINI Coefficient for number of transfers ']='P101003',['Sao Paulo\'s GINI Coefficient for number of transfers ']='P101004',['London\'s GINI coefficient for transportation costs']='P101005',['Sao Paulo\'s GINI coefficient for transportation costs']='P101006',['New York\'s GINI coefficient for time of travel ']='P101007',['Sao Paulo\'s GINI coefficient for time of travel ']='P101008',['New York\'s GINI Coefficient for number of transfers ']='P101009',['New York\'s GINI coefficient for transportation costs']='P101010',['has quality review']='hasQualityReview',['Benchmark']='PWC_HAS_BENCHMARK',['approximate F1-score CEA']='P99003',['approximate F1-score CTA']='P99004',['approximate F1-score CPA']='P99005',['approximate precision CEA']='P99006',['approximate precision CTA']='P99007',['approximate precision CPA']='P99008',['approximate recall CEA']='P99009',['approximate recall CTA']='P99010',['approximate recall CPA']='P99011',['has medical condition']='P117091',['group of workers']='P99012',['ah-score CTA']='P99013',['ap-score CTA']='P99014',['Indicators influenced by the intervention']='P118044',['manual workers']='P99015',['dependency on age ']='P118000',['has maximum at']='P118001',['dependency on age']='P118002',['declining with age']='P118003',['millenials']='P118004',[' shift from driving to transit']='P118005',['decline in personal car ownership']='P118006',['shift']='P118007',['proportion on the group of workers']='P99016',['proportion in the group of workers']='P99017',['assumption']='P99018',['decline']='P118008',['living conditions']='P118009',['https://www.wikidata.org/wiki/Q1404808']='P118010',['longer studies']='P118011',['changes in residential attitudes/lifestyles']='P118012',['compared to groups of elder people']='P118013',['Pretraining Architecture']='P103000',['Pretraining Task']='P103001',['blog post']='P103003',['Available Languages']='P104000',['Available Ontology Languages']='P104001',['Sourcecode']='P104002',['Accessibility']='P104003',['Used Upper Ontologies']='P104004',['Governing Instances']='P104005',['Maintenance']='P104006',['Latest Release']='P104007',['Description Size']='P104008',['Description Quality']='P104009',['Number of Terms']='P104010',['Used Ontologies']='P104011',['Creation Type']='P104012',['Automatic Analysis']='P104013',['Modularity']='P104014',['Extensability']='P104015',['AI paradigm']='P104016',['Contributes to communication how']='P118018',['image resolution']='P104017',['image resized resolution ']='P104018',['# trained images']='P105000',['# test images']='P105001',['# rating']='P105002',['# user']='P105003',['# rating type']='P105004',['# movie']='P105005',['# genre']='P105006',['# rating on movie genre']='P105007',['Data Access Layer']='P118019',['Defined Challenges']='P118020',['Degree of impairment']='P118021',['system name']='P105008',['connectionist model']='P105009',['symbolic model']={'P105010','P105011'},['system feature']='P105012',['reasoning type']='P105013',['reasoning goal']='P105014',['ablation study']='P105015',['Experiment participants']='P118022',['Research participants']='P118023',['Participant: deaf-mute person']='P118059',['Interface layer']='P118024',['model name']='P105016',['has use']='wikidata:P366',['Optimizer']='P105017',['drop out probability']='P105018',['# epoch']='P105019',['Logic Layer']='P118025',['has control parameters']='P118026',['Performance criteria']='P118027',['contibution objective']='P118028',['Sense']='P118029',['type of inference']='P105020',['type of inference supported']='P105021',['inference engine']={'P105022','P105023','P105024'},['Review Article']='P105025',['Introduction']='P105026',['evaluation data']='P105027',['evaluation data split']='P105028',['infrastructure']='P105029',['process steps']='P105030',['provenance support']='P105031',['component model']='P105032',['has application domain']='P105033',['has corresponding pattern']='P105034',['has processing engine']='P105035',['Resource Formalism']='P105036',['resource size']='P105037',['resource type']='P105038',['has statistical model']='P105039',['has KR step 1']='P105040',['has ML step 1']='P105041',['has ML step 2']='P105042',['has ML step 3']='P105043',['has ML step 4']='P105044',['has ML step 5']='P105045',['has system maturity']='P105046',['has training type']='P105047',['has variable data 1']='P105048',['has variable data 2']='P105049',['has variable data 3']='P105050',['has variable data 4']='P105051',['has variable data 5']='P105052',['has variable data 6']='P105053',['has variable data 7']='P105054',['has variable SW 1']='P105055',['has variable SW 2']='P105056',['has variable SW 3']='P105057',['has variable SW 4']='P105058',['reports']='P105059',['altLabel']='P105060',['hasCompoundElement']='P105061',['source of AIS data']='P118030',['Logic type']='P106001',['spelling']='P106002',['used software']='P118031',['research problem description ']='P118032',['methods ']='P118033',['research results']='P118034',['reccomendations for the future results']='P118035',['Participant: carer of hearing-impaired children']='P118060',['# image']='P106003',['external dataset']={'P106004','P106005'},['Participant: family with a impaired children']='P118062',['neural-symbolic model']='P106006',['rating type']='P106007',['percentage training rating']='P106008',['is review paper?']='P106009',['penetration depth [nm]']='P106011',['centralization']='P106012',['machine']='P106013',['aperture diameter']='P106014',['aperture diameter [mm]']='P106015',['distance [mm]']='P106016',['sputtering rate']='P106017',['sputtering rate [nm/s]']='P106018',['homogeneity']='P106019',['Participant: Normal hearing individuals with wind-voiced earphones']='P118063',['Participant: kindergarten-preschool children with hidden hearing status ']='P118064',['has study year']='P118036',['has languages']='P118037',['adopted language']='P118038',['Experiment phases']='P118039',['categorized in']='P118040',['Type of intervention']='P118045',['Duration of Programme']='P118046',['Indicators for monitoring']='P118047',['residential location choice']='P118048',['prefer']='P118049',['no preference ']='P118050',['limited differences']='P118051',['has problem domain']='P118052',['has ressearch problem']='P118053',[' type of study design']='P118054',['evaluation dataset']='P118055',['Participant: deaf person']='P118056',['Participant: hard-of-hearing persons']='P118057',['Participant: normal hearing person']='P118058',['ship database']='P118065',['types ']='P118066',['contribution objective']='P118067',['school subject']='P118068',['Activities type']='P118069',['Allows self-learning']='P118070',['asynchronous learning content']='P118071',['Educational level']='P118072',['Educational strategy']='P118073',['ICT content']='P118074',['ICT services  ']='P118075',['Needs an internet access']='P118076',['Allows personalization']='P118077',['Being taught']='P118078',['Participant: child with hearing implants ']='P118079',['Participat: student']='P118080',['Participant: teacher']='P118081',['Participant: schoolchild']='P118082',['category of participant']='P118083',['type of persistent identifiers']='P118084',['has fixed effect term II']='P118085',['has random effect term']='P118086',['qudt:numericValue']='P118087',['qudt:unit']={'P118089','P118088'},['country of research origin']='P119000',['Training title']='P119001',['training title abbreviation']='P119002',['students with special needs']='P119003',['Training topics']='P119004',['In-training activities']='P119005',['Training activities period']='P119006',[' Training completion criteria']='P119007',['Training place']='P119008',['Year of the training start']='P119009',['Training in-person']='P119010',['Participant: Community Learning Disability Team (CLDT) member']='P119011',['Participant: Daycare educator']='P119012',['Participant: family caregiver']='P119013',['Participant: General education art teacher']='P119014',['Participant: General education math teacher']='P119015',['Participant: Generalist teacher']='P119016',['Participant: Paraprofessional']='P119017',['Participant: psychiatrist']='P119018',['Participant: service manager']='P119019',['Participant: Special education teacher']='P119020',['Participant: Special education technician']='P119021',['Participant: Specialist teacher']='P119022',['Participant: Staff of residence with special services']='P119023',['Participant: support staff']='P119024',['Participant: trainer']='P119025',['Participant: Work with children with autism and/or developmental delay']='P119026',['occlussion level']='P119027',['Main findings']='P119028',['R601359']='P119029',['R601361']='P119030',['R601363']='P119031',['R601365']='P119032',['R601367']='P119033',['R601369']='P119034',['R601371']='P119035',['R601373']='P119036',['R601375']='P119037',['R601377']='P119038',['R601379']='P119039',['R601381']='P119040',['R601383']='P119041',['R601385']='P119042',['R601387']='P119043',['R601389']='P119044',['R601391']='P119045',['R601396']='P119046',['R601398']='P119047',['R601400']='P119048',['R601402']='P119049',['R601404']='P119050',['R601406']='P119051',['R601408']='P119052',['R601410']='P119053',['R601412']='P119054',['R601414']='P119055',['R601416']='P119056',['R601418']='P119057',['R601420']='P119058',['R601422']='P119059',['R601424']='P119060',['R601426']='P119061',['R601428']='P119062',['ICT measurement']='P119063',['ICT elasticity']='P119064',['start of covered period']='wikidata:P7103',['end of covered period']='wikidata:P7104',['learning environment']='P119065',['Educational model']='P119066',['education stage']='P119067',['educational group']='P119068',['academic major']='wikidata:P812',['PhD program']='P119069',['Education course']='P119070',['documentary support']='P119071',['participant: student']='P119072',['Participant: administrative staff']='P119073',['Education mode']='P119074',['Experimental Settings']='P119075',['has linked images']='P119076',['has  result-precison']='P119077',['has result-recall']='P119078',['has result-accuracy']='P119079',['has result-others']='P119080',['literal translation']='wikidata:P2441',['Type of research paper']='P119082',['temporal replication']='P119083',['statement supported by']='wikidata:P3680',['has baselines']='P119084',['dependent variable']='P119085',['highest achieved coefficient of determination on verification or testing part']='P119086',['`has evaluation results-precision']='P119087',['has evaluation results-recall']={'P119088','P119089','P119090'},['has evaluation results-f1 score']='P119091',['has evaluation result-accuracy']='P119092',['has evaluation result-auc']='P119093',['has evaluation result-sensitivity']='P119094',['has evaluation result-specificity']='P119095',['has evaluation result-f1 score']='P119096',['has evaluation result-recall']='P119097',['`has evaluation result-precision']='P119098',['forecast lead time']='P119099',['historical dataset length']='P119100',['number of parts in dataset split']='P119101',['ratio of parts in dataset split']='P119102',['endogenous predictors']='P119103',['exogenous predictors']='P119104',['Main conclusion']='P119130',['missing data handling']='P119105',['number of comments']='wikidata:P10651',['number of reblogs']='wikidata:P10756',['has evaluation result others']='P119106',['has evaluation results others']='P119107',['Project type']='P119108',['Participant: country']='P119109',['Participant: University']='P119110',['Participant: others']='P119111',['Project aim']='P119112',['in-project activities']='P119113',['Project language']='P119114',['short-term objectives']='P119115',['long-term objectives']='P119116',['project outcomes']='P119117',['project start']='P119118',['project end']='P119119',['International program']='P119120',['beneficiar']='P119121',['Indirect beneficiar']='P119122',['Expece items']='P119123',['Social project']='P119160',['Fielf of knowledge']='P119161',['Item type']='P132024',['URLs']='P132025',['project URL']='P119124',['Educational project']='P119125',['International project']='P119126',['Project duration']='P119127',['budget']='wikidata:P2769',['Expence items']='P119128',['fraction']='P119131',['Pretraining length (tokens)']='P119132',['Pretraining compute [PetaFLOPs-days]']='P119133',['Sampling proportion']='P119134',['Disk size']='P119135',['Hardware details']='P119136',['Hardware used']='P119138',['Hardware information']='P119137',['GPU Power consumption']='P119139',['Total power consumption']='P119140',['Carbon emitted']='P119141',['Carbon emitted (tCO2eq)']='P119142',['replication package']='P119143',['Finetuning corpus']='P119144',['source website for the property']='wikidata:P1896',['use MARC field']='P119145',['string normalization']='P119146',['code repository (compiled)']='P119147',['evalutation dataset']='P119148',['Abstraction']='P119149',['quality feedback']='qualityFeedback',['visual features']='P119150',['Location:Country_Code']='P119151',['Location:Study_Area']='P119152',['Location:Location']='P119153',['Study_startdate']='P119154',['Study_enddate']='P119155',['Country Code']='P119156',['Location Name']='P119157',['Study start date']='P119158',['Study end date']='P119159',['Field Design']='P119162',['Soil texture']='P119163',['Soil pH']='P119164',['Intervention tested']='P119165',['Management system']='P119166',['Utilised pulse crop']='P119167',['Pulse: cultivar name']='P119168',['Pulse: sowing month']='P119169',['Pulse: Sowing between row space (cm) ']={'P119170','P119192','P119200','P119201','P119210','P119211','P119212'},['Pulse: Sowing within row space (cm)']='P119171',['Pulse: Tillage regime']='P119172',['Pulse: Maximum tillage depth (cm)']='P119173',['Pulse: Fertilisation regime']='P119174',['Pulse: N-addition (kg/ha)']='P119175',['Pulse: Pesticide application']='P119176',['Pulse: Weed management']='P119177',['Comparator']='P119178',['Biodiversity: Survey Method']='P119179',['Biodiversity: Effect dimension']='P119180',['Biodiversity: Taxon surveyed']='P119181',['Biodiversity: Unit']='P119182',['Biodiversity: Intervention (Xi) number']='P119183',['Biodiversity: Comparator (Xc) number']='P119184',['ln(Xi)']='P119185',['ln(Xc)']='P119186',['lnR']='P119187',['Crop rotation']='P119188',['Pulse: sowing density unit']='P119189',['Pulse: sowing density']='P119190',['Cover crop']='P119191',['Yield: Survey Method']='P119193',['Yield: Effect dimension']='P119194',['Yield: Unit']='P119195',['Yield: Intervention (Xi) number']='P119196',['Yield: Comparator (Xc) number']='P119197',['Intercrops']='P119198',['descriprion']='P119199',['Soil quality: Survey Method']='P119202',['Soil quality: Soil sample depth (max. cm)']='P119203',['Soil quality: Effect dimension']='P119204',['Soil quality category']='P119205',['Soil quality grouped indicator']='P119206',['Soil quality exact indicator']='P119207',['Soil quality: Unit']='P119208',['Soil quality: Intervention (Xi) number']='P119209',['Field of knowledge']='P119213',['number of NVD descriptions']='P119214',['orkgSubmitter']='P119215',['BERT fixed in training']='P119216',['continual knowledge infusion']='P119217',['has evaluation result']='P119218',['Abnormality-AUC']='P119219',['Disease-AUC']='P119220',['Dice score']='P119221',['fusion level']='P119222',['model size']='P119223',['Authors: Country']='P119224',['Oldest reference']='P119225',['Newest reference']='P119226',['contribution aim']='P119227',['Software developed']='P119228',['Contribution goal']='P119229',['Computational method used']='P119230',['Method developed']='P119231',['Prospects of future research']='P119232',['Neural network developed']='P119233',['Neural network type']='P119234',['research application']='P119235',['native label']='wikidata:P1705',['Evaluation metics']='P119236',['curated problems']='P119237',['citing bergen bullying research group papers']='P119238',['Using Negative Acts Questionnaire-Revised (NAQ-R)']='P119239',['training time']='P120000',['training time, s']='P120001',['Galiciana work ID']='wikidata:P3004',['R-Square']='P120002',['Pearson Correlation Coefficient PCC']='P120003',['Average Margin of Error - AME']='P120004',['temporal resolution of observations']='P120005',['extreme values choice']='P120006',['temporal downscaling']='P120007',['probability distribution']='P120008',['model calibration']='P120009',['sampling rate']='wikidata:P11413',['intensity duration frequency formula']='P120010',['primary processing of rainfall data']='P120011',['maximum series contruction']='P120012',['assumption of time series behaviour']='P120013',['Cites']='P121000',['CitesURL']='P121001',['GSRank']='P121002',['QueryDate']='P121003',['CitationURL']='P121004',['StartPage']='P121005',['EndPage']='P121006',['ECC']='P121007',['CitesPerYear']='P121008',['CitesPerAuthor']='P121009',['AuthorCount']='P121010',['spatial downscaling']='P121011',['GNN Type']='P130045',['uncertainty estimation']='P121013',['recorded AIS data']='P121014',['recorded trajectories']='P121015',['processed AIS data']='P121016',['processed trajectories']='P121017',['number of ships']='P121018',['ship type']='P121019',['voltage']='wikidata:P2436',['Electric Field (kV/mm)']='P121020',['has list element']='hasListElement',['authors']='hasAuthors',['catchment area']='P123011',['design storm']='P123012',['duration of design storm']='P123013',['Conference name']='P122000',['Conference date']='P122001',['Conference code']='P122002',['Funding Text 1']='P122003',['Funding Details']='P122004',['Author full names']='P122005',['evaluation criteria']='P122006',['evaluation aspect']='P122007',['Total Students']='P122008',['conducted exams']='P122009',['Used LLMs']='P122010',['Precision/recall/balanced']='P122011',['return period']='P123014',['calibrated parameters']='P123015',['LID practices']='P123016',['most efficient LID practices']='P123017',['return period of storm']='P123018',['reduction of peak runoff']='P123019',['reduction of runoff volume']='P123020',['covered languages']='P123000',['language type']='P123001',['evaluated task']='P123002',['NLP Tasks for evaluation']='P123003',['benchmarked datasets']='P123004',['studied by']='wikidata:P2579',['designed prototype']='P123005',['Selected Problems']='P123006',['problem topics']='P123007',['evaluation ']='P123008',['designed prototype for evaluation']='P123009',['filed of study']='P123010',['research_area']='P129007',['observed rainfall event']='P123021',['creation of IDF curves from historical data ']='P123022',['creation of IDF curves from climate model output']='P123023',['model calibration on observed rainfall event']='P123024',['model verification on observed rainfall event']='P123025',['multivariate frequency analysis']='P123026',['camera pose']='P123027',['number of lanes']='wikidata:P10367',['segmentation']='P123028',['trajectories']='P123029',['dashboard developer country']='P123030',['source of data']='P123031',['level of data granularity']='P123032',['main indicators of COVID-19']='P123033',['ancillary indicators of COVID-19 (other)']='P123034',['data processing']='P123035',['data sources']='P123036',['Threats To Validity']='P123037',['Research Object']='P123038',['primary area']='P123039',['benchmark name']='P123040',['data samples']='P123041',['total ability']='P123042',['reasoning abilities']='P123043',['reasoning abilities (L2)']='P123044',['evaluated models on MMBench']='P123045',['training method']='P123046',['total ability task']='P123047',['Output data type']='P123048',['references work, tradition or theory']='wikidata:P8371',['additional information']='P123049',['tool useses AI']='P124000',['evaluation uses AI']='P124001',['System Usability Score']='P124002',['has sector']='P126016',['has tagged value']='P127000',['ethical risks']='P124003',['paper eligibility criteria']='P125000',['paper exclusion criteria']='P125001',['article type']='P126002',['Authors` Keywords']='P126003',['managing']='P126004',['application used']='P126005',['educational subject']='P126006',['educational specialty']='P126007',['beneficiary']='P126008',['concerns distance education (y/n)']='P126009',['Research outcome']='P126010',['type of research outcome']='P126011',['number of languages']='P126012',['has hypothesis test (invasion biology)']='P126013',['test score']='wikidata:P5022',['is conclusive']='P126014',['considers socio-political factor']='P126015',['has socio-policital factor type']='P126017',['has representation type']='P126018',['has tag']='P127001',['Data Preprocessing']='P127002',['Recall (%)']='P127003',['Data Preparation']='P127004',['AIS data ']='P127005',['trajectories points']='P127006',['expression, gesture or body pose']='wikidata:P6022',['category contains']='wikidata:P4224',['has current density J [A/mm²]']='P127007',['type of the task']='P127008',['number of ctiteria']='P127009',['warehouse type']='P127010',['container type']='P127011',['Data model']='P127012',['Data origin']='P127013',['transport type']='P127014',['Modes of shipment']='P127015',['Conrtibutio research actuality']='P127016',['R Packages']='P128000',['input data type - observation stations']='P128001',['input data type - model output']='P128002',['real-time prediction']='P128003',['short term prediction']='P128004',['mid term prediction']='P128005',['long term prediction']='P128006',['simultaneous usage of endogenous and exogenous predictors']='P128007',['multioutput model and/or chain model']='P128008',['absolute performance metrics - mean absolute error and/or root mean square error']='P128009',['relative performance metrics - coefficient of determination and/or Nash-Sutcliffe efficiency ']='P128010',['comparison of model and observations']='P128011',['model vs. observations']='P128012',['high tide events']='P128013',['input and/or output data type - observation stations']='P128014',['high water events']='P128015',['Data Cleaning']='P128016',['is considered in']='P128017',['belongs to']='P128018',['Deep Learning Model']='P129000',['Knowledge Graph Creation Approach']='P129001',['Knowledge Graph Completion']='P129002',['Results/ Benefits']='P129003',['created_web_Application']='P129004',['Knowledge Graph creation tool']='P129005',['has invasion biology research questions']='P129006',['graph_creation_method']='P129008',['disease severity']='P129009',['cell concentration']='P129010',['species']='P129011',['organ']='P129012',['cell marker']='P129013',['results of patient groups']='P129014',['marker for cell identification']='P129015',['action marker']='P129016',['in-vivo']='P129017',['frequency of activated T helper cells']='P129018',['correlation found']='P129019',['single- plamid based genetic tool ']='P129020',['available data']='P129021',['uses_ontolology']='P129022',['syntactic_module']='P129023',['Levenshtein similarity']='P129024',['word_embeddings']='P129025',['semantic_module']='P129026',['post-processing']='P129027',['Country/Region']='P129028',['object of visualiztion']='P129029',['object of virtualiztion']='P129030',['type of object visualized']='P129031',['type of object virtualized']='P129032',['technology used']='P129033',['application technology']='P129034',['devices to be used']='P129035',['is a building?']='P129036',['Object`s cration time/period']='P129037',['cause of damage (changes)']='P129038',['modelling approach']='P129039',['Historical edidences']='P129040',['Stable isotope analysis ']='P129041',['uav']='P129042',['aerial view']='wikidata:P8592',['Aerial mapping']='P129043',['native species']='P129044',['cytokine overexpression']='P129045',['methodological context']='P129046',['object title']='P129047',['type of the pbject']='P129048',['object is  a part of']='P129049',['period of object`s origin']='P129050',['historic photo']='P129051',['Historic map']='P129052',['Historic flight photos']='P129053',['historical engineering drawings']='P129054',['historical steel catalogues']='P129055',['ршіещкшсфд technical reports']='P129056',['historical technical reports']='P129057',['historical plan']='P129058',['historical letters']='P129059',['diary']='P129060',['historical drawing']='P129061',['painting']='P129062',['historical engraving']='P129063',['historical land records']='P129064',['information modelling methodology']='P129065',['cause of destoyed']='P129066',['period of damage']='P129067',['obect exists in any condition']='P129068',['released on']='P130000',['ensemble technique']='P130002',['peak streamflows']='P130003',['higher education institution country']='P130004',['Number of objects examined']='P130005',['type of object']='P130006',['accessibility evaluation tool']='P130007',['objetives']='P130008',['rules violation checked (y/n)']='P130009',['success criteria']='P130010',['top-three violations']='P130011',['Web Content Accessibility Guidelines Version']='P130012',['Level (A / AA / AAA)']='P130013',['key feature']='P130014',['evaluated models on proposed benchmark']='P130015',['clustering visualization']='P130016',['Adjusted random index (ARI)']='P130017',['Fowlkes–Mallows index (FMI)']='P130018',['Six Degrees of Francis Bacon ID']='wikidata:P2401',['collection or exhibition size']='wikidata:P1436',['website type']='P130019',['top mistakes']='P130020',['research period']='P130021',['paired supervisor and phd students']='P130022',['workstations']='P130024',['has efficiency']='P130023',['Twitter']='P130025',['has number of modules']='P130026',['Ontology Evaluation']='P130027',['Domain specific task']='P130028',['specific domain ']='P130029',['Infection Rate']='P130030',['Data Exfiltration ']='P130031',['Resistance']='P130032',['Detection Avoidance']='P130033',['Attack Vector Flexibility']='P130034',['Hack Tool']='P130035',['major elements']='P130036',['Layer Perspective']='P130037',['focuses on']='P130038',['managed by']='P130039',['development phases']='P130040',['neurodevelopmental features']='P130041',['Missing time period']='P130042',['anomaly detection']='P130043',['Total benchmarks']='P130044',['Insight 1']='P132029',['prompting']='P130047',['LLM Type']='P130046',['related domain']='P130048',['level of task']='P130049',['Covariance']='P132011',['statistical mesasures']='P132012',['Suggested action']='P140000',['research direction']='P131000',['covered approaches']='P131001',['key techniques']='P131002',['placeholder']='placeholder',['Used Graph']='P132000',['pressure']='P132001',['CAS Registry Number']='wikidata:P231',['pressure unit']='P132002',['chemical formula']='wikidata:P274',['Class entropy']='P132003',['Norm. entropy']='P132004',['Mutual information']='P132005',['Noise Signal Ratio']='P132006',['Mean and standard values ']='P132007',['mean noise to signal ratio']='P132008',['normal entropy']='P132009',['mutal information']='P132010',['a']='P132013',['Quantitative analysis of raw material extraction in Latin America']='P132014',['Meta Data from Worldbank, CEPAL, UN Comtrade']='P132015',['Quantitative comparison of 15 Latin American countries (mining/production and exports)']='P132016',['Extractivism takes on very different intensities and dynamics in the region and can be categorised into four regional clusters (extreme extractivism, intensive extractivism, partial extractivism and weak extractivism).']='P132017',['Literature Review']='P132018',['The paper begins with an overview of the development theory and policy debates on the commodity-based development model and the implementation of indigenous rights. Finally, the question of whether sustainable practices of indigenous groups should be understood as an expression of their specific culture and whether these types of economic activity are relevant and realisable as models for a larger social context will be explored.']='P132019',['The relationship between resource-based developments and the implementation of indigenous autonomy rights has hardly been analysed to date. Numerous studies in the research field emphasise the importance of the recognition of indigenous rights for processes of social decolonisation and democratisation and identify their guarantee as a central prerequisite for the protection of ecologically sensitive regions (e.g. Bebbington et al. 2018). protection of ecologically sensitive regions. However, they often tend to focus indigenous groups in conflicts over land and resources on the defence of \"traditional ways of life\" and a \"harmonious relationship with nature\" and thus run the risk of ignoring important objectives which, in addition to the defence of land and raw materials, can also include coping with social change and improving the general living conditions of the affected population groups.']='P132020',['convariance']='P132021',['Mean absolute deviation']='P132022',['subtask']='P132027',['haslocation']='P132023',['PMID']='P132026',['Overshooting 1.5°C is fast becoming inevitable. Minimising the magnitude and duration of overshoot is essential']='P132028',['located in the administrative territorial entity']='wikidata:P131',['length']='wikidata:P2043',['Gloabal avarage tempreture']='P133000',['Global average temperature']='P133001',['Best_practices']='P133002',['Advanced_strategies']='P133003',['research problem (Insight 1)']='P133004',['said to be the same as']='wikidata:P460',['Insight']='P140014',['popularity features']='P142029',['context aware features']='P142028',['Precursors or molecules used']='P141001',['mitigation strategies']='P134000',['farming stage']='P134001',['activities/factors']='P134002',['activities or factors']='P134003',['preharvesting parameter']='P134004',['important features']='P134005',['classification classes defined for the features']='P134006',['dataset used (public or own)']='P134007',['total numbers of images used for training']='P134008',['best model or method or algorithm']='P134009',['model evaluation technique']='P134010',['disease name']='P134011',['focal length during strain [mm]']='P135002',['focal length']='wikidata:P2151',['focal length during strain']='P135000',['focal length [mm]']='P135001',['relative focal length change (%)']='P135003',['toughness']='wikidata:P5520',['characteristics of communication']='P135004',['requirements for communication']='P135005',['use case class']='P135006',['considers failures in power grid']='P135007',['type of algorithm / methodology']='P135008',['geographical area']='P135009',['number of communication participants']='P135010',['frameworks']='P135011',['performance indicators power grid']='P135012',['objective for considering communication']='P135013',['communication modelling approach']='P135014',['description communication modelling approach']='P135015',['uses external framework']='P135016',['considers state of communication network']='P135017',['considers stochastical elements']='P135018',['performance indicators communication']='P135019',['communication technologies']='P135020',['considers communication failures']='P135021',['overlay topology']='P135022',['Dependencies between communication and energy systems']='P135023',['description of the use case']='P135024',['communication properties']='P135025',['communication requirements']='P135026',['type of algorithm/methodology']='P135027',['organizational structure']='P135028',['considers communication network state']='P135029',['considers stochastic elements']='P135030',['communication topologies']='P135031',['communication failures']='P135032',['type of potential']='P135033',['wind speed data']='P135034',['turbine height min']='P135035',['turbine height max']='P135036',['number of turbines']='P135037',['rotor diameter min']='P135038',['rotor diameter max']='P135039',['turbine capacity min']='P135040',['turbine capacity max']='P135041',['Wikidata language code']='wikidata:P9753',['stated in']='wikidata:P248',['relevancy estimation']='P138000',['based on dataset']='P138002',['based on paper']='P138003',['MRR']='P138016',['based on human rating']='P138001',['close match']='P135042',['has latent variables']='P135043',['has regressions']='P135044',['has variances and covariances']='P135045',['venue serie']='P135046',['allows graph view']='P135047',['uses embeddings']='P135048',['provides UI']='P135049',['allows editing']='P135050',['allows source attribution']='P135051',['ontology based']='P135052',['has lmm significance testing']='P135053',['has anova']='P135054',['has lmm prediction']='P135055',['has linear regression']='P135056',['area of expertise']='P135057',['ACM Digital Library author ID']='wikidata:P864',['Arnet Miner author ID']='wikidata:P5776',['Google News topics ID']='wikidata:P5337',['Loop ID']='wikidata:P2798',['DBLP author ID']='wikidata:P2456',['ResearcherID']='wikidata:P1053',['paper:links_source_information']='P136009',['paper:external_ontology_support']='P136004',['paper:uses_embeddings']='P136007',['paper:provides_confidence_score']='P136008',['paper:scientific_relation']='P136006',['paper:allows_editing']='P136003',['paper:provides_GUI']='P136005',['has degradation type']='P140011',['Multiplatform']='P136010',['Multiple user roles']='P136011',['Multiple user support']='P136012',['Project auditing']='P136013',['Project progress']='P136014',['Authentication']='P136015',['Status of software']='P136016',['Automated full-text retrieval']='P136017',['Automated search']='P136018',['Snowballing']='P136019',['Manual reference importing']='P136020',['Manually attaching full-text']='P136021',['Manually inserting full-text']='P136022',['Reference importing']='P136023',['Deduplication']='P136024',['Discrepancy resolving']='P136025',['In-/excluding references']='P136026',['Reference labelling & comments']='P136027',['Screening phases']='P136028',['Exporting results']='P136029',['Flow diagram creation']='P136030',['Living/updatable']='P136031',['Free to use']='P136032',['Systematic literature review stage']='P136033',['has published version']='hasPublishedVersion',['main species']='P136037',['Restoration intervention type']='P136034',['Time since restoration']='P136035',['monitoring duration']='P136036',['environmental disturbance']='P136038',['reason for restoration']='P136039',['soil property']='P137000',['dataset features']='P137001',['machine learning objective']='P137002',['machine learning algorithm']='P137003',['machine learning algorithms/methods']='P137004',['properties for this type']='wikidata:P1963',['evaluation measures']='P138015',['water property']='P138004',['animal specie']='P138005',['crop name']='P138006',['clicked']='P138007',['read']='P138008',['cited']='P138009',['liked']='P138010',['relevancy']='P138011',['other user']='P138012',['other automatic']='P138013',['Candidate_facet_generation']='P139000',['facet_types']='P139007',['candidate_facet']='P139001',['direct_property']='P139002',['indirect_property']='P139003',['path_length']='P139004',['Categorical Facets']='P139005',['Quantitative Facets']='P139006',['Candidate_facets']='P139008',['Facet_selection']='P139009',['Intra-Facet Metrics']='P139010',['paper_link']='P139011',['Inter-Facet Metrics']='P139012',['facet extraction']='P139013',['facet values extraction']='P139014',['semantic similarity']='P139015',['parameters for value cardinality scoring']='P139016',['predicate probability']='P139017',['investigated part']='P141000',['Range of substrate/deposition temperatures']='P141002',['Growth Rate']='P141003',['Film Thickness']='P141004',['Film Density']='P141005',['Refractive Index']='P141006',['Electrical Properties']='P141007',['Chemical Composition']='P141008',['Mechanical Properties']='P141009',['Surface Roughness']='P141010',['Gas Permeability']='P141011',['Selection of viewpoints']='P140001',['Rotating field of view']='P140002',['Optic Flow']='P140003',['Velocity profile']='P140004',['Scale of space']='P140005',['Human activity']='P140006',['Building\'s function']='P140007',['Expending energy while moving']='P140008',['sustainable development goal']='sustainableDevelopmentGoal',['has restoration method']='P140009',['has ecosystem type']='P140010',['Balanced Accuracy']='P140012',['ML/DL method']='P140013',['covid-19 audio related symptom']='P143018',['Insight on Carbon Dioxide']='P140015',['insight on climate change and immobility']='P140016',['Insight on extreme weather']='P140017',['Insight on Food system transformation']='P140018',['Insight on Health impact']='P140019',['Insight on critical climate thresholds 1.5 degree']='P140020',['SLR Task']='P140021',['Human Interaction']='P140022',['Text Representation']='P140023',['Minimum Requirement']='P140024',['Model Execution']='P140025',['Pre-screening Support']='P140026',['Post-Screening Support']='P140027',['paper:contribution']='P140028',['SLR stage']='P140029',['R0 value']='P140030',['CI-values']='P140031',['summary insight']='P142000',['has heat treatment/coating']='P142001',['has base oil']='P142002',['has additive']='P142003',['has viscosity']='P142004',['rpm']='P142005',['machine used']='P142006',['IUCN realm']='P142008',['IUCN biome']='P142009',['IUCN EFG']='P142010',['degradation type']='P142011',['supports WEC initiation mechanism']='P142012',['has morphological result']='P142013',['has methodological result']='P142014',['microstructure']='wikidata:P5589',['Symbolic Representation']='P142015',['Human-in-Loop']='P142016',['Trustworthiness']='P142017',['Explainability']='P142018',['Transparency']='P142019',['local name']='P142020',['food type']='P142021',['food form']='P142022',['scientific name']='P142023',['common name']='P142024',['has listed ingredient']='wikidata:P4543',['importance']='P142025',['food image']='P142026',['WEC influence']='P145022',['FH-BU algorithm']='P142030',['FH-TD algorithm']='P142031',['Summery insight']='P142032',['Summry insight']='P142033',['Summery insoght']='P142034',['yearly change']='P142035',['site coordinates']='P142036',['hasDataset']='P142037',['country of sample']='P142038',['kind of human sample']='P142039',['definition of polarization']='P142040',['secondary data source']='P142041',['political topic assessed']='P142042',['type of media']='P142043',['summary of findings']='P142044',['type of polarization assessed']='P142045',['polarization measurement']='P142046',['human sample type']='P142047',['Computer-based format']='P142048',['type of corpus research']='P142049',['corpus volume']='P142050',['corpus source']='P142051',['Corpus elements type']='P142052',['DL model']={'P142053','P142054'},['DL method']='P142055',['ML algorithm']='P142056',['data_set']='P142057',['used features']='P142058',['mythology']='P142059',['bilingual corpora used']='P142060',['Sign language translated']='P142061',['Proposed Dataset']='P143000',['Researsh problem']='P143001',['recommendation']='P143002',['Study species']='P143003',['Species\' climate']='P143004',['study findings']='P143005',['ethics considerations']='P143006',['Latitude range']='P143007',['no. of facets k']='P143008',['average execution time']='P143009',['user study questions']='P143010',['Experiment queries']='P143011',['user ratings']='P143012',['facet selection and/or ranking']='P143013',['keyword queries']='P143014',['Veterans` needs']='P143015',['How to help Veterans']='P143016',['Women Veterans']='P143017',['Mean Reciprocal Rank (MRR)']='P143019',['TechQA dataset']='P143020',['Baseline (Elastic Search)']='P143021',['DFS (Dynamic facet search) Flat']='P143022',['DFS (Dynamic facet search) Typed']='P143023',['Dictionaries evaluated']='P143024',['Dictionary']='P143025',['Visual representation of the entries']='P143026',['Entries type']='P143027',['research methodology']='P143028',['research findings']='P143029',['research limitations']='P143030',['Statistical analyses']='P143031',['LDA score cutoff']='P143032',['Goodness of fit']='P143035',['Benchmark Description']='P143036',['Benchmark Methodology']='P143037',['throughput']='wikidata:P2957',['CAD Affliation Neutral']='P144000',['CAD Identity Directed Hate']='P144001',['CAD Affliation Directed Hate']='P144002',['LTI Person Directed Neutral']='P144003',['LTI Person Directed Hate']='P144004',['Derogatory Slur']='P144005',['Not Derogatory Slur (NDG)']='P144006',['Homonym (HOM)']='P144007',['Hateful']='P144008',['Offensive']='P144009',['Normal']='P144010',['Undecided']='P144011',['mAP']='P144012',['Train accuracy']='P144013',['A subset of the OMG Enterprise SQL Schema with 199 Tables, selecting 13 tables for the benchmark ']='P144014',['schema']='P144015',['question/answer pairs']='P144016',['Survey questions']='P144017',['Survey respondents']='P144018',['Model name']='P144019',['Physical parameter']='P144020',['Physical Properties']='P144022',['shape']='wikidata:P1419',['height']='wikidata:P2048',['width']='wikidata:P2049',['original_article']='P144026',['nominal voltage']='P144023',['Upper voltage limit']='P144024',['Lower voltage limit']='P144025',['orkg_paper']='P144027',['reborn_paper_production']='P144028',['reborn_data_production']='P144029',['reborn_production']='P144030',['first_author']='P144031',['published_in']={'P144032','P144033'},['uri_interlinking']='P145010',['original_research_finding']='P144034',['orkg_template']='P144035',['data_analysis_method']='P144036',['json_data']='P144037',['mentioned']='P145000',['COVID-19 Target']='P145001',['Potent In Drugs']='P145002',['Constrain the relations with:']='P145003',['collaboration']='P145004',['strengths']='P145005',['reborn_deposition']='P145006',['data_repository']='P145007',['doi_interlinking']='P145008',['uri']='P145009',['reborn_collection']='P145011',['method name']='P145012',['research topic']='P145013',['paper title']='P145014',['aim ']='P145015',['image_type']='P145016',['image transformation strategy']='P145017',['image transformation methods']='P145018',['image detection strategy']='P145019',['image detection method']='P145020',['detection criteria classification']='P145021',['observed feature']='P145023',['type of influence']='P145024',['influenced feature']='P145025',['WEC risk increases']='P145026',['user responses']='P145027',['overall agreement between survey users and system']='P145028',['average result']='P145029',['Fleiss Score']='P145030',['Facets']='P145031',['MAP_score']='P145032',['F_score']='P145033',['level of facet categories (max_l)']='P145034',['maximum number of facet terms at the top-level, i.e. level 2']='P145035',['look-ahead parameter d of the top-down method']='P145036',['Input Datasource']='P145037',['Input type of KG']='P145038',['R691895']='P145039',['estimated Model (in Latex)']='P145040',['ICT Measure']='P145041',['Elasticity']='P145042',['Level of Aggregation']='P145043',['N/Year']='P145044',['Output Measure']='P145045',['Robustness of Method']='P145046',['GPT (General Purpose Technology) Approach']='P145047',['GPT Conclusion']='P145048',['Form of data']='P145049',['TFP Growth Residual']='P145050',['Price Deflator Used']='P145051',['key new insights']='P145052',['DataSource']='P145053',['Output type']='P145054',['Resource abstraction']='P145055',['Workflow orchestration']='P145056',['Data serialisation and storage']='P145057',['Experimental provenance']='P145058',}
return SciKGTeX
